@@ -12,7 +12,12 @@
  ***********************************************************************/
 
 #include "mwm.h"
+
+#if XmVERSION >= 2
+#include <Xm/Xpm.h>
+#else
 #include <XmI/XmXpm.h>
+#endif
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -57,6 +62,15 @@ static unsigned char def_bitmap_bits[] =
     0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xff, 0xff, 0xff, 0xff,
     0xff, 0x03};
 
+
+#ifdef __EMX__
+ /* dos-like */
+#define cPATHELEMENTSEP ';'
+#else
+  /* un*x-like */
+#define cPATHELEMENTSEP ':'
+#endif
+
 /*
  * Find the specified icon file somewhere along the given path.
  *
@@ -100,7 +114,7 @@ find_icon_file(char *icon, char *pathlist, int type)
     /* Search each element of the pathlist for the icon file */
     while ((pathlist) && (*pathlist))
     {
-	dir_end = strchr(pathlist, ':');
+	dir_end = strchr(pathlist, cPATHELEMENTSEP);
 	if (dir_end != NULL)
 	{
 	    strncpy(path, pathlist, dir_end - pathlist);
@@ -216,7 +230,11 @@ static void
 get_xpm_file(ScreenInfo *scr, MwmWindow *tmp_win)
 {
     XWindowAttributes root_attr;
-    XmXpmAttributes xpm_attributes;
+#if XmVERSION >= 2
+    XpmAttributes xpm_attributes;
+#else
+    _LtXpmAttributes xpm_attributes;
+#endif
     XImage *im, *imshape;
     GC gc;
     char *path = NULL;
@@ -228,12 +246,20 @@ get_xpm_file(ScreenInfo *scr, MwmWindow *tmp_win)
     XGetWindowAttributes(dpy, scr->root_win, &root_attr);
     xpm_attributes.colormap = root_attr.colormap;
     xpm_attributes.closeness = 40000;	/* Allow for "similar" colors */
-    xpm_attributes.valuemask = XmXpmSize | XmXpmReturnPixels | XmXpmColormap |
-	XmXpmCloseness;
+#if XmVERSION >= 2
+    xpm_attributes.valuemask = XpmSize | XpmReturnPixels | XpmColormap |
+	XpmCloseness;
+#else
+    xpm_attributes.valuemask = _LtXpmSize | _LtXpmReturnPixels | _LtXpmColormap |
+	_LtXpmCloseness;
+#endif
 
 #ifdef NONSTANDARD_CONVERTERS
-    if (_XmXpmReadFileToImage(dpy, path, &im, &imshape, &xpm_attributes) ==
-	XmXpmSuccess)
+#if XmVERSION >= 2
+    if (XpmReadFileToImage(dpy, path, &im, &imshape, &xpm_attributes) == XpmSuccess)
+#else
+    if (_LtXpmReadFileToImage(dpy, path, &im, &imshape, &xpm_attributes) == _LtXpmSuccess)
+#endif
     {
 
 	tmp_win->icon_pixmap = XCreatePixmap(dpy, scr->root_win,
