@@ -781,7 +781,7 @@ MENU_AddItem(ScreenInfo *scr, MenuRoot * menu, char *item, char *item2,
 
     if (func == F_POPUP)
     {
-	unsigned i;
+	int i;
 
 	if (action != (char *)0)
 	{
