@@ -475,7 +475,7 @@ smart_placement(ScreenInfo *scr, MwmWindow *t,
  * Handles initial placement and sizing of a new window. Returns False in
  * the event of a lost window.
  */
-Boolean
+static Boolean
 place_window(ScreenInfo *scr, MwmWindow *tmp_win)
 {
     MwmWindow *t;
@@ -998,7 +998,7 @@ lower_children(MwmWindow *win)
 void
 WIN_CaptureWindows(ScreenInfo *scr)
 {
-    int i, j;
+    unsigned int i, j;
     unsigned int nchildren;
     Window root, parent, *children;
 
