@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Mrm.c,v 1.20 2000/01/26 12:43:37 amai Exp $
+ * $Id: Mrm.c,v 1.21 2000/05/16 14:41:24 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -1229,8 +1229,7 @@ void
 ReadList(UilModuleType *Module)
 {
     int NumberOfWidgets;
-    int i;
-    char c;
+    int i, c;
 
     fread(&NumberOfWidgets, sizeof(int), 1, stdin);	/* INT(widget count)  */
     fread(&MaxAttributes, sizeof(int), 1, stdin);	/* INT(max attributes)  */
@@ -1248,7 +1247,7 @@ ReadList(UilModuleType *Module)
 
 	for (j = 0; (c != EOF) && (c != '"'); j++)
 	{			/* NAMES = NAME "  */
-	    string[j] = c;	/* NAME = [^"]*    */
+	    string[j] = (char)c;	/* NAME = [^"]*    */
 	    if (j >= MAX_STR)
 		Exit(LOC, "String def too long\n");
 	    c = getc(stdin);
