@@ -22,7 +22,7 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: Draw.h,v 1.6 2000/06/11 17:58:40 danny Exp $
+ * $Id: Draw.h,v 1.7 2000/08/21 15:01:49 danny Exp $
  */
 
 /*
@@ -44,8 +44,10 @@ void xbaeDrawCell(XbaeMatrixWidget, int, int);
 XbaeCellType xbaeGetDrawCellValue(XbaeMatrixWidget, int, int, String *,
 				      Pixmap *, Pixmap *, int *, int *,
 				      Pixel *, Pixel *, int *);
-void xbaeDrawString(XbaeMatrixWidget mw, Window win, GC gc, String string,
-			int length, int x, int y, int maxlen,
+static void xbaeDrawString(XbaeMatrixWidget mw, Window win, GC gc, String string,
+			int length,
+			int x, int y,
+			int maxlen, int maxht,
 			unsigned char alignment, Boolean highlight,
 			Boolean bold, Boolean rowLabel,
 			Boolean colLabel, Pixel color);
