@@ -22,7 +22,7 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: Draw.c,v 1.15 2000/06/11 17:58:53 danny Exp $
+ * $Id: Draw.c,v 1.16 2000/08/21 15:01:51 danny Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -260,6 +260,9 @@ xbaeDrawCellString(XbaeMatrixWidget mw,
     if (!win)
 	return;
 
+    if (row_height == 0)
+	return;		/* Quick fix */
+
 #if 0
     /*
      * Probably not needed - time will tell!  If anybody gets a segv on
@@ -331,14 +334,14 @@ xbaeDrawCellString(XbaeMatrixWidget mw,
     /*
      * Draw the string in the cell.
      */
-
     xbaeDrawString(mw, win, gc, str, strlen(str),
-		   x + TEXT_X_OFFSET(mw), y + TEXT_Y_OFFSET(mw),
-		   mw->matrix.column_widths[column],
-		   mw->matrix.column_alignments ?
-		   mw->matrix.column_alignments[column] :
-		   XmALIGNMENT_BEGINNING, selected,
-		   False, False, False, fg);
+		x + TEXT_X_OFFSET(mw), y + TEXT_Y_OFFSET(mw),
+		mw->matrix.column_widths[column],
+		row_height,
+		mw->matrix.column_alignments ?
+		mw->matrix.column_alignments[column] :
+		XmALIGNMENT_BEGINNING, selected,
+		False, False, False, fg);
 
 #if XmVersion >= 1002
     if (mw->matrix.highlighted_cells &&
@@ -439,14 +442,14 @@ xbaeDrawCellString(XbaeMatrixWidget mw,
     /*
      * Draw the string in the cell.
      */
-
     xbaeDrawString(mw, win, gc, str, strlen(str),
-		   x + TEXT_X_OFFSET(mw), y + TEXT_Y_OFFSET(mw),
-		   mw->matrix.column_widths[column],
-		   mw->matrix.column_alignments ?
-		   mw->matrix.column_alignments[column] :
-		   XmALIGNMENT_BEGINNING, selected,
-		   False, False, False, fg);
+	x + TEXT_X_OFFSET(mw), y + TEXT_Y_OFFSET(mw),
+	mw->matrix.column_widths[column],
+	-1,
+	mw->matrix.column_alignments ?
+	mw->matrix.column_alignments[column] :
+	XmALIGNMENT_BEGINNING, selected,
+	False, False, False, fg);
 
 #if XmVersion >= 1002
     if (mw->matrix.highlighted_cells &&
@@ -521,7 +524,8 @@ xbaeDrawCellWidget(XbaeMatrixWidget mw,
  * Draw a string with specified attributes. We want to avoid having to
  * use a GC clip_mask, so we clip by characters. This complicates the code.
  */
-void
+	/* FIX ME this should be clipped with the row height for the last row */
+static void
 xbaeDrawString(XbaeMatrixWidget mw,
 		Window win,
 		GC gc,
@@ -530,6 +534,7 @@ xbaeDrawString(XbaeMatrixWidget mw,
 		int x,
 		int y,
 		int maxlen,
+		int maxht,		/* Added for row heights */
 		unsigned char alignment,
 		Boolean highlight,
 		Boolean bold,
@@ -544,8 +549,12 @@ xbaeDrawString(XbaeMatrixWidget mw,
     Boolean choppedEnd = False;
     XRectangle *ink_array = NULL;
     XRectangle *logical_array = NULL;
-    int num_chars;
-    XRectangle overall_logical;
+    int num_chars, doclip;
+    XRectangle overall_logical, clipht;
+
+#ifdef	XBAE_VERBOSE
+    fprintf(stderr, "xbaeDrawString(%s) x %d y %d, clip w %d h %d\n", string, x, y, maxlen, maxht);
+#endif
 
     if (rowLabel || colLabel)
     {
@@ -557,6 +566,7 @@ xbaeDrawString(XbaeMatrixWidget mw,
 	font_struct = mw->matrix.font_struct;
 	font_set = mw->matrix.font_set;
     }
+
     /*
      * Initialize starting character in string
      */
@@ -567,6 +577,28 @@ xbaeDrawString(XbaeMatrixWidget mw,
     else 
 	maxwidth = maxlen * LABEL_WIDTH(mw);
 
+    /*
+     * Clip height
+     */
+    if (maxht < 0) {
+	doclip = 0;
+    } else {
+	doclip = 1;
+    }
+
+#if 0
+    clipht.height = y + maxht;
+    clipht.width = x + maxwidth;
+    clipht.x = 0;
+    clipht.y = 0;
+
+    if (doclip) {
+	fprintf(stderr, "XSetClipRectangles - x %d y %d w %d h %d\n",
+		x, y, clipht.width, clipht.height);
+	XSetClipRectangles(XtDisplay(mw), gc, 0, 0, &clipht, 1, Unsorted);
+    }
+#endif
+
     if (font_set)
     {
 	ink_array = (XRectangle*)XtMalloc(length * sizeof(XRectangle));
@@ -797,6 +829,18 @@ xbaeDrawString(XbaeMatrixWidget mw,
 	 */
 	x -= overall_logical.x;
 
+#if 1
+    clipht.height = y + maxht;
+    clipht.width = x + maxwidth;
+    clipht.x = 0;
+    clipht.y = 0;
+
+    if (doclip) {
+	fprintf(stderr, "XSetClipRectangles - x %d y %d w %d h %d\n",
+		x, y, clipht.width, clipht.height);
+	XSetClipRectangles(XtDisplay(mw), gc, 0, 0, &clipht, 1, Unsorted);
+    }
+#endif
 	/*
 	 * Now draw the string at x starting at char 'start' and of
 	 * length 'length'
@@ -985,6 +1029,20 @@ xbaeDrawString(XbaeMatrixWidget mw,
 	 * Now draw the string at x starting at char 'start' and of length
 	 * 'length'
 	 */
+#if 1
+    clipht.width = maxwidth + x;
+    clipht.height = maxht + y;
+    clipht.x = 0;
+    clipht.y = 0;
+
+    if (doclip) {
+#ifdef XBAE_VERBOSE
+	fprintf(stderr, "XSetClipRectangles 2 - x %d y %d w %d h %d\n",
+		x, y, clipht.width, clipht.height);
+#endif
+	XSetClipRectangles(XtDisplay(mw), gc, 0, 0, &clipht, 1, Unsorted);
+    }
+#endif
 #ifdef NEED_WCHAR
 	if (TWO_BYTE_FONT(mw))
 	    XDrawString16(XtDisplay(mw), win, gc, x, y, &string[start],
@@ -1006,6 +1064,10 @@ xbaeDrawString(XbaeMatrixWidget mw,
 		XDrawString(XtDisplay(mw), win, gc, x - 1, y,
 			    &string[start], length);
     }
+
+    if (doclip) {
+	XSetClipMask(XtDisplay(mw), gc, None);
+    }
 }
 
 void
@@ -1313,7 +1375,8 @@ xbaeDrawColumnLabel(XbaeMatrixWidget mw, int column, Boolean pressed)
 			   labelX, labelY, mw->matrix.column_widths[column],
 			   mw->matrix.column_label_alignments ?
 			   mw->matrix.column_label_alignments[column] :
-			   XmALIGNMENT_BEGINNING, False,
+			   XmALIGNMENT_BEGINNING,
+			False, -1,
 			   mw->matrix.bold_labels, False, True,
 			   mw->matrix.column_label_color);
 	
@@ -1412,13 +1475,14 @@ xbaeDrawRowLabel(XbaeMatrixWidget mw, int row, Boolean pressed)
 
     if (mw->matrix.row_labels[row][0] != '\0')
 	xbaeDrawString(mw, win, gc,
-		       mw->matrix.row_labels[row],
-		       strlen(mw->matrix.row_labels[row]),
-		       TEXT_X_OFFSET(mw) + VERT_SB_OFFSET(mw), y,
-		       mw->matrix.row_label_width,
-		       mw->matrix.row_label_alignment, False,
-		       mw->matrix.bold_labels, True, False,
-		       mw->matrix.row_label_color);
+		mw->matrix.row_labels[row],
+		strlen(mw->matrix.row_labels[row]),
+		TEXT_X_OFFSET(mw) + VERT_SB_OFFSET(mw), y,
+		mw->matrix.row_label_width,	/* width clip */
+		-1,				/* height clip */
+		mw->matrix.row_label_alignment, False,
+		mw->matrix.bold_labels, True, False,
+		mw->matrix.row_label_color);
     
     if (button)
 	xbaeDrawCellShadow(mw, win, row, -1, VERT_SB_OFFSET(mw),
