@@ -1,6 +1,8 @@
 /*
  * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
  * Copyright(c) 1995-99 Andrew Lister
+ * Copyright (c) 1999-2000 by the LessTif Developers.
+ *
  *                        All rights reserved
  * Permission to use, copy, modify and distribute this material for
  * any purpose and without fee is hereby granted, provided that the
@@ -20,7 +22,7 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: ScrollMgr.c,v 1.7 2000/03/28 21:44:11 danny Exp $
+ * $Id: ScrollMgr.c,v 1.14 2000/06/11 17:58:50 danny Exp $
  */
 
 /*
@@ -177,23 +179,29 @@ xbaeSmScrollEvent(SmScrollMgr scrollMgr, XEvent *event)
     {
 
     case Expose:
-
 	/*
 	 * Normal Expose event, translate it into our scrolled
 	 * coordinate system.
 	 */
+#ifdef XBAE_VERBOSE
+	fprintf(stderr, "xbaeSmScrollEvent: Expose\n");
+#endif
+
 	event->xexpose.x += scrollMgr->offset_x;
 	event->xexpose.y += scrollMgr->offset_y;
 	break;
 
     case GraphicsExpose:
-
 	/*
 	 * If we are not scrolling, then this must be the first
 	 * GraphicsExpose event.  Remove the corresponding scroll from the
 	 * queue, and if we have more GraphicsExposes to come, set scrolling
 	 * to True.
 	 */
+#ifdef XBAE_VERBOSE
+	fprintf(stderr, "xbaeSmScrollEvent: GraphicsExpose\n");
+#endif
+
 	if (scrollMgr->scrolling == False)
 	{
 	    xbaeSmRemoveScroll(scrollMgr);
@@ -248,7 +256,7 @@ xbaeScrollVertCB(Widget w, XtPointer client_data, XmScrollBarCallbackStruct *cal
     int trailing_fixed_column_width = TRAILING_FIXED_COLUMN_WIDTH(mw);
     int row_label_width = ROW_LABEL_WIDTH(mw);
     int fixed_row_label_offset = FIXED_ROW_LABEL_OFFSET(mw);
-    
+
     /*
      * Not managed yet
      */
@@ -258,16 +266,24 @@ xbaeScrollVertCB(Widget w, XtPointer client_data, XmScrollBarCallbackStruct *cal
     /*
      * Didn't scroll
      */
-    if (call_data->value == VERT_ORIGIN(mw))
+    if (call_data->value == VERT_ORIGIN(mw)) {
+#ifdef XBAE_VERBOSE
+	fprintf(stderr, "xbaeScrollVertCB: didn't scroll\n");
+#endif
 	return;
+    }
 
     /*
      * Scrolled forward. We want to copy a chunk starting at src_y up
      * to the top (dest_y=0)
      */
-    else if (call_data->value > VERT_ORIGIN(mw))
-    {
+    else if (call_data->value > VERT_ORIGIN(mw)) {
+#ifdef XBAE_VERBOSE
+	fprintf(stderr, "xbaeScrollVertCB: scrolled forward\n");
+#endif
+
 	dest_y = 0;
+				/* FIX ME */
 	src_y = (call_data->value - VERT_ORIGIN(mw)) * row_height;
 	height = ClipChild(mw)->core.height - src_y;
     }
@@ -276,8 +292,11 @@ xbaeScrollVertCB(Widget w, XtPointer client_data, XmScrollBarCallbackStruct *cal
      * Scrolled backward. We want to copy a chunk starting at the top
      * (src_y=0) down to dest_y.
      */
-    else
-    {
+    else {
+#ifdef XBAE_VERBOSE
+	fprintf(stderr, "xbaeScrollVertCB: scrolled backward\n");
+#endif
+
 	dest_y = (VERT_ORIGIN(mw) - call_data->value) * row_height;
 	src_y = 0;
 	height = ClipChild(mw)->core.height - dest_y;
@@ -524,7 +543,7 @@ xbaeScrollVertCB(Widget w, XtPointer client_data, XmScrollBarCallbackStruct *cal
 		       FILL_HORIZ_WIDTH(mw),
 		       ClipChild(mw)->core.height - height,
 		       False);
- 	
+
 	/*
 	 * Redraw the new chunk of fixed columns and row labels
 	 */
@@ -568,7 +587,7 @@ xbaeScrollHorizCB(Widget w, XtPointer client_data, XmScrollBarCallbackStruct *ca
     Boolean need_vert_fill = NEED_VERT_FILL(mw);
     Boolean has_attached_trailing_rows = HAS_ATTACHED_TRAILING_ROWS(mw);
     Boolean need_vert_dead_space_fill = NEED_VERT_DEAD_SPACE_FILL(mw);
-    
+
     /*printf("%d\n", HORIZ_ORIGIN(mw));*/
     /*
      * Didn't scroll
@@ -697,7 +716,7 @@ xbaeScrollHorizCB(Widget w, XtPointer client_data, XmScrollBarCallbackStruct *ca
 			   trailing_fixed_row_label_offset +
 			   trailing_fixed_row_height,
 			   MATRIX_HORIZ_VISIBLE_SPACE(mw), 0, False);
-	    
+
 	    if (need_vert_dead_space_fill)
 		XClearArea(XtDisplay(mw), XtWindow(mw),
 			   fixed_column_label_offset,
@@ -793,7 +812,7 @@ xbaeScrollHorizCB(Widget w, XtPointer client_data, XmScrollBarCallbackStruct *ca
 		      src_x, horiz_sb_offset,
 		      width, column_label_height,
 		      dest_x, horiz_sb_offset);
-	
+
 	/*
 	 * Copy trailing filled portion of the columns if necessary
 	 */
@@ -807,7 +826,7 @@ xbaeScrollHorizCB(Widget w, XtPointer client_data, XmScrollBarCallbackStruct *ca
 			  width, FILL_VERT_HEIGHT(mw),
 			  dest_x, trailing_fixed_row_label_offset +
 			  trailing_fixed_row_height);
-	    
+
 	    if (need_vert_dead_space_fill)
 		XCopyArea(XtDisplay(mw), XtWindow(mw), XtWindow(mw),
 			  mw->matrix.draw_gc,
@@ -815,7 +834,7 @@ xbaeScrollHorizCB(Widget w, XtPointer client_data, XmScrollBarCallbackStruct *ca
 			  width, vert_dead_space_height,
 			  dest_x, unattached_trailing_rows_offset);
 	}
-	
+
 	/*
 	 * Clear newly scrolled chunk of fixed rows on TopClip
 	 */
@@ -911,9 +930,9 @@ xbaeRedrawCells(XbaeMatrixWidget mw, Rectangle *expose)
      */
     startCol = xbaeXtoCol(mw, rect.x1 + HORIZ_ORIGIN(mw));
     endCol = xbaeXtoCol(mw, rect.x2 + HORIZ_ORIGIN(mw));
-    startRow = YtoRow(mw, rect.y1 + mw->matrix.first_row_offset) +
+    startRow = xbaeYtoRow(mw, rect.y1 + mw->matrix.first_row_offset) +
 	VERT_ORIGIN(mw);
-    endRow = YtoRow(mw, rect.y2 + mw->matrix.first_row_offset) +
+    endRow = xbaeYtoRow(mw, rect.y2 + mw->matrix.first_row_offset) +
 	VERT_ORIGIN(mw);
 
     SANITY_CHECK_ROW(mw, startRow);
@@ -944,7 +963,50 @@ xbaeRedrawCells(XbaeMatrixWidget mw, Rectangle *expose)
 	xbaeSetClipMask(mw, CLIP_NONE);
 }
 
-#if 0
+/*
+ * These used to be simple macros.
+ */
+Dimension
+xbaeMatrixFixedRowHeight(XbaeMatrixWidget mw)
+{
+#ifdef	HAVE_ROW_HEIGHTS
+	int		i;
+	Dimension	h;
+
+	if (mw->matrix.row_heights) {
+		h = 0;
+		for (i=0; i<mw->matrix.fixed_rows; i++)
+			h += mw->matrix.row_heights[i];
+	} else {
+		h = (int)mw->matrix.fixed_rows * ROW_HEIGHT(mw);
+	}
+
+	return h;
+#else
+	return (int)mw->matrix.fixed_rows * ROW_HEIGHT(mw);
+#endif
+}
+
+Dimension
+xbaeMatrixTrailingFixedRowHeight(XbaeMatrixWidget mw)
+{
+#ifdef	HAVE_ROW_HEIGHTS
+	int		i;
+	Dimension	h = 0;
+
+	if (mw->matrix.row_heights == 0)
+		return ((int)mw->matrix.trailing_fixed_rows * ROW_HEIGHT(mw));
+
+	for (i= (mw->matrix.rows - mw->matrix.trailing_fixed_rows);
+			i<mw->matrix.rows; i++)
+		h += mw->matrix.row_heights[i];
+	return h;
+#else
+	return ((int)mw->matrix.trailing_fixed_rows * ROW_HEIGHT(mw));
+#endif
+}
+
+#ifndef	HAVE_ROW_HEIGHTS
 /*
  * Redraw the row and column labels and the cells in fixed rows/columns
  * that are overlapped by the Rectangle argument.
@@ -981,14 +1043,14 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
     if (mw->matrix.rows && mw->matrix.fixed_rows && mw->matrix.row_labels)
     {
 	Rectangle rect;
-	
+
 	/*
 	 * Get the Rectangle enclosing the fixed row labels
 	 */
 	SETRECT(rect, vert_sb_offset, row_label_offset,
 		vert_sb_offset + row_label_width - 1,
 		fixed_row_label_offset - 1);
-	
+
 	/*
 	 * If the expose Rectangle overlaps, then some labels must be redrawn
 	 */
@@ -1007,9 +1069,9 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    /*
 	     * Redraw each label that was intersected
 	     */
-	    endRow = YtoRow(mw, intersect.y2 + mw->matrix.first_row_offset);
+	    endRow = xbaeYtoRow(mw, intersect.y2 + mw->matrix.first_row_offset);
 	    SANITY_CHECK_ROW(mw, endRow);
-	    for (i = YtoRow(mw, intersect.y1 + mw->matrix.first_row_offset),
+	    for (i = xbaeYtoRow(mw, intersect.y1 + mw->matrix.first_row_offset),
 		     SANITY_CHECK_ROW(mw, i);
 		 i <= endRow; i++)
 		xbaeDrawRowLabel(mw, i, False);
@@ -1050,9 +1112,9 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    /*
 	     * Redraw each label that was intersected
 	     */
-	    endRow = YtoRow(mw, intersect.y2) + TRAILING_VERT_ORIGIN(mw);
+	    endRow = xbaeYtoRow(mw, intersect.y2) + TRAILING_VERT_ORIGIN(mw);
 	    SANITY_CHECK_ROW(mw, endRow);
-	    for (i = YtoRow(mw, intersect.y1) + TRAILING_VERT_ORIGIN(mw),
+	    for (i = xbaeYtoRow(mw, intersect.y1) + TRAILING_VERT_ORIGIN(mw),
 		 SANITY_CHECK_ROW(mw, i); i <= endRow; i++)
 		xbaeDrawRowLabel(mw, i, False);
 	}
@@ -1089,7 +1151,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 
 	    /*
 	     * Translate 'intersect' to take into account any fixed rows.
-	     * This gets it back into the coord system expected by YtoRow().
+	     * This gets it back into the coord system expected by xbaeYtoRow().
 	     */
 	    intersect.y1 += FIXED_ROW_HEIGHT(mw);
 	    intersect.y2 += FIXED_ROW_HEIGHT(mw);
@@ -1097,9 +1159,9 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    /*
 	     * Redraw each label that was intersected
 	     */
-	    endRow = YtoRow(mw, intersect.y2) + VERT_ORIGIN(mw);
+	    endRow = xbaeYtoRow(mw, intersect.y2) + VERT_ORIGIN(mw);
 	    SANITY_CHECK_ROW(mw, endRow);
-	    for (i = YtoRow(mw, intersect.y1) + VERT_ORIGIN(mw),
+	    for (i = xbaeYtoRow(mw, intersect.y1) + VERT_ORIGIN(mw),
 		 SANITY_CHECK_ROW(mw, i); i <= endRow;	 i++)
 		xbaeDrawRowLabel(mw, i, False);
 	}
@@ -1281,11 +1343,11 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    startCol = xbaeXtoCol(mw, intersect.x1 + HORIZ_ORIGIN(mw));
 	    endCol = xbaeXtoCol(mw, intersect.x2 + HORIZ_ORIGIN(mw));
 
-	    startRow = YtoRow(mw, intersect.y1) +
+	    startRow = xbaeYtoRow(mw, intersect.y1) +
 		(mw->matrix.fixed_rows
 		 ? 0
 		 : VERT_ORIGIN(mw));
-	    endRow = YtoRow(mw, intersect.y2) +
+	    endRow = xbaeYtoRow(mw, intersect.y2) +
 		(mw->matrix.fixed_rows
 		 ? 0
 		 : VERT_ORIGIN(mw));
@@ -1346,8 +1408,8 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    startCol = xbaeXtoCol(mw, intersect.x1 + HORIZ_ORIGIN(mw));
 	    endCol = xbaeXtoCol(mw, intersect.x2 + HORIZ_ORIGIN(mw));
 
-	    startRow = YtoRow(mw, intersect.y1) + TRAILING_VERT_ORIGIN(mw);
-	    endRow = YtoRow(mw, intersect.y2) + TRAILING_VERT_ORIGIN(mw);
+	    startRow = xbaeYtoRow(mw, intersect.y1) + TRAILING_VERT_ORIGIN(mw);
+	    endRow = xbaeYtoRow(mw, intersect.y2) + TRAILING_VERT_ORIGIN(mw);
 
 	    /*
 	     * Redraw each cell that was intersected
@@ -1449,16 +1511,16 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 			     ? 0
 			     : HORIZ_ORIGIN(mw)));
 
-	    startRow = redrawFixedRows ? 0 : YtoRow(mw, intersect.y1) +
+	    startRow = redrawFixedRows ? 0 : xbaeYtoRow(mw, intersect.y1) +
 		VERT_ORIGIN(mw);
 	    if (redrawTrailingFixedRows)
 	    {
-		skipRow = YtoRow(mw, intersect.y2) + VERT_ORIGIN(mw) -
+		skipRow = xbaeYtoRow(mw, intersect.y2) + VERT_ORIGIN(mw) -
 		    mw->matrix.trailing_fixed_rows + 1;
 		endRow = mw->matrix.rows - 1;
 	    }
 	    else
-		endRow = YtoRow(mw, intersect.y2) + VERT_ORIGIN(mw);
+		endRow = xbaeYtoRow(mw, intersect.y2) + VERT_ORIGIN(mw);
 
 	    /*
 	     * Redraw each cell that was intersected
@@ -1587,17 +1649,17 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    startCol = xbaeXtoTrailingCol(mw, intersect.x1);
 	    endCol = xbaeXtoTrailingCol(mw, intersect.x2);
 
-	    startRow = redrawFixedRows ? 0 : YtoRow(mw, intersect.y1) +
+	    startRow = redrawFixedRows ? 0 : xbaeYtoRow(mw, intersect.y1) +
 		VERT_ORIGIN(mw);
 
 	    if (redrawTrailingFixedRows)
 	    {
-		skipRow = YtoRow(mw, intersect.y2) + VERT_ORIGIN(mw) -
+		skipRow = xbaeYtoRow(mw, intersect.y2) + VERT_ORIGIN(mw) -
 		    mw->matrix.trailing_fixed_rows + 1;
 		endRow = mw->matrix.rows - 1;
 	    }
 	    else
-		endRow = YtoRow(mw, intersect.y2) + VERT_ORIGIN(mw);
+		endRow = xbaeYtoRow(mw, intersect.y2) + VERT_ORIGIN(mw);
 
 	    /*
 	     * Redraw each cell that was intersected
@@ -1620,7 +1682,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 		    if (redrawTrailingFixedRows && (i == skipRow) &&
 			(endRow > skipRow))
 			i = TRAILING_VERT_ORIGIN(mw);
-		    
+
 		    /*
 		     * If we need to clip the vertical fill
 		     */
@@ -1664,11 +1726,11 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	{
 	    width = mw->core.width - row_label_width -
 		VERT_SB_SPACE(mw);
-	    
+
 	    height = mw->core.height - column_label_height -
 		HORIZ_SB_SPACE(mw) ;
 	}
-	
+
 	DRAW_SHADOW(XtDisplay(mw), XtWindow(mw), "win",
 		    mw->manager.top_shadow_GC,
 		    mw->manager.bottom_shadow_GC,
@@ -1715,17 +1777,16 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
     /*
      * Handle the row labels that are in fixed rows
      */
-    if (mw->matrix.rows && mw->matrix.fixed_rows && mw->matrix.row_labels)
-    {
+    if (mw->matrix.rows && mw->matrix.fixed_rows && mw->matrix.row_labels) {
 	Rectangle rect;
-	
+
 	/*
 	 * Get the Rectangle enclosing the fixed row labels
 	 */
 	SETRECT(rect, vert_sb_offset, row_label_offset,
 		vert_sb_offset + row_label_width - 1,
 		fixed_row_label_offset - 1);
-	
+
 	/*
 	 * If the expose Rectangle overlaps, then some labels must be redrawn
 	 */
@@ -1744,9 +1805,9 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    /*
 	     * Redraw each label that was intersected
 	     */
-	    endRow = YtoRow(mw, intersect.y2 + mw->matrix.first_row_offset);
+	    endRow = xbaeYtoRow(mw, intersect.y2 + mw->matrix.first_row_offset);
 	    SANITY_CHECK_ROW(mw, endRow);
-	    for (i = YtoRow(mw, intersect.y1 + mw->matrix.first_row_offset),
+	    for (i = xbaeYtoRow(mw, intersect.y1 + mw->matrix.first_row_offset),
 		     SANITY_CHECK_ROW(mw, i);
 		 i <= endRow; i++)
 		xbaeDrawRowLabel(mw, i, False);
@@ -1757,8 +1818,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
      * Handle the row labels that are in trailing fixed rows
      */
     if (mw->matrix.rows && mw->matrix.trailing_fixed_rows &&
-	mw->matrix.row_labels)
-    {
+	mw->matrix.row_labels) {
 	Rectangle rect;
 
 	/*
@@ -1787,9 +1847,9 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    /*
 	     * Redraw each label that was intersected
 	     */
-	    endRow = YtoRow(mw, intersect.y2) + TRAILING_VERT_ORIGIN(mw);
+	    endRow = xbaeYtoRow(mw, intersect.y2) + TRAILING_VERT_ORIGIN(mw);
 	    SANITY_CHECK_ROW(mw, endRow);
-	    for (i = YtoRow(mw, intersect.y1) + TRAILING_VERT_ORIGIN(mw),
+	    for (i = xbaeYtoRow(mw, intersect.y1) + TRAILING_VERT_ORIGIN(mw),
 		 SANITY_CHECK_ROW(mw, i); i <= endRow; i++)
 		xbaeDrawRowLabel(mw, i, False);
 	}
@@ -1798,8 +1858,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
     /*
      * Handle row labels that aren't in fixed rows
      */
-    if (mw->matrix.row_labels && mw->matrix.rows)
-    {
+    if (mw->matrix.row_labels && mw->matrix.rows) {
 	Rectangle rect;
 
 	/*
@@ -1826,7 +1885,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 
 	    /*
 	     * Translate 'intersect' to take into account any fixed rows.
-	     * This gets it back into the coord system expected by YtoRow().
+	     * This gets it back into the coord system expected by xbaeYtoRow().
 	     */
 	    intersect.y1 += FIXED_ROW_HEIGHT(mw);
 	    intersect.y2 += FIXED_ROW_HEIGHT(mw);
@@ -1834,10 +1893,10 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    /*
 	     * Redraw each label that was intersected
 	     */
-	    endRow = YtoRow(mw, intersect.y2) + VERT_ORIGIN(mw);
+	    endRow = xbaeYtoRow(mw, intersect.y2) + VERT_ORIGIN(mw);
 	    SANITY_CHECK_ROW(mw, endRow);
-	    for (i = YtoRow(mw, intersect.y1) + VERT_ORIGIN(mw),
-		 SANITY_CHECK_ROW(mw, i); i <= endRow;	 i++)
+	    for (i = xbaeYtoRow(mw, intersect.y1) + VERT_ORIGIN(mw),
+			 SANITY_CHECK_ROW(mw, i); i <= endRow;	 i++)
 		xbaeDrawRowLabel(mw, i, False);
 	}
     }
@@ -1924,7 +1983,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    endCol = xbaeXtoTrailingCol(mw, intersect.x2);
 	    SANITY_CHECK_COLUMN(mw, endCol);
 	    for (i = xbaeXtoTrailingCol(mw, intersect.x1),
-		 SANITY_CHECK_COLUMN(mw, i); i <= endCol; i++)
+			SANITY_CHECK_COLUMN(mw, i); i <= endCol; i++)
 		xbaeDrawColumnLabel(mw, i, False);
 	}
     }
@@ -1934,7 +1993,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
      */
     if (mw->matrix.column_labels && mw->matrix.columns)
     {
-	Rectangle rect;
+	Rectangle rect, corrected_expose;
 
 	/*
 	 * Get the Rectangle enclosing the non-fixed column labels
@@ -1944,10 +2003,18 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 		fixed_column_label_offset + VISIBLE_WIDTH(mw) - 1,
 		horiz_sb_offset + column_label_height - 1);
 
+	/*
+	 * "untransform" the y component of the expose rectangle
+	 * column headings have transfomed x coordinates but original y coordinates
+	 */
+	SETRECT(corrected_expose,
+		expose->x1, expose->y1 - mw->matrix.matrix_scroll_mgr->offset_y,
+		expose->x2, expose->y2 - mw->matrix.matrix_scroll_mgr->offset_y);
+
 	/*
 	 * If the expose Rectangle overlaps, then some labels must be redrawn
 	 */
-	if (OVERLAP(*expose, rect))
+	if (OVERLAP(corrected_expose, rect))
 	{
 	    Rectangle intersect;
 	    int endCol, i;
@@ -1957,7 +2024,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	     * Rectangle along the X axis.  The resulting Rectangle will
 	     * be in 'rect's coordinate system.
 	     */
-	    X_INTERSECT(rect, *expose, intersect);
+	    X_INTERSECT(rect, corrected_expose, intersect);
 
 	    /*
 	     * Translate 'intersect' to take into account any fixed columns.
@@ -1972,7 +2039,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    endCol = xbaeXtoCol(mw, intersect.x2 + HORIZ_ORIGIN(mw));
 	    SANITY_CHECK_COLUMN(mw, endCol);
 	    for (i = xbaeXtoCol(mw, intersect.x1 + HORIZ_ORIGIN(mw)),
-		 SANITY_CHECK_COLUMN(mw, i); i <= endCol; i++)
+			SANITY_CHECK_COLUMN(mw, i); i <= endCol; i++)
 		xbaeDrawColumnLabel(mw, i, False);
 	}
     }
@@ -2018,11 +2085,11 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    startCol = xbaeXtoCol(mw, intersect.x1 + HORIZ_ORIGIN(mw));
 	    endCol = xbaeXtoCol(mw, intersect.x2 + HORIZ_ORIGIN(mw));
 
-	    startRow = YtoRow(mw, intersect.y1) +
+	    startRow = xbaeYtoRow(mw, intersect.y1) +
 		(mw->matrix.fixed_rows
 		 ? 0
 		 : VERT_ORIGIN(mw));
-	    endRow = YtoRow(mw, intersect.y2) +
+	    endRow = xbaeYtoRow(mw, intersect.y2) +
 		(mw->matrix.fixed_rows
 		 ? 0
 		 : VERT_ORIGIN(mw));
@@ -2083,8 +2150,8 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    startCol = xbaeXtoCol(mw, intersect.x1 + HORIZ_ORIGIN(mw));
 	    endCol = xbaeXtoCol(mw, intersect.x2 + HORIZ_ORIGIN(mw));
 
-	    startRow = YtoRow(mw, intersect.y1) + TRAILING_VERT_ORIGIN(mw);
-	    endRow = YtoRow(mw, intersect.y2) + TRAILING_VERT_ORIGIN(mw);
+	    startRow = xbaeYtoRow(mw, intersect.y1) + TRAILING_VERT_ORIGIN(mw);
+	    endRow = xbaeYtoRow(mw, intersect.y2) + TRAILING_VERT_ORIGIN(mw);
 
 	    /*
 	     * Redraw each cell that was intersected
@@ -2186,16 +2253,16 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 			     ? 0
 			     : HORIZ_ORIGIN(mw)));
 
-	    startRow = redrawFixedRows ? 0 : YtoRow(mw, intersect.y1) +
+	    startRow = redrawFixedRows ? 0 : xbaeYtoRow(mw, intersect.y1) +
 		VERT_ORIGIN(mw);
 	    if (redrawTrailingFixedRows)
 	    {
-		skipRow = YtoRow(mw, intersect.y2) + VERT_ORIGIN(mw) -
+		skipRow = xbaeYtoRow(mw, intersect.y2) + VERT_ORIGIN(mw) -
 		    mw->matrix.trailing_fixed_rows + 1;
 		endRow = mw->matrix.rows - 1;
 	    }
 	    else
-		endRow = YtoRow(mw, intersect.y2) + VERT_ORIGIN(mw);
+		endRow = xbaeYtoRow(mw, intersect.y2) + VERT_ORIGIN(mw);
 
 	    /*
 	     * Redraw each cell that was intersected
@@ -2324,17 +2391,17 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	    startCol = xbaeXtoTrailingCol(mw, intersect.x1);
 	    endCol = xbaeXtoTrailingCol(mw, intersect.x2);
 
-	    startRow = redrawFixedRows ? 0 : YtoRow(mw, intersect.y1) +
+	    startRow = redrawFixedRows ? 0 : xbaeYtoRow(mw, intersect.y1) +
 		VERT_ORIGIN(mw);
 
 	    if (redrawTrailingFixedRows)
 	    {
-		skipRow = YtoRow(mw, intersect.y2) + VERT_ORIGIN(mw) -
+		skipRow = xbaeYtoRow(mw, intersect.y2) + VERT_ORIGIN(mw) -
 		    mw->matrix.trailing_fixed_rows + 1;
 		endRow = mw->matrix.rows - 1;
 	    }
 	    else
-		endRow = YtoRow(mw, intersect.y2) + VERT_ORIGIN(mw);
+		endRow = xbaeYtoRow(mw, intersect.y2) + VERT_ORIGIN(mw);
 
 	    /*
 	     * Redraw each cell that was intersected
@@ -2357,7 +2424,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 		    if (redrawTrailingFixedRows && (i == skipRow) &&
 			(endRow > skipRow))
 			i = TRAILING_VERT_ORIGIN(mw);
-		    
+
 		    /*
 		     * If we need to clip the vertical fill
 		     */
@@ -2379,6 +2446,7 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	}
     }
 
+	/* Danny Here */
     /*
      * Draw a shadow just inside row/column labels and around outer edge
      * of clip widget.	We can't use height of clip widget because it is
@@ -2401,11 +2469,11 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
 	{
 	    width = mw->core.width - row_label_width -
 		VERT_SB_SPACE(mw);
-	    
+
 	    height = mw->core.height - column_label_height -
 		HORIZ_SB_SPACE(mw) ;
 	}
-	
+
 	DRAW_SHADOW(XtDisplay(mw), XtWindow(mw), "win",
 		    mw->manager.top_shadow_GC,
 		    mw->manager.bottom_shadow_GC,
@@ -2416,3 +2484,135 @@ xbaeRedrawLabelsAndFixed(XbaeMatrixWidget mw, Rectangle *expose)
     }
 }
 #endif
+/*
+ * Subject: Xbae matrix - column headers not redrawn - a proposed fix
+ *    Date: Tue, 11 Apr 2000 16:48:31 +0200
+ *    From: Andrew Hately <andrew.hately@eurocontrol.be>
+ *      To: Danny Backx <danny@gnu.org>, xbae <xbae@lists.frogdream.com>
+ * 
+ * 
+ * 
+ * 
+ * You may remember I described a problem where column headers are not redrawn.
+ * I reproduced the problem, run HP's version of mwm or their vuewm, but not
+ * lesstif's mwm, using a binary compiled with HP's X11R5 and Motif 1.2
+ * To reproduce the problem, give the matrix column labels and a vertical
+ * scrollbar; the visible window whould be less than half the total scrollable
+ * height. With the scrollbar at the top, obscure the top half of the matrix
+ * using another (shell) window. Now click in the lower part of the scrollbar -
+ * in one action bringing the matrix window completely into view _and_ jump
+ * scrolling downward. The column headings are not redrawn.
+ * 
+ * I have made the problem go away by the following change to ScrollMgr.c, in
+ * the function xbaeRedrawLabelsAndFixed
+ * 
+ * About a quarter of the way through this large routine is a piece of code to
+ * redraw column labels over "unfixed" columns.
+ * 
+ * Here is my changed version of it. I introduce the variable
+ * "corrected_expose":
+ * 
+ * 
+ * 
+ * 
+ * 
+ * 
+ *     **
+ *      * Handle column labels that aren't in fixed columns
+ *      **
+ *     if (mw->matrix.column_labels && mw->matrix.columns)
+ *     {
+ *         Rectangle rect;
+ *         Rectangle corrected_expose;
+ * 
+ *         **
+ *          * Get the Rectangle enclosing the non-fixed column labels
+ *          **
+ *         SETRECT(rect,
+ *                 fixed_column_label_offset, horiz_sb_offset,
+ *                 fixed_column_label_offset + VISIBLE_WIDTH(mw) - 1,
+ *                 horiz_sb_offset + column_label_height - 1);
+ * 
+ *         **
+ *          * "untransform" the y component of the expose rectangle
+ *          * column headings have transfomed x coordinates but original y coordinates
+ *          **
+ *         SETRECT( corrected_expose,
+ *                  expose->x1, expose->y1 - mw->matrix.matrix_scroll_mgr->offset_y,
+ *                  expose->x2, expose->y2 - mw->matrix.matrix_scroll_mgr->offset_y );
+ * 
+ *         **
+ *          * If the expose Rectangle overlaps, then some labels must be redrawn
+ *          **
+ *         if (OVERLAP( corrected_expose, rect))
+ *         {
+ *             Rectangle intersect;
+ *             int endCol, i;
+ * 
+ *             **
+ *              * Intersect the non-fixed-column-labels Rectangle with the expose
+ *              * Rectangle along the X axis.  The resulting Rectangle will
+ *              * be in 'rect's coordinate system.
+ *              **
+ *             X_INTERSECT(rect, corrected_expose, intersect);
+ * 
+ *             **
+ *              * Translate 'intersect' to take into account any fixed columns.
+ *              * This gets it back into the coord system expected by XtoCol().
+ *              **
+ *             intersect.x1 += fixed_column_width;
+ *             intersect.x2 += fixed_column_width;
+ * 
+ *             **
+ *              * Redraw each label that was intersected
+ *              **
+ *             endCol = xbaeXtoCol(mw, intersect.x2 + HORIZ_ORIGIN(mw));
+ *             SANITY_CHECK_COLUMN(mw, endCol);
+ *             for (i = xbaeXtoCol(mw, intersect.x1 + HORIZ_ORIGIN(mw)),
+ *                  SANITY_CHECK_COLUMN(mw, i); i <= endCol; i++)
+ *                 xbaeDrawColumnLabel(mw, i, False);
+ *         }
+ *     }
+ * 
+ * 
+ * 
+ * 
+ * 
+ * 
+ * 
+ * 
+ * 
+ * My change seems to address the problem that the Expose event is transformed
+ * into "scroll manager" coordinates before it is applied. The column and row
+ * labels need only one of the two coordinates transformed (I believe) - x for
+ * column labels and y for row labels. (Can anyone confirm this?) If I'm right,
+ * the fix should be applied generally to the six similar sections of this
+ * function.
+ * 
+ * My investigations on Lesstif builds both on hpux and linux indicate that the
+ * problem does not appear there. As far as I can tell, with Lesstif's mwm, the
+ * column heading expose seems to take effect before the scroll manager has
+ * consumed the scroll events; hence mw->matrix.matrix_scroll_mgr->offset_y is
+ * zero when xbaeSmScrollEvent is called and the headings are redrawn
+ * correctly.
+ * 
+ * (Thanks to Chuck Ocharet at Thinkbank for a description of the Panhandler
+ * which helped me work out what was going on.)
+ * 
+ * I sent this to the list incase any of you can confirm this 1) behaviour 2)
+ * fix
+ * and to Danny Backx incase you do.
+ * 
+ * regards
+ * Andrew
+ * 
+ * -- 
+ * mailto://ah@9000.org 
+ * http://counter.li.org/cgi-bin/runscript/display-person.cgi?user=45690
+ * 
+ * ---------------------------------------------------------------------
+ * To unsubscribe, e-mail: xbae-unsubscribe@lists.frogdream.com
+ * For additional commands, e-mail: xbae-help@lists.frogdream.com
+ * 
+ * 
+ */ 
