@@ -1,7 +1,7 @@
 #define	LARGE_PAGE
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Notebook.c,v 1.27 2000/01/25 23:56:27 amai Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Notebook.c,v 1.28 2000/08/08 22:21:13 danny Exp $
  *
  * Copyright (C) 1997-1998 Free Software Foundation, Inc.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Notebook.c,v 1.27 2000/01/25 23:56:27 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Notebook.c,v 1.28 2000/08/08 22:21:13 danny Exp $";
 
 
 /*
@@ -58,7 +58,7 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Noteboo
 #include <XmI/DebugUtil.h>
 
 #include <Xm/NotebookP.h>
-#include <XmI/XmXpm.h>
+#include <Xm/Xpm.h>
 
 /*
  * Traits used by Notebook
@@ -1622,12 +1622,12 @@ _XmNBDefaultLastPageNumber(Widget w, int offset, XrmValue *val)
 static void
 _XmNBCreateSpiralPixmap(Widget w)
 {
-	_LtXpmAttributes   attrib; 
+	XpmAttributes   attrib; 
         Pixmap          mask;
 
 	attrib.valuemask = 0;
 
-	_LtXpmCreatePixmapFromData(XtDisplay(w),
+	XpmCreatePixmapFromData(XtDisplay(w),
                 XRootWindowOfScreen(XtScreen(w)),
                 spiral,
                 &NB_SpiralPixmap(w),
