@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Xme.c,v 1.13 2000/04/30 22:38:32 amai Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Xme.c,v 1.15 2000/08/15 11:13:01 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Xme.c,v 1.13 2000/04/30 22:38:32 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Xme.c,v 1.15 2000/08/15 11:13:01 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -40,6 +40,11 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Xme.c,v
 #include <Xm/VendorSEP.h>
 #include <XmI/MessagesI.h>
 
+/* required prototypes: */
+extern void _XtAddCallback(XtCallbackList *, XtCallbackProc, XtPointer);
+extern void _XtRemoveCallback(XtCallbackList *, XtCallbackProc, XtPointer);
+
+
 /* DragIcon */
 Widget
 XmeGetTextualDragIcon(Widget w)
@@ -212,7 +217,10 @@ XmeGetDefaultDisplay(void)
 void 
 XmeAddFocusChangeCallback(Widget w, XtCallbackProc cp, XtPointer udata)
 {
-    XmWidgetExtData extData;
+    XmBaseClassExt *bce;
+    XtPointer nsec;
+    Widget desktopParent;
+    int size;
 
     if(!XmIsVendorShell(w))
     {
@@ -220,20 +228,35 @@ XmeAddFocusChangeCallback(Widget w, XtCallbackProc cp, XtPointer udata)
         return;
     }
 
-    extData = _XmGetWidgetExtData(w, XmSHELL_EXTENSION);
-    if (extData == NULL)
-    {
-        XmeWarning(w, "Can not find Vendor Shell Extention Data.");
-        return;
-    }
+    bce = _XmGetBaseClassExtPtr(XtClass(w), XmQmotif);
+    size = (*bce)->secondaryObjectClass->core_class.widget_size;
+    nsec = XtCalloc(1, size);
 
-    XtAddCallback(extData->widget, XmNfocusMovedCallback, cp, udata);
+    ((XmExtRec *)nsec)->object.self = (Widget)nsec;
+    ((XmExtRec *)nsec)->object.widget_class = (*bce)->secondaryObjectClass;
+    ((XmExtRec *)nsec)->object.parent = w;
+    ((XmExtRec *)nsec)->object.xrm_name = w->core.xrm_name;
+    ((XmExtRec *)nsec)->object.being_destroyed = False;
+    ((XmExtRec *)nsec)->object.destroy_callbacks = NULL;
+    ((XmExtRec *)nsec)->object.constraints = NULL;
+
+    ExtObj_LogicalParent(nsec) = w;
+    ExtObj_ExtensionType(nsec) = XmSHELL_EXTENSION;
+
+    Desktop_Parent(nsec) = desktopParent;
+
+    _XtAddCallback(&VSEP_FocusMovedCallback(nsec),
+		   cp, udata);
+    XtFree((char *)nsec);
 }
 
 void
 XmeRemoveFocusChangeCallback(Widget w, XtCallbackProc cp, XtPointer udata)
 {
-    XmWidgetExtData extData;
+    XmBaseClassExt *bce;
+    XtPointer nsec;
+    Widget desktopParent;
+    int size;
 
     if(!XmIsVendorShell(w))
     {
@@ -241,14 +264,26 @@ XmeRemoveFocusChangeCallback(Widget w, XtCallbackProc cp, XtPointer udata)
         return;
     }
 
-    extData = _XmGetWidgetExtData(w, XmSHELL_EXTENSION);
-    if (extData == NULL)
-    {
-        XmeWarning(w, "Can not find Vendor Shell Extention Data.");
-        return;
-    }
+    bce = _XmGetBaseClassExtPtr(XtClass(w), XmQmotif);
+    size = (*bce)->secondaryObjectClass->core_class.widget_size;
+    nsec = XtCalloc(1, size);
 
-    XtRemoveCallback(extData->widget, XmNfocusMovedCallback, cp, udata);
+    ((XmExtRec *)nsec)->object.self = (Widget)nsec;
+    ((XmExtRec *)nsec)->object.widget_class = (*bce)->secondaryObjectClass;
+    ((XmExtRec *)nsec)->object.parent = w;
+    ((XmExtRec *)nsec)->object.xrm_name = w->core.xrm_name;
+    ((XmExtRec *)nsec)->object.being_destroyed = False;
+    ((XmExtRec *)nsec)->object.destroy_callbacks = NULL;
+    ((XmExtRec *)nsec)->object.constraints = NULL;
+
+    ExtObj_LogicalParent(nsec) = w;
+    ExtObj_ExtensionType(nsec) = XmSHELL_EXTENSION;
+
+    Desktop_Parent(nsec) = desktopParent;
+
+    _XtRemoveCallback(&VSEP_FocusMovedCallback(nsec),
+                      cp, udata);
+    XtFree((char *)nsec);
 }
 
 /* Visual */
@@ -317,5 +352,28 @@ XmeGetHomeDirName(void)
 XmFontList
 XmeGetDefaultRenderTable(Widget w, unsigned int fontListType)
 {
-	return NULL;
+	return (XmFontList)NULL;
+}
+
+/* "online" references e.g. on
+   http://vireo.gatech.edu/ebt-bin/nph-dweb/dynaweb/SGI_Developer/Motif21_WG/@Generic__BookTextView/35630;td=2;cs=fullhtml;pt=4;lang=de#X
+*/
+/* Transfer */
+Atom
+*XmeStandardTargets(Widget w,
+                    int count,
+		    int *count_return)
+{
+ _XmWarning(NULL, "XmeStandardTargets(): not yet implemented!");
+ return (Atom *)NULL;
+}
+
+
+/* Transfer */
+void 
+XmeStandardConvert(Widget w,
+                        XtPointer ignore,
+			XmConvertCallbackStruct *call_data)
+{
+ _XmWarning(NULL, "XmeStandardConvert(): not yet implemented!");
 }
