@@ -1,8 +1,9 @@
 /**
  *
- * $Id: BaseClass.c,v 1.10 1998/09/12 15:05:18 rwscott Exp $
+ * $Id: BaseClass.c,v 1.17 2000/08/29 15:04:51 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: BaseClass.c,v 1.10 1998/09/12 15:05:18 rwscott Exp $";
+static const char rcsid[] = "$Id: BaseClass.c,v 1.17 2000/08/29 15:04:51 amai Exp $";
 
 #include <LTconfig.h>
 #include <XmI/XmI.h>
@@ -37,6 +38,7 @@ static const char rcsid[] = "$Id: BaseClass.c,v 1.10 1998/09/12 15:05:18 rwscott
 #include <Xm/DropTransP.h>
 #include <Xm/VendorSEP.h>
 #include <Xm/DropSMgrP.h>
+#include <Xm/DialogS.h>
 
 #include <X11/RectObjP.h>
 #include <X11/Xutil.h>
@@ -47,6 +49,11 @@ static const char rcsid[] = "$Id: BaseClass.c,v 1.10 1998/09/12 15:05:18 rwscott
 
 #include <stdio.h>
 
+/* For the prototype police */
+
+extern XmWrapperData	_XmGetWrapperData(WidgetClass wc);
+extern void		_XmFreeWrapperData(XmWrapperData data);
+
 XrmQuark XmQmotif = 0;
 int _XmInheritClass;
 XmBaseClassExt *_Xm_fastPtr;
@@ -198,7 +205,7 @@ XmWidgetExtDataStackRec, *XmWidgetExtDataStackPtr;
 /*
  * associate a context with an extension type.
  */
-XContext extContexts[XmDEFAULT_EXTENSION + 1] = { 0 };
+static XContext extContexts[XmDEFAULT_EXTENSION + 1] = { 0 };
 
 static XContext
 FindAssociatedContext(unsigned int extType)
@@ -370,8 +377,11 @@ _XmFreeWrapperData(XmWrapperData data)
  * no-one outside this module should be allowed to call them. They are
  * considered private and no-one outside this module should ever need
  * them. --aldi
+ *
+ * I made Push and Pop static, but left Get and Free global, after testing
+ * linkage with M*tif.
  */
-XmWrapperData
+static XmWrapperData
 _XmPushWrapperData(WidgetClass wc)
 {
     XmBaseClassExt *ext, bce;
@@ -444,7 +454,7 @@ _XmPushWrapperData(WidgetClass wc)
  * loud and clear: the wrapper is removen from the list but the memory
  * isn't freed.
  */
-XmWrapperData
+static XmWrapperData
 _XmPopWrapperData(WidgetClass wc)
 {
     XmBaseClassExt *ext;
@@ -1193,7 +1203,8 @@ RealizeWrapper(Widget w, XtValueMask *ValueMask,
 
     ext = _XmGetWidgetExtData(w, XmSHELL_EXTENSION);
 
-    if (ext != NULL && ext->widget != NULL)
+/*    if (ext != NULL && ext->widget != NULL && !XmIsDialogShell(w)) */
+    if (ext != NULL && ext->widget != NULL && wc != xmDialogShellWidgetClass)
     {
 	/*
 	 * Check for a callback list to be executed (the only exception
@@ -1869,11 +1880,11 @@ _XmTransformSubResources(XtResourceList comp_resources,
 	for (i = 0; i < num_comp_resources; i++)
 	{
 	    res[i].resource_name
-		= XrmQuarkToString((XrmQuark)comp_resources[i].resource_name);
+		= XrmQuarkToString((XrmQuark)(long)comp_resources[i].resource_name);
 	    res[i].resource_class
-		= XrmQuarkToString((XrmQuark)comp_resources[i].resource_class);
+		= XrmQuarkToString((XrmQuark)(long)comp_resources[i].resource_class);
 	    res[i].resource_type
-		= XrmQuarkToString((XrmQuark)comp_resources[i].resource_type);
+		= XrmQuarkToString((XrmQuark)(long)comp_resources[i].resource_type);
 	    /* MLM: sigh.  For want of a nail...  I coulda saved myself days if
 	     * I'da done this in the first place */
 	    res[i].resource_size
@@ -1881,7 +1892,7 @@ _XmTransformSubResources(XtResourceList comp_resources,
 	    res[i].resource_offset
 		= -((int)comp_resources[i].resource_offset + 1);
 	    res[i].default_type
-		= XrmQuarkToString((XrmQuark)comp_resources[i].default_type);
+		= XrmQuarkToString((XrmQuark)(long)comp_resources[i].default_type);
 	    res[i].default_addr
 		= comp_resources[i].default_addr;
 	}
@@ -1904,6 +1915,10 @@ XmGetSecondaryResourceData(WidgetClass w_class,
 {
     XmBaseClassExt *bce = NULL;
 
+    DEBUGOUT(XdbDebug(__FILE__, NULL,
+		      "XmGetSecondaryResourceData() called on %s.\n",
+		      w_class->core_class.class_name));
+
     bce = _XmGetBaseClassExtPtr(w_class, XmQmotif);
 
     if (!bce || !*bce)
