@@ -1,6 +1,6 @@
 /**
  *
- * $Id: BulletinBoard.c,v 1.50 2000/01/10 13:35:08 rwscott Exp $
+ * $Id: BulletinBoard.c,v 1.52 2000/07/25 08:44:11 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: BulletinBoard.c,v 1.50 2000/01/10 13:35:08 rwscott Exp $";
+static const char rcsid[] = "$Id: BulletinBoard.c,v 1.52 2000/07/25 08:44:11 amai Exp $";
 
 #include <LTconfig.h>
 #include <XmI/XmI.h>
@@ -39,6 +39,7 @@ static const char rcsid[] = "$Id: BulletinBoard.c,v 1.50 2000/01/10 13:35:08 rws
 #include <Xm/PushB.h>
 #include <Xm/PushBG.h>
 #include <Xm/MwmUtil.h>
+#include <Xm/VendorSEP.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -556,8 +557,12 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 
 	if ((ve = _LtFindVendorExt(new_w)) != NULL)
 	{
-	    XtAddCallback(ve, XmNfocusMovedCallback,
-			bbclass->bulletin_board_class.focus_moved_proc, new_w);
+    	    extern void _XtAddCallback(XtCallbackList *,
+				       XtCallbackProc, XtPointer);
+
+	    _XtAddCallback(&VSEP_FocusMovedCallback(ve),
+			   bbclass->bulletin_board_class.focus_moved_proc,
+                           new_w);
 	}
     }
 
@@ -577,12 +582,18 @@ destroy(Widget w)
     DEBUGOUT(XdbDebug("RWS", w,"%s:destroy(%d)\n",
     	__FILE__, __LINE__
     	));
+
+    if (BB_DialogTitle(w))
+        XmStringFree(BB_DialogTitle(w));
     XmFontListFree(BB_LabelFontList(w));
     XmFontListFree(BB_ButtonFontList(w));
     XmFontListFree(BB_TextFontList(w));
     if ((ve = _LtFindVendorExt(w)) != NULL)
       {
+	_XtRemoveAllCallbacks(&VSEP_FocusMovedCallback(ve));
+	/* mitch
 	XtRemoveAllCallbacks(ve,XmNfocusMovedCallback);
+	*/
       }
     
 
@@ -651,6 +662,11 @@ set_values(Widget old,
 		BB_DialogTitle(new_w) = XmStringCopy(BB_DialogTitle(new_w));
 	    }
 
+            XmStringFree(BB_DialogTitle(old));
+        }
+        else if (BB_DialogTitle(old) != BB_DialogTitle(new_w))
+        {
+            BB_DialogTitle(new_w) = XmStringCopy(BB_DialogTitle(new_w));
 	    XmStringFree(BB_DialogTitle(old));
 	}
 
