@@ -1,6 +1,6 @@
 /**
  *
- * $Id: CutPaste.c,v 1.7 1998/09/12 15:05:19 rwscott Exp $
+ * $Id: CutPaste.c,v 1.11 2000/07/07 00:50:30 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: CutPaste.c,v 1.7 1998/09/12 15:05:19 rwscott Exp $";
+static const char rcsid[] = "$Id: CutPaste.c,v 1.11 2000/07/07 00:50:30 rwscott Exp $";
 
 #include <LTconfig.h>
 #include <XmI/XmI.h>
@@ -153,6 +153,12 @@ static Window _XmClipboardInitializeSelection(Display *display,
 
 static Boolean _XmClipboardWeOwnSelection(Display *display, XmClipboard * clip);
 
+/* And one external function for the prototype police */
+
+extern int XmClipboardWithdrawFormat(Display *display, Window window,
+				     int data_id);
+
+
 
 /******************************* low level ******************************/
 
@@ -559,7 +565,7 @@ _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
     *data = NULL;
     *len = 0;
 
-    ret_buf = (unsigned *)XtMalloc(8);
+    ret_buf = (unsigned *)XtMalloc(8); /* minimum size */
     ret_buf[0] = 0;
     offset = 0;
     alloc_size = 0;
@@ -588,6 +594,9 @@ _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
 
 	    XtFree((char *)ret_buf);
 
+	    DEBUGOUT(XdbDebug(__FILE__, NULL,
+		"_XmClipboardGetWindowProperty: XmClipboardFail (alloc_size %d)\n",
+			alloc_size));
 	    return XmClipboardFail;
 	}
 
@@ -651,6 +660,9 @@ _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
 	*type_return = actual_type;
     }
 
+    DEBUGOUT(XdbDebug(__FILE__, NULL,
+	"_XmClipboardGetWindowProperty: XmClipboardSuccess (alloc_size %d)\n",
+		alloc_size));
     return XmClipboardSuccess;
 }
 
@@ -1633,7 +1645,7 @@ _XmClipboardLock(Display *display, Window window)
 
     if (!len)
     {
-	lock = (XmClipboardLockRec *) XtMalloc(sizeof(unsigned) * 2);
+	lock = (XmClipboardLockRec *) XtMalloc(sizeof(XmClipboardLockRec));
 	lock->lockowner = None;
 	lock->lockdepth = 0;
     }
@@ -1707,7 +1719,8 @@ _XmClipboardLock(Display *display, Window window)
 	}
     }
 
-    _XmClipboardReplaceItem(display, XmCLIP_LOCK, (unsigned *)lock, 8,
+    _XmClipboardReplaceItem(display, XmCLIP_LOCK, (unsigned *)lock,
+			    sizeof(XmClipboardLockRec),
 			    PropModeReplace, 32, False);
 
     _XmClipboardSetAccess(display, window);
@@ -1760,7 +1773,7 @@ _XmClipboardUnlock(Display *display, Window window, Boolean remove_all_locks)
 
     if (lock->lockdepth > UNLOCKED)
     {
-	len = 8;
+	len = sizeof(XmClipboardLockRec);
     }
     else
     {
@@ -2386,7 +2399,7 @@ XmClipboardInquireCount(Display *display,
 	    return XmClipboardFail;
 	}
 
-	/* FIX ME */
+	/* FIX ME:  This is supposed to be the ICCCM way */
     }
 
     if (max_length != NULL)
@@ -2461,7 +2474,7 @@ XmClipboardInquireFormat(Display *display,
 	    return XmClipboardFail;
 	}
 
-	/* FIX ME */
+	/* FIX ME: This is supposed to be the ICCCM way of things */
     }
 
     if (name)
