@@ -1,6 +1,6 @@
 /**
  *
- * $Id: DebugUtil.c,v 1.46 2000/04/30 22:38:21 amai Exp $
+ * $Id: DebugUtil.c,v 1.47 2000/08/04 18:20:31 amai Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DebugUtil.c,v 1.46 2000/04/30 22:38:21 amai Exp $";
+static const char rcsid[] = "$Id: DebugUtil.c,v 1.47 2000/08/04 18:20:31 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -206,16 +206,12 @@ XdbComboBoxType2String(unsigned char type)
     {
     case XmDROP_DOWN_LIST:
     	return("XmDROP_DOWN_LIST");
-	break;
     case XmDROP_DOWN_COMBO_BOX:
     	return("XmDROP_DOWN_COMBO_BOX");
-	break;
     case XmCOMBO_BOX:
     	return("XmCOMBO_BOX");
-	break;
     default:
 	return("UNKNOWN");
-	break;
     }
 }
 #endif
@@ -227,19 +223,14 @@ XdbGeoAction2String(int action)
 	{
 	case XmGET_ACTUAL_SIZE:
 		return("XmGET_ACTUAL_SIZE");
-		break;
 	case XmGET_PREFERRED_SIZE:
 		return("XmGET_PREFERRED_SIZE");
-		break;
 	case XmGEO_PRE_SET:
 		return("XmGEO_PRE_SET");
-		break;
 	case XmGEO_POST_SET:
 		return("XmGEO_POST_SET");
-		break;
 	default:
 		return("Unknown geo action");
-		break;
 	}
 }
 
@@ -632,16 +623,12 @@ XdbMenuFocusOp2String(int f)
     {
     case XmMENU_FOCUS_SAVE:
     	return ("XmMENU_FOCUS_SAVE");
-    	break;
     case XmMENU_FOCUS_RESTORE:
     	return ("XmMENU_FOCUS_RESTORE");
-    	break;
     case XmMENU_FOCUS_SET:
     	return ("XmMENU_FOCUS_SET");
-    	break;
     default:
     	return("Unknown focus op");
-    	break;
     }
 }
 
@@ -729,7 +716,7 @@ XdbXmString2String(XmString xms)
   static char *s = NULL;
 
     if (s) {
-      free(s);
+      XtFree(s);
       s=NULL;
     }
     if (xms == (XmString)XmUNSPECIFIED)
