@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Desktop.c,v 1.5 1998/09/12 15:05:21 rwscott Exp $
+ * $Id: Desktop.c,v 1.7 2000/08/29 15:04:52 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,15 +22,17 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Desktop.c,v 1.5 1998/09/12 15:05:21 rwscott Exp $";
+static const char rcsid[] = "$Id: Desktop.c,v 1.7 2000/08/29 15:04:52 amai Exp $";
 
 #include <LTconfig.h>
+
+#include <string.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
 #include <Xm/ExtObjectP.h>
 #include <Xm/DesktopP.h>
-#include <string.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -244,7 +246,10 @@ initialize(Widget request, Widget new_w,
     }
     else
     {
+	/* rws 19 Jul 2000
+	   So, is this a problem????
 	_XmError(new_w, "Desktop initialize: I have no desktopParent");
+	*/
     }
 }
 
@@ -280,7 +285,10 @@ destroy(Widget w)
     }
     else
     {
+	/* rws 19 Jul 2000
+	   So, is this a problem????
 	_XmError(w, "Desktop destroy: I have no desktopParent");
+	*/
     }
 
     XtFree((char *)Desktop_Children(w));
