@@ -1,6 +1,6 @@
 /**
  *
- * $Id: DialogS.c,v 1.22 1999/09/28 21:45:14 danny Exp $
+ * $Id: DialogS.c,v 1.23 2000/07/07 00:50:31 rwscott Exp $
  *
  * derived from Xt Vendor class.c 
  *
@@ -25,7 +25,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DialogS.c,v 1.22 1999/09/28 21:45:14 danny Exp $";
+static const char rcsid[] = "$Id: DialogS.c,v 1.23 2000/07/07 00:50:31 rwscott Exp $";
 
 #include <stdio.h>
 
@@ -250,7 +250,49 @@ WidgetClass xmDialogShellExtObjectClass = (WidgetClass)&xmDialogShellExtClassRec
 static void 
 class_initialize(void)
 {
+    int ncom, i, j, addon;
+    XtResourceList combined, shells;
+    Cardinal nshells;
+
     _XmDialogSCoreClassExtRec.record_type = XmQmotif;
+
+    ncom = XtNumber(ext_resources) +
+                xmVendorShellExtClassRec.object_class.num_resources;
+
+    _XmTransformSubResources(xmVendorShellExtClassRec.object_class.resources,
+                             xmVendorShellExtClassRec.object_class.
+				num_resources,
+                             &shells, &nshells);
+
+    combined = (XtResourceList)XtMalloc(sizeof(XtResource) * ncom);
+
+    bcopy(shells, combined, nshells * sizeof(XtResource));
+
+    /* can't just copy.  We know we need to drop one */
+    for (i = 0, addon = 0; i < XtNumber(ext_resources); i++)
+    {
+	for (j = 0; j < nshells; j++)
+	{
+	    if (strcmp(combined[j].resource_name,
+		       ext_resources[i].resource_name) == 0)
+	    {
+		combined[j] = ext_resources[i];
+		break;
+	    }
+	}
+
+	if (j != nshells)
+	{
+	    combined[nshells + addon] = ext_resources[i];
+	    addon++;
+	}
+    }
+
+    XtFree((XtPointer)shells);
+
+    xmDialogShellExtClassRec.object_class.resources = combined;
+    xmDialogShellExtClassRec.object_class.num_resources = nshells + addon;
+
 }
 
 static void 
