@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Display.c,v 1.13 1998/09/12 15:05:21 rwscott Exp $
+ * $Id: Display.c,v 1.17 2000/08/29 15:04:52 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,9 +22,10 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Display.c,v 1.13 1998/09/12 15:05:21 rwscott Exp $";
+static const char rcsid[] = "$Id: Display.c,v 1.17 2000/08/29 15:04:52 amai Exp $";
 
 #include <LTconfig.h>
+
 #include <XmI/XmI.h>
 #include <XmI/MacrosI.h>
 #include <XmI/AtomMgrI.h>
@@ -76,7 +77,7 @@ static XtResource resources[] =
     }
 };
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -85,7 +86,7 @@ static void initialize(Widget request, Widget new_w,
 
 static void destroy(Widget w);
 
-#if 0
+#if 1
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
 #endif
@@ -148,23 +149,23 @@ XmDisplayClassRec xmDisplayClassRec = {
 	/* class_part_initialize */ class_part_initialize,
 	/* class_inited          */ False,
 	/* initialize            */ initialize,
-	/* initialize_hook       */ NULL,
+	/* initialize_hook       */ NULL, /* Motif has one */
 	/* realize               */ XtInheritRealize,
-	/* actions               */ NULL /*actions*/,
-	/* num_actions           */ 0 /*XtNumber(actions)*/,
+	/* actions               */ NULL,
+	/* num_actions           */ 0,
 	/* resources             */ resources,
 	/* num_resources         */ XtNumber(resources),
 	/* xrm_class             */ NULLQUARK,
-	/* compress_motion       */ False /*True*/,
-	/* compress_exposure     */ XtExposeNoCompress /*XtExposeCompressMultiple*/,
-	/* compress_enterleave   */ False /*True*/,
+	/* compress_motion       */ False,
+	/* compress_exposure     */ XtExposeNoCompress,
+	/* compress_enterleave   */ False,
 	/* visible_interest      */ False,
 	/* destroy               */ destroy,
 	/* resize                */ NULL,
 	/* expose                */ NULL,
-	/* set_values            */ NULL /*set_values*/,
+	/* set_values            */ set_values, /* Motif doesn't have this */
 	/* set_values_hook       */ NULL,
-	/* set_values_almost     */ NULL /*XtInheritSetValuesAlmost*/,
+	/* set_values_almost     */ NULL,
 	/* get_values_hook       */ NULL,
 	/* accept_focus          */ NULL,
 	/* version               */ XtVersion,
@@ -178,8 +179,8 @@ XmDisplayClassRec xmDisplayClassRec = {
     {
 	/* geometry manager */ NULL,
         /* change_managed   */ NULL,
-        /* insert_child     */ XtInheritInsertChild,
-        /* delete_child     */ XtInheritDeleteChild,
+        /* insert_child     */ XtInheritInsertChild, /* Motif has one */
+        /* delete_child     */ XtInheritDeleteChild, /* Motif has one */
         /* extension        */ NULL,	
     },
     /* Shell class part */
@@ -271,7 +272,7 @@ _XmAddCloseConnectionCallback(Widget w, XtCallbackProc callback)
  * The widget class methods...
  */
 static void
-class_initialize()
+class_initialize(void)
 {
     _XmDisplayCoreClassExtRec.record_type = XmQmotif;
 }
@@ -306,7 +307,17 @@ initialize(Widget request, Widget new_w,
     XPointer FirstDisplayWidget;
     XmDisplay dpy = (XmDisplay)new_w;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "XmDisplay initialize\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
+		      "%s:initialize(%d) - %i args\n"
+		      "\trequest X %5i Y %5i W %5i H %5i\n"
+		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
+		      __FILE__, __LINE__,
+		      *num_args,
+		      XtX(request), XtY(request),
+		      XtWidth(request), XtHeight(request),
+		      XtX(new_w), XtY(new_w),
+		      XtWidth(new_w), XtHeight(new_w)));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     dpy->display.shellCount = 0;
     dpy->display.numModals = 0;
@@ -404,7 +415,7 @@ destroy(Widget w)
     _XmFlushAtomsForDisplay(XtDisplay(w));
 }
 
-#if 0
+#if 1
 /*
  * There is almost nothing dto do -- yet.
  */
@@ -412,6 +423,21 @@ static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
+		      "%s:set_values(%d) - %i args\n"
+		      "\t    old X %5i Y %5i W %5i H %5i\n"
+		      "\trequest X %5i Y %5i W %5i H %5i\n"
+		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
+		      __FILE__, __LINE__,
+		      *num_args,
+		      XtX(old), XtY(old),
+		      XtWidth(old), XtHeight(old),
+		      XtX(request), XtY(request),
+		      XtWidth(request), XtHeight(request),
+		      XtX(new_w), XtY(new_w),
+		      XtWidth(new_w), XtHeight(new_w)));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+
     return False;
 }
 #endif
@@ -502,17 +528,34 @@ _XmGetDropSiteManagerObject(XmDisplay xmDisplay)
 {
     XmDropSiteManagerObject dsm = NULL;
 
-    if (Display_DSM(xmDisplay) == NULL)
+    DEBUGOUT(XdbDebug(__FILE__, (Widget)xmDisplay, "%s:_XmGetDropSiteManagerObject(%d) - %s 0x%p\n",
+    	__FILE__, __LINE__,
+    	Display_DSM(xmDisplay) ? "Old" : "New", Display_DSM(xmDisplay)));
+    if (!XmIsDisplay(xmDisplay))
     {
-	dsm = (XmDropSiteManagerObject)XtCreateWidget("DropSiteManager",
-				       Display_DropSiteManagerClass(xmDisplay),
-						   (Widget)xmDisplay, NULL, 0);
-
-	Display_DSM(xmDisplay) = dsm;
+    	_XmWarning((Widget)xmDisplay, "%s:_XmGetDropSiteManagerObject(%d) called without an XmDisplay",
+    		__FILE__, __LINE__);
     }
     else
     {
-	dsm = Display_DSM(xmDisplay);
+	if (Display_DSM(xmDisplay) == NULL)
+	{
+	    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmGetDropSiteManagerObject(%d) - creating\n",
+		__FILE__, __LINE__
+		));
+	    dsm = (XmDropSiteManagerObject)XtCreateWidget("DropSiteManager",
+					   Display_DropSiteManagerClass(xmDisplay),
+						       (Widget)xmDisplay, NULL, 0);
+	    DEBUGOUT(XdbDebug2(__FILE__, (Widget)xmDisplay, (Widget)dsm, "%s:_XmGetDropSiteManagerObject(%d) - created 0x%p\n",
+		__FILE__, __LINE__, dsm
+		));
+
+	    Display_DSM(xmDisplay) = dsm;
+	}
+	else
+	{
+	    dsm = Display_DSM(xmDisplay);
+	}
     }
 
     return dsm;
@@ -523,6 +566,8 @@ _XmGetDragProtocolStyle(Widget w)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(w));
 
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmGetDragProtocolStyle(%d)\n",
+    	__FILE__, __LINE__));
     switch (Display_DragReceiverProtocolStyle(disp))
     {
     case XmDRAG_NONE:
@@ -550,6 +595,8 @@ _XmGetDragProtocolStyle(Widget w)
 unsigned char
 _XmGetDragTrackingMode(Widget w)
 {
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmGetDragTrackingMode(%d)\n",
+    	__FILE__, __LINE__));
     return 0;
 }
 
@@ -559,6 +606,8 @@ _XmGetDragContextFromHandle(Widget w, Atom iccHandle)
     Widget disp = XmGetXmDisplay(XtDisplay(w)), dc;
     int i;
 
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmGetDragContextFromHandle(%d)\n",
+    	__FILE__, __LINE__));
     for (i = 0; i < MGR_NumChildren(disp); i++)
     {
 
@@ -586,6 +635,8 @@ _XmGetXmDisplayClass(void)
 {
     if (__XmDisplayClass == NULL)
     {
+	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmGetXmDisplayClass(%d)\n",
+	    __FILE__, __LINE__));
 	__XmDisplayClass = (WidgetClass)&xmDisplayClassRec;
     }
 
@@ -603,6 +654,8 @@ _XmSetXmDisplayClass(WidgetClass wc)
 {
     WidgetClass OldDisplayClass, SuperClass;
 
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmSetXmDisplayClass(%d)\n",
+    	__FILE__, __LINE__));
     OldDisplayClass = __XmDisplayClass;
     SuperClass = wc;
 
@@ -631,6 +684,8 @@ XmGetDragContext(Widget w, Time time)
     Widget disp = XmGetXmDisplay(XtDisplay(w)), dc = NULL;
     int i;
 
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:XmGetDragContext(%d)\n",
+    	__FILE__, __LINE__));
     for (i = 0; i < MGR_NumChildren(disp); i++)
     {
 	if (XmIsDragContext(MGR_Children(disp)[i]))
