@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DragBS.c,v 1.22 2000/04/30 22:38:22 amai Exp $
+ * $Id: DragBS.c,v 1.25 2000/08/21 15:54:37 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DragBS.c,v 1.22 2000/04/30 22:38:22 amai Exp $";
+static const char rcsid[] = "$Id: DragBS.c,v 1.25 2000/08/21 15:54:37 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -355,9 +356,10 @@ end_protection(Display *display)
  */
 short
 _XmReadDragBuffer(XmDndBufMgr bmgr, Boolean read_string,
-		  char *retbuf, short size)
+		  char *retbuf, short bufsize)
 {
     int rsize, eaten;
+    short size;
 
     DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmReadDragBuffer(%d) - read_string %s size %i\n",
 		      __FILE__, __LINE__,
@@ -367,35 +369,31 @@ _XmReadDragBuffer(XmDndBufMgr bmgr, Boolean read_string,
     if (read_string)
     {
 	rsize = bmgr->name_size;
-
 	eaten = bmgr->name_start - bmgr->names;
-
 	if (rsize <= eaten)
 	{
-	    size = eaten - rsize;
-	}
-
+		size = eaten - rsize;
+		if (size > bufsize)
+			size = bufsize;
+	} else
+		size = bufsize;
 	bcopy(bmgr->name_start, retbuf, size);
-
 	bmgr->name_start += size;
-
 	return size;
     }
     else
     {
 	rsize = bmgr->atom_size;
-
 	eaten = bmgr->atom_start - bmgr->atoms;
-
 	if (rsize <= eaten)
 	{
-	    size = eaten - rsize;
-	}
-
+		size = eaten - rsize;
+		if (size > bufsize)
+			size = bufsize;
+	} else
+		size = bufsize;
 	bcopy(bmgr->atom_start, retbuf, size);
-
 	bmgr->atom_start += size;
-
 	return size;
     }
 }
@@ -416,7 +414,7 @@ _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
 
     if (write_string)
     {
-	increase_needed = (bmgr->name_size + size) > bmgr->name_avail;
+	increase_needed = (bmgr->name_size + size) - bmgr->name_avail;
 	if (increase_needed > 0)
 	{
 	    increase_needed /= 1000;
@@ -427,7 +425,6 @@ _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
 	    if (bmgr->names == bmgr->name_ptr)
 	    {
 		bmgr->names = XtMalloc(bmgr->name_avail);
-
 		bcopy(bmgr->name_ptr, bmgr->names, bmgr->name_size);
 	    }
 	    else
@@ -437,14 +434,13 @@ _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
 	}
 
 	bcopy(data, bmgr->names + bmgr->name_size, size);
-
 	bmgr->name_size += size;
 
 	return size;
     }
     else
     {
-	increase_needed = (bmgr->atom_size + size) > bmgr->atom_avail;
+	increase_needed = (bmgr->atom_size + size) - bmgr->atom_avail;
 	if (increase_needed)
 	{
 	    increase_needed /= 1000;
@@ -454,7 +450,6 @@ _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
 	    if (bmgr->atoms == bmgr->atom_ptr)
 	    {
 		bmgr->atoms = XtMalloc(bmgr->atom_avail);
-
 		bcopy(bmgr->atom_ptr, bmgr->atoms, bmgr->atom_size);
 	    }
 	    else
@@ -464,7 +459,6 @@ _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
 	}
 
 	bcopy(data, bmgr->atoms + bmgr->atom_size, size);
-
 	bmgr->atom_size += size;
 
 	return size;
@@ -508,6 +502,7 @@ read_atom_pairs(Display *display)
 		      __FILE__, __LINE__));
 
 	gotit = True;
+	prop = (unsigned char *)pairs;
     }
 
     end_protection(display);
@@ -1134,6 +1129,10 @@ read_targets_table(Display *display, XmDndTargetsTable tbl)
     DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_targets_table(%d) - True %p\n",
 		      __FILE__, __LINE__, tbl));
 
+    if (targets)
+     {
+         XFree((XPointer)targets);
+     }
     return True;
 }
 
@@ -1879,4 +1878,3 @@ _XmByteOrder(void)
 
     return byte_order;
 }
-
