@@ -1,6 +1,6 @@
 /**
  *
- * $Id: DragC.c,v 1.27 2000/04/18 01:58:02 rwscott Exp $
+ * $Id: DragC.c,v 1.29 2000/08/29 15:04:52 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -40,7 +40,7 @@
  * provided "as is" without express or implied warranty.
  */
 
-static const char rcsid[] = "$Id: DragC.c,v 1.27 2000/04/18 01:58:02 rwscott Exp $";
+static const char rcsid[] = "$Id: DragC.c,v 1.29 2000/08/29 15:04:52 amai Exp $";
 
 #include <LTconfig.h>
 #include <XmI/XmI.h>
@@ -53,6 +53,7 @@ static const char rcsid[] = "$Id: DragC.c,v 1.27 2000/04/18 01:58:02 rwscott Exp
 #include <Xm/DisplayP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/MenuUtilP.h>	/* for the _XmGrab stuff */
+
 #include <X11/Xfuncs.h>
 
 #include <XmI/DebugUtil.h>
@@ -421,7 +422,11 @@ initialize(Widget request, Widget new_w,
     DC_OrigDragOver(new_w) = NULL;
 
     /* setup the notify cb */
+#if 0
     dsm = _XmGetDropSiteManagerObject(_XmDCtoDD(new_w));
+#else
+    dsm = _XmGetDropSiteManagerObject((XmDisplay)XmGetXmDisplay(XtDisplay(new_w)));
+#endif
     XtSetArg(argl[0], XmNclientData, (XtPointer)new_w);
     if (DC_SourceIsExternal(new_w))
     {
@@ -453,7 +458,10 @@ initialize(Widget request, Widget new_w,
     DC_NumReceiverInfos(new_w) = 0;
     DC_MaxReceiverInfos(new_w) = 0;
 
-    XtRealizeWidget(new_w);
+    if (XtIsRealized(XtParent(new_w)))
+    {
+	XtRealizeWidget(new_w);
+    }
 
     DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "Initialize: Parent %s window 0x%X us 0x%X\n",
