@@ -1,6 +1,6 @@
 /**
  *
- * $Id: DrawnB.c,v 1.29 1998/10/24 22:28:36 rwscott Exp $
+ * $Id: DrawnB.c,v 1.41 2000/03/17 17:48:49 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,13 +22,14 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DrawnB.c,v 1.29 1998/10/24 22:28:36 rwscott Exp $";
+static const char rcsid[] = "$Id: DrawnB.c,v 1.41 2000/03/17 17:48:49 danny Exp $";
 
 #include <LTconfig.h>
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
 #include <Xm/DrawnBP.h>
+#include <Xm/RepType.h>
 #include <Xm/TransltnsP.h>
 
 #include <XmI/DebugUtil.h>
@@ -45,14 +46,14 @@ static const char rcsid[] = "$Id: DrawnB.c,v 1.29 1998/10/24 22:28:36 rwscott Ex
 void _XmDrawnB_TraitAddCallback(Widget, XtCallbackProc, XtPointer, Boolean);
 
 static XmActivatableTraitRec _XmDrawnBTraitRec = {
-        /* version      */      0,
-        /* cb           */      _XmDrawnB_TraitAddCallback
+	/* version      */      0,
+	/* cb           */      _XmDrawnB_TraitAddCallback
 };
 #endif
 
 /* Forward Declarations */
 #if XmVERSION > 1
-static void class_initialize();
+static void class_initialize(void);
 #endif
 static void class_part_initialize(WidgetClass w_class);
 
@@ -122,7 +123,7 @@ static XtResource resources[] =
     {
 	XmNshadowThickness, XmCShadowThickness, XmRHorizontalDimension,
 	sizeof(Dimension), XtOffsetOf(XmDrawnButtonRec, primitive.shadow_thickness),
-	XmRCallProc, (XtPointer)_XmPrimitiveShadowThicknessDefault
+	XmRImmediate, (XtPointer)2
     },
     {
 	XmNlabelString, XmCXmString, XmRXmString,
@@ -137,7 +138,7 @@ static XtResource resources[] =
     {
 	XmNhighlightThickness, XmCHighlightThickness, XmRHorizontalDimension,
 	sizeof(Dimension), XtOffsetOf(XmDrawnButtonRec, primitive.highlight_thickness),
-	XmRCallProc, (XtPointer)_XmPrimitiveHighlightThicknessDefault
+	XmRImmediate, (XtPointer)2
     }
 };
 
@@ -192,7 +193,7 @@ XmDrawnButtonClassRec xmDrawnButtonClassRec = {
     /* Core class part */
     {
 	/* superclass            */ (WidgetClass) &xmLabelClassRec,
-        /* class_name            */ "XmDrawnButton",
+	/* class_name            */ "XmDrawnButton",
 	/* widget_size           */ sizeof(XmDrawnButtonRec),
 #if XmVERSION > 1
 	/* class_initialize      */ class_initialize,
@@ -231,18 +232,18 @@ XmDrawnButtonClassRec xmDrawnButtonClassRec = {
     /* Primitive Class part */
     {
 	/* border_highlight      */ XmInheritBorderHighlight,
-       	/* border_unhighlight    */ XmInheritBorderUnhighlight,
-       	/* translations          */ XtInheritTranslations,
-       	/* arm_and_activate_proc */ ArmAndActivate,
-       	/* Synthetic Resources   */ NULL, 
-        /* num syn res           */ 0,
+	/* border_unhighlight    */ XmInheritBorderUnhighlight,
+	/* translations          */ XtInheritTranslations,
+	/* arm_and_activate_proc */ ArmAndActivate,
+	/* Synthetic Resources   */ NULL,
+	/* num syn res           */ 0,
 	/* extension             */ (XtPointer)&_XmDrawnBPrimClassExtRec
     },
     /* Label Class part */
     {
-        /* setOverrideCallback */ XmInheritSetOverrideCallback,
-        /* menuProcs           */ NULL,
-        /* translations        */ NULL,
+	/* setOverrideCallback */ XmInheritSetOverrideCallback,
+	/* menuProcs           */ NULL,
+	/* translations        */ NULL,
 	/* extension           */ NULL
     },
     /* DrawnButton Class part */
@@ -256,12 +257,12 @@ WidgetClass xmDrawnButtonWidgetClass = (WidgetClass)&xmDrawnButtonClassRec;
 
 #if XmVERSION > 1
 static void
-class_initialize()
+class_initialize(void)
 {
     if (! XmeTraitSet(xmDrawnButtonWidgetClass, XmQTactivatable,
-                &_XmDrawnBTraitRec)) {
-        _XmWarning(NULL,
-            "XmDrawnButton ClassInitialize: XmeTraitSet failed\n");
+		&_XmDrawnBTraitRec)) {
+	_XmWarning(NULL,
+	    "XmDrawnButton ClassInitialize: XmeTraitSet failed\n");
     }
 }
 #endif
@@ -287,21 +288,13 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(new_w), XtHeight(new_w)));
     DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
-    if (!Lab_Font(new_w))
-    {
-	Lab_Font(new_w) = _XmGetDefaultFontList(new_w,
-						XmBUTTON_FONTLIST);
-    }
-
-    if (Lab_Label(new_w))
-    {
-    XmString tmp;
-
-	_XmStringFree(Lab_Label(new_w));
-	tmp = XmStringCreateSimple("\0");
-	Lab_Label(new_w) = _XmStringCreate(tmp);
-	XmStringFree(tmp);
-    }
+    /* check the RepType resources */
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmRMultiClick),
+			     DB_MultiClick(new_w), new_w))
+	DB_MultiClick(new_w) = XmMULTICLICK_KEEP;
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmRShadowType),
+			     DB_ShadowType(new_w), new_w))
+	DB_ShadowType(new_w) = XmSHADOW_ETCHED_IN;
 
     DB_Armed(new_w) = False;
     DB_Timer(new_w) = 0;
@@ -313,6 +306,7 @@ destroy(Widget w)
     if (DB_Timer(w) != 0)
     {
 	XtRemoveTimeOut(DB_Timer(w));
+	DB_Timer(w) = 0;
     }
 }
 
@@ -323,8 +317,9 @@ realize(Widget w,
 {
     /* this is about the only reason I can think of why DrawnB should want
      * a realize */
-    *value_mask |= CWBackingStore;
+    *value_mask |= CWBackingStore | CWBitGravity;
     attributes->backing_store = NotUseful;
+    attributes->bit_gravity = ForgetGravity;
 
 #define superclass (&xmPrimitiveClassRec)
     (*superclass->core_class.realize) (w, value_mask, attributes);
@@ -335,7 +330,7 @@ static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    Boolean refresh_needed = True;
+    Boolean refresh_needed = False;
 
     DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
@@ -351,22 +346,36 @@ set_values(Widget old, Widget request, Widget new_w,
 		      XtWidth(new_w), XtHeight(new_w)));
     DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
+    /* check the RepType resources */
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmRMultiClick),
+			     DB_MultiClick(new_w), new_w))
+	DB_MultiClick(new_w) = DB_MultiClick(old);
+    if (!XmRepTypeValidValue(XmRepTypeGetId(XmRShadowType),
+			     DB_ShadowType(new_w), new_w))
+	DB_ShadowType(new_w) = DB_ShadowType(old);
+
+    if (DB_ShadowType(old) != DB_ShadowType(new_w))
+    {
+	refresh_needed = True;
+    }
+
     /* rws 23 Jul 1997
        Label will have polluted the height and width since it will not
        be able to determine the correct size, since it does not know what
-       is in the window!  Therefore if the size has changed use the 
+       is in the window!  Therefore if the size has changed use the
        requested size.
        xdir top right hand logo button
+       JHG: If there's something identifiable in the button, trust Label.
+       rws 11 Sep 1999
+       Don't trust Label. Take a look at drawnbutton/test9
      */
-    if (XtHeight(old) != XtHeight(new_w))
+    if (/* !Lab_TextRect_height(new_w) && */
+	(XtWidth(new_w) != XtWidth(request) ||
+	 XtHeight(new_w) != XtHeight(request)))
     {
-    	XtHeight(new_w) = XtHeight(request);
-    	refresh_needed = True;
-    }
-    if (XtWidth(old) != XtWidth(new_w))
-    {
-    	XtWidth(new_w) = XtWidth(request);
-    	refresh_needed = True;
+	XtWidth(new_w) = XtWidth(request);
+	XtHeight(new_w) = XtHeight(request);
+	refresh_needed = True;
     }
     return refresh_needed;
 }
@@ -379,12 +388,10 @@ expose(Widget w, XEvent *event, Region region)
     DEBUGOUT(XdbDebug(__FILE__, w, "Expose (%dx%d%+d%+d)\n",
 		      XtWidth(w), XtHeight(w),XtX(w),XtY(w)));
 
-/*
 #define superclass (&xmLabelClassRec)
     (*superclass->core_class.expose) (w, event, region);
 #undef superclass
-*/
-#if 1
+#if 0
     /* rws 24 Oct 1998
        mfm clipboard pixmap
      */
@@ -417,28 +424,17 @@ expose(Widget w, XEvent *event, Region region)
     }
 #endif
 
-    if (DB_PushButtonEnabled(w))
-    {
-	_XmDrawShadows(XtDisplay(w), XtWindow(w),
-		       Prim_TopShadowGC(w),
-		       Prim_BottomShadowGC(w),
-		       Prim_HighlightThickness(w), Prim_HighlightThickness(w),
-		       XtWidth(w) - 2 * Prim_HighlightThickness(w),
-		       XtHeight(w) - 2 * Prim_HighlightThickness(w),
-		       Prim_ShadowThickness(w),
-		 (XtSensitive(w) && DB_Armed(w)) ? XmSHADOW_IN : XmSHADOW_OUT);
-    }
-    else
-    {
-	_XmDrawShadows(XtDisplay(w), XtWindow(w),
-		       Prim_TopShadowGC(w),
-		       Prim_BottomShadowGC(w),
-		       Prim_HighlightThickness(w), Prim_HighlightThickness(w),
-		       XtWidth(w) - 2 * Prim_HighlightThickness(w),
-		       XtHeight(w) - 2 * Prim_HighlightThickness(w),
-		       Prim_ShadowThickness(w),
-		       DB_ShadowType(w));
-    }
+    _XmDrawShadows(XtDisplay(w), XtWindow(w),
+		   Prim_TopShadowGC(w), Prim_BottomShadowGC(w),
+		   Prim_HighlightThickness(w), Prim_HighlightThickness(w),
+		   XtWidth(w) - (Prim_HighlightThickness(w) << 1),
+		   XtHeight(w) - (Prim_HighlightThickness(w) << 1),
+		   Prim_ShadowThickness(w),
+		   DB_PushButtonEnabled(w)
+		   ? XtSensitive(w) && DB_Armed(w)
+		     ? XmSHADOW_IN
+		     : XmSHADOW_OUT
+		   : DB_ShadowType(w));
 
     if (DB_ExposeCallback(w))
     {
@@ -463,37 +459,11 @@ resize(Widget w)
     DEBUGOUT(XdbDebug(__FILE__, w, "Resize (%dx%d%+d%+d)\n",
 		      XtWidth(w), XtHeight(w),XtX(w),XtY(w)));
 
-    if (!XtIsRealized(w))
-    {
-	return;
-    }
+#define superclass (&xmLabelClassRec)
+    (*superclass->core_class.resize) (w);
+#undef superclass
 
-/*
-    if (DB_PushButtonEnabled(w))
-    {
-	_XmDrawShadows(XtDisplay(w), XtWindow(w),
-		       Prim_TopShadowGC(w),
-		       Prim_BottomShadowGC(w),
-		       Prim_HighlightThickness(w), Prim_HighlightThickness(w),
-		       XtWidth(w) - 2 * Prim_HighlightThickness(w),
-		       XtHeight(w) - 2 * Prim_HighlightThickness(w),
-		       Prim_ShadowThickness(w),
-		 (XtSensitive(w) && DB_Armed(w)) ? XmSHADOW_IN : XmSHADOW_OUT);
-    }
-    else
-    {
-	_XmDrawShadows(XtDisplay(w), XtWindow(w),
-		       Prim_TopShadowGC(w),
-		       Prim_BottomShadowGC(w),
-		       Prim_HighlightThickness(w), Prim_HighlightThickness(w),
-		       XtWidth(w) - 2 * Prim_HighlightThickness(w),
-		       XtHeight(w) - 2 * Prim_HighlightThickness(w),
-		       Prim_ShadowThickness(w),
-		       DB_ShadowType(w));
-    }
-*/
-
-    if (DB_ResizeCallback(w))
+    if (XtIsRealized(w) && DB_ResizeCallback(w))
     {
 	cbs.reason = XmCR_RESIZE;
 	cbs.event = NULL;
@@ -512,27 +482,31 @@ static void
 Arm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmDrawnButtonCallbackStruct cbs;
-    XtExposeProc exp;
 
     XmProcessTraversal(w, XmTRAVERSE_CURRENT);
 
-    DB_Armed(w) = True;
-
-    exp = XtClass(w)->core_class.expose;
-    (*exp) (w, event, (Region)NULL);
-
-    if (DB_ArmCallback(w))
+    if (!DB_Armed(w))
     {
-	cbs.reason = XmCR_ARM;
-	cbs.event = event;
-	cbs.window = XtWindow(w);
-	cbs.click_count = DB_ClickCount(w);
+	DB_Armed(w) = True;
+	if (event)
+	    DB_ArmTimeStamp(w) = event->xbutton.time;
 
-	XFlush(XtDisplay(w));
+	if (XtIsRealized(w))
+	    XtClass(w)->core_class.expose(w, event, NULL);
 
-	XtCallCallbackList(w,
-			   DB_ArmCallback(w),
-			   (XtPointer)&cbs);
+	if (DB_ArmCallback(w))
+	{
+	    cbs.reason = XmCR_ARM;
+	    cbs.event = event;
+	    cbs.window = XtWindow(w);
+	    cbs.click_count = DB_ClickCount(w);
+
+	    XFlush(XtDisplay(w));
+
+	    XtCallCallbackList(w,
+			       DB_ArmCallback(w),
+			       (XtPointer)&cbs);
+	}
     }
 }
 
@@ -540,27 +514,28 @@ static void
 Activate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmDrawnButtonCallbackStruct cbs;
-    XtExposeProc exp;
 
     DB_ClickCount(w) = 1;
 
     DB_Armed(w) = False;
 
-    exp = XtClass(w)->core_class.expose;
-    (*exp) (w, event, (Region)NULL);
+    if (XtIsRealized(w))
+	XtClass(w)->core_class.expose(w, event, NULL);
 
     if (event->xany.type == KeyPress || event->xany.type == KeyRelease ||
 	(event->xbutton.x >= 0 && event->xbutton.x < XtWidth(w) &&
 	 event->xbutton.y >= 0 && event->xbutton.y < XtHeight(w)))
     {
-
-	if (DB_ActivateCallback(w))
+	cbs.reason = XmCR_ACTIVATE;
+	cbs.event = event;
+	cbs.window = XtWindow(w);
+	cbs.click_count = DB_ClickCount(w);
+	if (XmIsRowColumn(XtParent(w)))
+	{
+	    RC_MenuMenuCallback(w, &cbs);
+	}
+	if (!Lab_SkipCallback(w) && DB_ActivateCallback(w))
 	{
-	    cbs.reason = XmCR_ACTIVATE;
-	    cbs.event = event;
-	    cbs.window = XtWindow(w);
-	    cbs.click_count = DB_ClickCount(w);
-
 	    XFlush(XtDisplay(w));
 
 	    XtCallCallbackList(w,
@@ -574,12 +549,12 @@ static void
 Disarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmDrawnButtonCallbackStruct cbs;
-    XtExposeProc exp;
 
     if (DB_Armed(w))
     {
-	exp = XtClass(w)->core_class.expose;
-	(*exp) (w, event, (Region)NULL);
+	DB_Armed(w) = False;
+	if (XtIsRealized(w))
+	    XtClass(w)->core_class.expose(w, event, (Region)NULL);
     }
 
     if (DB_DisarmCallback(w))
@@ -601,15 +576,14 @@ static void
 ArmTimeout(XtPointer data, XtIntervalId *id)
 {
     Widget w = (Widget)data;
-    XtExposeProc exp = XtClass(w)->core_class.expose;
 
     DEBUGOUT(XdbDebug(__FILE__, w, "ArmTimeout\n"));
- 
+
     DB_Timer(w) = 0;
 
     if (XtIsRealized(w))
     {
-	(*exp) (w, NULL, NULL);
+	XtClass(w)->core_class.expose(w, NULL, NULL);
 	XFlush(XtDisplay(w));
     }
 }
@@ -618,13 +592,12 @@ static void
 ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmDrawnButtonCallbackStruct cbs;
- 
+
     DEBUGOUT(XdbDebug(__FILE__, w, "ArmAndActivate\n"));
 
     /* Arm, Activate, and Disarm now, but draw the disarmed state later */
 
     Arm(w, event, params, num_params);
-    DB_Armed(w) = False;
     if (!Lab_SkipCallback(w) && DB_ActivateCallback(w))
     {
 	XFlush(XtDisplay(w));
@@ -636,6 +609,7 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 			   DB_ActivateCallback(w),
 			   (XtPointer)&cbs);
     }
+    DB_Armed(w) = False;
     if (DB_DisarmCallback(w))
     {
 	XFlush(XtDisplay(w));
@@ -651,6 +625,7 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     if (DB_Timer(w) != 0)
     {
 	XtRemoveTimeOut(DB_Timer(w));
+	DB_Timer(w) = 0;
     }
 
     DB_Timer(w) = XtAppAddTimeOut(XtWidgetToApplicationContext(w),
@@ -662,7 +637,8 @@ EnterWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     _XmPrimitiveEnter(w, event, NULL, NULL);
 
-    if (DB_PushButtonEnabled(w) && XtSensitive(w) && DB_Armed(w))
+    if (DB_PushButtonEnabled(w) && XtSensitive(w) && DB_Armed(w) &&
+	XtIsRealized(w))
     {
 	_XmDrawShadows(XtDisplay(w), XtWindow(w),
 		       Prim_TopShadowGC(w),
@@ -680,7 +656,8 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     _XmPrimitiveLeave(w, event, NULL, NULL);
 
-    if (DB_PushButtonEnabled(w) && XtSensitive(w) && DB_Armed(w))
+    if (DB_PushButtonEnabled(w) && XtSensitive(w) && DB_Armed(w) &&
+	XtIsRealized(w))
     {
 	_XmDrawShadows(XtDisplay(w), XtWindow(w),
 		       Prim_TopShadowGC(w),
@@ -709,7 +686,6 @@ MultiActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XButtonEvent *ev = (XButtonEvent *)event;
     XmDrawnButtonCallbackStruct cbs;
-    XtExposeProc exp;
 
     DEBUGOUT(XdbDebug(__FILE__, w, "DrawnB: MultiClick\n"));
 
@@ -728,20 +704,14 @@ MultiActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
 	DB_Armed(w) = False;
 
-	exp = XtClass(w)->core_class.expose;
-	(*exp) (w, event, NULL);
+	if (XtIsRealized(w))
+	    XtClass(w)->core_class.expose(w, event, NULL);
 
 	if (ev->type == KeyPress || ev->type == KeyRelease ||
 	    ((ev->x >= 0 && ev->x < XtWidth(w)) &&
 	     (ev->y >= 0 && ev->y < XtHeight(w))))
 	{
-	    if (DB_MultiClick(w) == XmMULTICLICK_DISCARD &&
-		DB_ClickCount(w) > 1)
-	    {
-		return;
-	    }
-
-	    if (DB_ActivateCallback(w))
+	    if (!Lab_SkipCallback(w) && DB_ActivateCallback(w))
 	    {
 		cbs.reason = XmCR_ACTIVATE;
 		cbs.event = event;
@@ -769,13 +739,13 @@ XmCreateDrawnButton(Widget parent, char *name,
 
 #if XmVERSION > 1
 void _XmDrawnB_TraitAddCallback(Widget w,
-                        XtCallbackProc cb,
-                        XtPointer cbp,
-                        Boolean set)
-{   
-        if (set)
-                XtAddCallback(w, XmNactivateCallback, cb, cbp);
-        else
-                XtRemoveCallback(w, XmNactivateCallback, cb, cbp);
-} 
+				XtCallbackProc cb,
+				XtPointer cbp,
+				Boolean set)
+{
+    if (set)
+	XtAddCallback(w, XmNactivateCallback, cb, cbp);
+    else
+	XtRemoveCallback(w, XmNactivateCallback, cb, cbp);
+}
 #endif
