@@ -1,6 +1,6 @@
 /** -*- Mode: C; tab-width: 8; indent-tabs-mode: nil -*-
  *
- * $Id: DropSMgr.c,v 1.28 2000/04/18 01:58:05 rwscott Exp $
+ * $Id: DropSMgr.c,v 1.29 2000/07/25 20:10:29 hennessy Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DropSMgr.c,v 1.28 2000/04/18 01:58:05 rwscott Exp $";
+static const char rcsid[] = "$Id: DropSMgr.c,v 1.29 2000/07/25 20:10:29 hennessy Exp $";
 
 #include <LTconfig.h>
 #include <XmI/XmI.h>
@@ -943,7 +943,7 @@ destroyInfoRec(XmDropSiteInfo dsi, Boolean thorough)
     	__FILE__, __LINE__));
 
     if (dsi->dropSiteType == XmDROP_SITE_COMPOSITE && thorough &&
-	dsi->numChildren != 0)
+	dsi->children != 0)
     {
 	XtFree((char *)dsi->children);
     }
