@@ -1,7 +1,6 @@
-#define MOZILLA
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/FileSB.c,v 1.87 2000/03/05 13:12:25 rwscott Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm/FileSB.c,v 1.89 2000/08/29 15:04:53 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
  *
@@ -23,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/FileSB.c,v 1.87 2000/03/05 13:12:25 rwscott Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/FileSB.c,v 1.89 2000/08/29 15:04:53 amai Exp $";
 
 #include <LTconfig.h>
 #include <XmI/XmI.h>
@@ -47,6 +46,12 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/FileSB.c,v
 
 #include <XmI/DebugUtil.h>
 
+
+/* #defines being used: */
+
+/* see below for more info */
+#define MOZILLA
+
 /* Forward Declarations */
 
 static void class_initialize(void);
@@ -1678,22 +1683,44 @@ geoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
 	layoutPtr->fit_mode = XmGEO_WRAP;
 	if (LabG_RecomputeSize(SB_HelpButton(_w)))
 	{
+#if 1
+	    /* rws 8 Jul 2000
+	       filesb/test6
+	     */
 	    if (SB_List(_w) && XtIsManaged(XtParent(SB_List(_w))))
 	    {
-	    layoutPtr->even_width = 6;
-	    layoutPtr->even_height = 6;
+		layoutPtr->even_width = 6;
+		layoutPtr->even_height = 6;
 	    }
 	    else
 	    {
-	    layoutPtr->even_width = 4;
-	    layoutPtr->even_height = 4;
+		layoutPtr->even_width = 4;
+		layoutPtr->even_height = 4;
 	    }
+#endif
 	}
 	else
 	{
 	    layoutPtr->even_width = 1;
 	    layoutPtr->even_height = 1;
 	}
+#if 1
+	/* rws 8 Jul 2000
+	   filesb/test15 when pressing Filter
+	 */
+	if (SB_OkButton(_w) && !LabG_RecomputeSize(SB_OkButton(_w)))
+	{
+	    layoutPtr->even_width = 1;
+	    if (XtIsRealized(_w))
+	    {
+		layoutPtr->even_height = 1;
+	    }
+	    else
+	    {
+		layoutPtr->even_height = 4;
+	    }
+	}
+#endif
 	layoutPtr->space_above = BB_MarginHeight(_w);
 	newRow = True;
     }
