@@ -1,6 +1,6 @@
 /**
  *
- * $Id: ImageCache.c,v 1.18 2000/03/16 13:00:40 rwscott Exp $
+ * $Id: ImageCache.c,v 1.19 2000/08/08 22:21:08 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ImageCache.c,v 1.18 2000/03/16 13:00:40 rwscott Exp $";
+static const char rcsid[] = "$Id: ImageCache.c,v 1.19 2000/08/08 22:21:08 danny Exp $";
 
 /*
  * --aldi 97/01/11: changed to use the generic hashtable module.
@@ -41,7 +41,11 @@ static const char rcsid[] = "$Id: ImageCache.c,v 1.18 2000/03/16 13:00:40 rwscot
 #include <string.h>
 
 #include <XmI/DebugUtil.h>
+#if XmVERSION >= 2
+#include <Xm/XpmP.h>
+#else
 #include <XmI/XmXpm.h>
+#endif
 
 /*
  * The actual caches for images and for pixmaps... we now use the generic
@@ -280,8 +284,13 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
     GC gc;
     XGCValues values;
 #ifdef NONSTANDARD_CONVERTERS
+#if XmVERSION >= 2
+    XpmColorSymbol xpm_colour_symbols[3];
+    XpmAttributes xpm_attrib;
+#else
     _LtXpmColorSymbol xpm_colour_symbols[3];
     _LtXpmAttributes xpm_attrib;
+#endif
 #endif /* NONSTANDARD_CONVERTERS */
 
     values.foreground = foreground;
@@ -465,6 +474,23 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
     xpm_attrib.numsymbols = XtNumber(xpm_colour_symbols);
     xpm_attrib.depth = depth;
     xpm_attrib.closeness = 40000;
+#if XmVERSION >= 2
+    xpm_attrib.valuemask = ( XpmSize | XpmReturnPixels | XpmColorSymbols
+			     | XpmCloseness | XpmDepth );
+
+    if (XpmReadFileToPixmap(DisplayOfScreen(screen),
+                               RootWindowOfScreen(screen),
+                               pathname_to_pixmap,
+			       &new_pix, &mask,
+			       &xpm_attrib) == XpmSuccess)
+    {
+	/* add the pixmap to the cache */
+	LTAddPixmapToCache(image_name, new_pix, screen,
+			   foreground, background, depth,
+			   xpm_attrib.width, xpm_attrib.height,
+			   xpm_attrib.x_hotspot, xpm_attrib.y_hotspot);
+    }
+#else
     xpm_attrib.valuemask = ( _LtXpmSize | _LtXpmReturnPixels | _LtXpmColorSymbols
 			     | _LtXpmCloseness | _LtXpmDepth );
 
@@ -479,7 +505,9 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
 			   foreground, background, depth,
 			   xpm_attrib.width, xpm_attrib.height,
 			   xpm_attrib.x_hotspot, xpm_attrib.y_hotspot);
-    } else
+    }
+#endif
+	else
 #endif /* NONSTANDARD_CONVERTERS */
 
     if (XReadBitmapFile(DisplayOfScreen(screen),
