@@ -1,6 +1,6 @@
 /**
  *
- * $Id: LTCvt.c,v 1.9 2000/01/03 23:29:11 rwscott Exp $
+ * $Id: LTCvt.c,v 1.10 2000/08/08 22:21:08 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LTCvt.c,v 1.9 2000/01/03 23:29:11 rwscott Exp $";
+static const char rcsid[] = "$Id: LTCvt.c,v 1.10 2000/08/08 22:21:08 danny Exp $";
 
 #ifdef NONSTANDARD_CONVERTERS 
 
@@ -35,7 +35,11 @@ static const char rcsid[] = "$Id: LTCvt.c,v 1.9 2000/01/03 23:29:11 rwscott Exp
 #include <Xm/XmP.h>
 #include <Xm/ScreenP.h>
 
-#include<XmI/XmXpm.h>
+#if XmVERSION >= 2
+#include <Xm/Xpm.h>
+#else
+#include <XmI/XmXpm.h>
+#endif
 
 #include <XmI/DebugUtil.h>
 
@@ -64,7 +68,11 @@ _XmNSEGetPixmap(Screen *screen, char *fname)
 {
     static Colormap _cmap;
 
+#if XmVERSION >= 2
+    XpmAttributes xpm_attrib;
+#else
     _LtXpmAttributes xpm_attrib;
+#endif
     Pixmap pmap;
     Pixmap mask;
 
@@ -129,6 +137,16 @@ _XmNSEGetPixmap(Screen *screen, char *fname)
 	return XmUNSPECIFIED_PIXMAP;
     }
 
+#if XmVERSION >= 2
+    xpm_attrib.colormap = _cmap;
+    xpm_attrib.closeness = 40000;
+    xpm_attrib.valuemask = XpmSize | XpmReturnPixels
+	| XpmColormap | XpmCloseness;
+
+    if (XpmReadFileToPixmap(dpy, w, pathname_to_pixmap,
+			       &pmap, &mask,
+			       &xpm_attrib) == XpmSuccess)
+#else
     xpm_attrib.colormap = _cmap;
     xpm_attrib.closeness = 40000;
     xpm_attrib.valuemask = _LtXpmSize | _LtXpmReturnPixels
@@ -137,6 +155,7 @@ _XmNSEGetPixmap(Screen *screen, char *fname)
     if (_LtXpmReadFileToPixmap(dpy, w, pathname_to_pixmap,
 			       &pmap, &mask,
 			       &xpm_attrib) == _LtXpmSuccess)
+#endif
     {
 	LTAddPixmapToCache(fname, pmap, screen, 0, 0, 0, 0, 0, 0, 0);
 	/* FIX ME! */
