@@ -23,8 +23,6 @@
  * Author:  Chris D. Peterson, MIT X Consortium
  */
 
-#ifndef LESSTIF_PRODUCTION
-
 #include <LTconfig.h>
 #include <XmI/DebugUtil.h>
 #include <Xm/XmP.h>
@@ -117,16 +115,34 @@ static Atom res_editor_command, res_editor_protocol, client_value;
 
 static Globals globals;
 
-static void SendFailure(), SendCommand(), InsertWidget(), ExecuteCommand();
-static void FreeEvent(), ExecuteSetValues(), ExecuteGetGeometry();
-static void ExecuteGetResources();
+static void SendFailure(Widget w, Atom sel, ResIdent ident, char *str);
+static void SendCommand(Widget w, Atom sel, ResIdent ident,
+			EditresCommand command, ProtocolStream *stream);
+static void InsertWidget(ProtocolStream *stream, Widget w);
+static void ExecuteCommand(Widget w, Atom sel, ResIdent ident,
+			   EditresEvent *event);
+static void FreeEvent(EditresEvent *event);
+static void ExecuteSetValues(Widget w, SetValuesEvent *sv_event,
+			     WidgetInfo *entry, ProtocolStream *stream,
+			     unsigned short *count);
+static void ExecuteGetGeometry(Widget w, ProtocolStream *stream);
+static void ExecuteGetResources(Widget w, ProtocolStream *stream);
 
-static void GetCommand();
-static void LoadResources();
-static Boolean IsChild();
-static void DumpChildren();
-static char *DumpWidgets(), *DoSetValues(), *DoFindChild();
-static char *DoGetGeometry(), *DoGetResources();
+static void GetCommand(Widget w, XtPointer data, Atom *selection, Atom *type,
+		       XtPointer value, unsigned long *length, int *format);
+static void LoadResources(Widget w);
+static void DumpChildren(Widget w, ProtocolStream *stream,
+			 unsigned short *count);
+static char *DumpWidgets(Widget w, EditresEvent *event,
+			 ProtocolStream *stream);
+static char *DoSetValues(Widget w, EditresEvent *event,
+			 ProtocolStream *stream);
+static char *DoFindChild(Widget w, EditresEvent *event,
+			 ProtocolStream *stream);
+static char *DoGetGeometry(Widget w, EditresEvent *event,
+			   ProtocolStream *stream);
+static char *DoGetResources(Widget w, EditresEvent *event,
+			    ProtocolStream *stream);
 
 /*
  * avoid linking with Xmu
@@ -172,11 +188,8 @@ XmuCopyISOLatin1Lowered(char *dst, XmConst char *src)
 
 /* ARGSUSED */
 void
-_XmNSEEditResCheckMessages(w, data, event, cont)
-Widget w;
-XtPointer data;
-XEvent *event;
-Boolean *cont;
+_XmNSEEditResCheckMessages(Widget w, XtPointer data, XEvent * event,
+			   Boolean *cont)
 {
     Time time;
     ResIdent ident;
@@ -215,7 +228,7 @@ Boolean *cont;
 	}
 
 	XtGetSelectionValue(w, res_comm, res_editor_command,
-			    GetCommand, (XtPointer) ident, time);
+			    GetCommand, (XtPointer)(unsigned long)ident, time);
     }
 }
 
@@ -233,12 +246,8 @@ Boolean *cont;
 #define ERROR_MESSAGE ("Client: Improperly formatted protocol request")
 
 static EditresEvent *
-BuildEvent(w, sel, data, ident, length)
-Widget w;
-Atom sel;
-XtPointer data;
-ResIdent ident;
-unsigned long length;
+BuildEvent(Widget w, Atom sel, XtPointer data, ResIdent ident,
+	   unsigned long length)
 {
     EditresEvent * event;
     ProtocolStream alloc_stream, *stream;
@@ -255,7 +264,7 @@ unsigned long length;
      */
 
     if (length < HEADER_SIZE) {
-	SendFailure(w, sel, ident, Failure, ERROR_MESSAGE);
+	SendFailure(w, sel, ident, ERROR_MESSAGE);
 	return(NULL);
     }
 
@@ -377,8 +386,7 @@ unsigned long length;
  */
 
 static void
-FreeEvent(event)
-EditresEvent * event;
+FreeEvent(EditresEvent *event)
 {
     if (event->any_event.widgets != NULL) {
 	XtFree((char *)event->any_event.widgets->ids);
@@ -403,14 +411,10 @@ EditresEvent * event;
 
 /* ARGSUSED */
 static void
-GetCommand(w, data, selection, type, value, length, format)
-Widget w;
-XtPointer data, value;
-Atom *selection, *type;
-unsigned long *length;
-int * format;
+GetCommand(Widget w, XtPointer data, Atom *selection, Atom *type,
+	   XtPointer value, unsigned long *length, int *format)
 {
-    ResIdent ident = (ResIdent) data;
+    ResIdent ident = (ResIdent)(unsigned long)data;
     EditresEvent * event;
 
     if ( (*type != res_editor_protocol) || (*format != EDITRES_FORMAT) )
@@ -435,11 +439,7 @@ int * format;
 
 /* ARGSUSED */    
 static void
-ExecuteCommand(w, sel, ident, event)
-Widget w;
-Atom sel;
-ResIdent ident;
-EditresEvent * event;
+ExecuteCommand(Widget w, Atom sel, ResIdent ident, EditresEvent *event)
 {
     char * (*func)();
     char * str;
@@ -504,13 +504,9 @@ EditresEvent * event;
     
 /* ARGSUSED */
 static Boolean
-ConvertReturnCommand(w, selection, target,
-		     type_ret, value_ret, length_ret, format_ret)
-Widget w;
-Atom * selection, * target, * type_ret;
-XtPointer *value_ret;
-unsigned long * length_ret;
-int * format_ret;
+ConvertReturnCommand(Widget w, Atom *selection, Atom *target,
+		     Atom *type_ret, XtPointer *value_ret,
+		     unsigned long *length_ret, int *format_ret)
 {
     /*
      * I assume the intrinsics give me the correct selection back.
@@ -535,10 +531,7 @@ int * format_ret;
 
 /* ARGSUSED */
 static void
-CommandDone(widget, selection, target)
-Widget widget;
-Atom *selection;
-Atom *target;    
+CommandDone(Widget widget, Atom *selection, Atom *target)
 {
     /* Keep the toolkit from automaticaly freeing the selection value */
 }
@@ -553,11 +546,7 @@ Atom *target;
  */
 
 static void
-SendFailure(w, sel, ident, str) 
-Widget w;
-Atom sel;
-ResIdent ident;
-char * str;
+SendFailure(Widget w, Atom sel, ResIdent ident, char *str) 
 {
     _LesstifEditResResetStream(&globals.stream);
     _LesstifEditResPutString8(&globals.stream, str);
@@ -573,10 +562,8 @@ char * str;
  */
 
 static XtPointer
-BuildReturnPacket(ident, command, stream)
-ResIdent ident;
-EditresCommand command;
-ProtocolStream * stream;
+BuildReturnPacket(ResIdent ident, EditresCommand command,
+		  ProtocolStream *stream)
 {
     long old_alloc, old_size;
     unsigned char * old_current;
@@ -621,12 +608,8 @@ ProtocolStream * stream;
  */
 
 static void
-SendCommand(w, sel, ident, command, stream)
-Widget w;
-Atom sel;
-ResIdent ident;
-EditresCommand command;
-ProtocolStream * stream;
+SendCommand(Widget w, Atom sel, ResIdent ident, EditresCommand command,
+	    ProtocolStream *stream)
 {
     BuildReturnPacket(ident, command, stream);
     globals.command_stream = stream;	
@@ -658,9 +641,7 @@ ProtocolStream * stream;
  */
 
 static int
-FindChildren(parent, children, normal, popup)
-Widget parent, **children;
-Boolean normal, popup;
+FindChildren(Widget parent, Widget **children, Boolean normal, Boolean popup)
 {
     CompositeWidget cw = (CompositeWidget) parent;
     int i, num_children, current = 0;
@@ -700,8 +681,7 @@ Boolean normal, popup;
  */
 
 static Boolean
-IsChild(top, parent, child)
-Widget top, parent, child;
+IsChild(Widget top, Widget parent, Widget child)
 {
     int i, num_children;
     Widget * children;
@@ -730,9 +710,7 @@ Widget top, parent, child;
  */
 
 static char * 
-VerifyWidget(w, info)
-Widget w;
-WidgetInfo *info;
+VerifyWidget(Widget w, WidgetInfo *info)
 {
     Widget top;
 
@@ -776,10 +754,7 @@ WidgetInfo *info;
  */
 
 static char *
-DoSetValues(w, event, stream)
-Widget w;
-EditresEvent * event;
-ProtocolStream * stream;
+DoSetValues(Widget w, EditresEvent *event, ProtocolStream *stream)
 {
     char * str;
     register unsigned i;
@@ -821,9 +796,8 @@ ProtocolStream * stream;
 
 /* ARGSUSED */
 static void
-HandleToolkitErrors(name, type, class, msg, params, num_params)
-String name, type, class, msg, *params;
-Cardinal * num_params;
+HandleToolkitErrors(String name, String type, String class, String msg,
+		    String *params, Cardinal *num_params)
 {
     SVErrorInfo * info = &globals.error_info;	
     char buf[BUFSIZ];
@@ -865,12 +839,8 @@ Cardinal * num_params;
  */
 
 static void
-ExecuteSetValues(w, sv_event, entry, stream, count)
-Widget w;
-SetValuesEvent * sv_event;
-WidgetInfo * entry;
-ProtocolStream * stream;
-unsigned short * count;
+ExecuteSetValues(Widget w, SetValuesEvent *sv_event, WidgetInfo *entry,
+		 ProtocolStream *stream, unsigned short *count)
 {
     XtErrorMsgHandler old;
     
@@ -909,10 +879,7 @@ unsigned short * count;
 
 /* ARGSUSED */
 static char * 
-DumpWidgets(w, event, stream)
-Widget w;
-EditresEvent * event;		/* UNUSED */
-ProtocolStream * stream;
+DumpWidgets(Widget w, EditresEvent *event, ProtocolStream *stream)
 {
     unsigned short count = 0;
         
@@ -952,8 +919,7 @@ ProtocolStream * stream;
  * go that far.  Then, we test whether it is an applicationShellWidget
  * class by looking for an explicit class name.  Seems pretty safe.
  */
-static Bool isApplicationShell(w)
-    Widget w;
+static Bool isApplicationShell(Widget w)
 {
     register WidgetClass c;
 
@@ -967,10 +933,7 @@ static Bool isApplicationShell(w)
 }
 
 static void
-DumpChildren(w, stream, count)
-Widget w;
-ProtocolStream * stream;
-unsigned short *count;
+DumpChildren(Widget w, ProtocolStream *stream, unsigned short *count)
 {
     int i, num_children;
     Widget *children;
@@ -1026,10 +989,7 @@ unsigned short *count;
  */
 
 static char *
-DoGetGeometry(w, event, stream)
-Widget w;
-EditresEvent * event;
-ProtocolStream * stream;
+DoGetGeometry(Widget w, EditresEvent *event, ProtocolStream *stream)
 {
     unsigned i;
     char * str;
@@ -1063,9 +1023,7 @@ ProtocolStream * stream;
  */
 
 static void
-ExecuteGetGeometry(w, stream)
-Widget w;
-ProtocolStream * stream;
+ExecuteGetGeometry(Widget w, ProtocolStream *stream)
 {
     int i;
     Boolean mapped_when_man;
@@ -1139,9 +1097,7 @@ ProtocolStream * stream;
  */
 
 static Boolean
-PositionInChild(child, x, y)
-Widget child;
-int x, y;
+PositionInChild(Widget child, int x, int y)
 {
     Arg args[6];
     Cardinal num;
@@ -1194,9 +1150,7 @@ int x, y;
  */
 
 static Widget 
-_FindChild(parent, x, y)
-Widget parent;
-int x, y;
+_FindChild(Widget parent, int x, int y)
 {
     Widget * children;
     int i = FindChildren(parent, &children, TRUE, FALSE);
@@ -1226,10 +1180,7 @@ int x, y;
  */
 
 static char *
-DoFindChild(w, event, stream)
-Widget w;
-EditresEvent * event;
-ProtocolStream * stream;
+DoFindChild(Widget w, EditresEvent *event, ProtocolStream *stream)
 {
     char * str;
     Widget parent, child;
@@ -1266,10 +1217,7 @@ ProtocolStream * stream;
  */
 
 static char *
-DoGetResources(w, event, stream)
-Widget w;
-EditresEvent * event;
-ProtocolStream * stream;
+DoGetResources(Widget w, EditresEvent *event, ProtocolStream *stream)
 {
     unsigned int i;
     char * str;
@@ -1304,9 +1252,7 @@ ProtocolStream * stream;
  */
 
 static void
-ExecuteGetResources(w, stream)
-Widget w;
-ProtocolStream * stream;
+ExecuteGetResources(Widget w, ProtocolStream *stream)
 {
     XtResourceList norm_list, cons_list;
     Cardinal num_norm, num_cons;
@@ -1367,9 +1313,7 @@ ProtocolStream * stream;
  */
 
 static void
-InsertWidget(stream, w)
-ProtocolStream * stream;
-Widget w;
+InsertWidget(ProtocolStream *stream, Widget w)
 {
     Widget temp;
     unsigned long * widget_list;
@@ -1410,9 +1354,7 @@ Widget w;
  */
 
 void
-_LesstifEditResPutString8(stream, str)
-ProtocolStream * stream;
-char * str;
+_LesstifEditResPutString8(ProtocolStream *stream, char *str)
 {
     int i, len = strlen(str);
 
@@ -1429,9 +1371,7 @@ char * str;
  */
 
 void
-_LesstifEditResPut8(stream, value)
-ProtocolStream * stream;
-unsigned int value;
+_LesstifEditResPut8(ProtocolStream *stream, unsigned int value)
 {
     unsigned char temp;
 
@@ -1457,9 +1397,7 @@ unsigned int value;
  */
 
 void
-_LesstifEditResPut16(stream, value)
-ProtocolStream * stream;
-unsigned int value;
+_LesstifEditResPut16(ProtocolStream *stream, unsigned int value)
 {
     _LesstifEditResPut8(stream, (value >> XER_NBBY) & BYTE_MASK);
     _LesstifEditResPut8(stream, value & BYTE_MASK);
@@ -1473,9 +1411,7 @@ unsigned int value;
  */
 
 void
-_LesstifEditResPut32(stream, value)
-ProtocolStream * stream;
-unsigned long value;
+_LesstifEditResPut32(ProtocolStream *stream, unsigned long value)
 {
     int i;
 
@@ -1491,9 +1427,7 @@ unsigned long value;
  */
 
 void
-_LesstifEditResPutWidgetInfo(stream, info)
-ProtocolStream * stream;
-WidgetInfo * info;
+_LesstifEditResPutWidgetInfo(ProtocolStream *stream, WidgetInfo *info)
 {
     unsigned int i;
 
@@ -1515,8 +1449,7 @@ WidgetInfo * info;
  */
 
 void
-_LesstifEditResResetStream(stream)
-ProtocolStream * stream;
+_LesstifEditResResetStream(ProtocolStream *stream)
 {
     stream->current = stream->top;
     stream->size = 0;
@@ -1547,9 +1480,7 @@ ProtocolStream * stream;
  */
 
 Boolean
-_LesstifEditResGet8(stream, val)
-ProtocolStream * stream;
-unsigned char * val;
+_LesstifEditResGet8(ProtocolStream *stream, unsigned char *val)
 {
     if (stream->size < (stream->current - stream->top)) 
 	return(FALSE);
@@ -1567,9 +1498,7 @@ unsigned char * val;
  */
 
 Boolean
-_LesstifEditResGet16(stream, val)
-ProtocolStream * stream;
-unsigned short * val;
+_LesstifEditResGet16(ProtocolStream *stream, unsigned short *val)
 {
     unsigned char temp1, temp2;
 
@@ -1588,9 +1517,7 @@ unsigned short * val;
  */
 
 Boolean
-_LesstifEditResGetSigned16(stream, val)
-ProtocolStream * stream;
-short * val;
+_LesstifEditResGetSigned16(ProtocolStream *stream, short *val)
 {
     unsigned char temp1, temp2;
 
@@ -1617,9 +1544,7 @@ short * val;
  */
 
 Boolean
-_LesstifEditResGet32(stream, val)
-ProtocolStream * stream;
-unsigned long * val;
+_LesstifEditResGet32(ProtocolStream *stream, unsigned long *val)
 {
     unsigned short temp1, temp2;
 
@@ -1639,9 +1564,7 @@ unsigned long * val;
  */
 
 Boolean
-_LesstifEditResGetString8(stream, str)
-ProtocolStream * stream;
-char ** str;
+_LesstifEditResGetString8(ProtocolStream *stream, char **str)
 {
     unsigned short len;
     register unsigned i;
@@ -1672,9 +1595,7 @@ char ** str;
  */
 
 Boolean
-_LesstifEditResGetWidgetInfo(stream, info)
-ProtocolStream * stream;
-WidgetInfo * info;
+_LesstifEditResGetWidgetInfo(ProtocolStream *stream, WidgetInfo *info)
 {
     unsigned int i;
 
@@ -1710,12 +1631,9 @@ WidgetInfo * info;
 
 /* ARGSUSED */
 static Boolean
-CvtStringToBlock(dpy, args, num_args, from_val, to_val, converter_data)
-Display * dpy;
-XrmValue * args;
-Cardinal * num_args;
-XrmValue * from_val, * to_val;
-XtPointer * converter_data;
+CvtStringToBlock(Display *dpy, XrmValue *args, Cardinal *num_args,
+		 XrmValue *from_val, XrmValue *to_val,
+		 XtPointer *converter_data)
 {
     char ptr[BUFSIZ];
     static EditresBlock block;
@@ -1764,8 +1682,7 @@ XtPointer * converter_data;
  */
 
 static void
-LoadResources(w)
-Widget w;
+LoadResources(Widget w)
 {
     static XtResource resources[] = {
         {"editresBlock", "EditresBlock", XtREditresBlock, sizeof(EditresBlock),
@@ -1781,5 +1698,3 @@ Widget w;
     XtGetApplicationResources( w, (caddr_t) &globals, resources,
 			      XtNumber(resources), NULL, (Cardinal) 0);
 }
-
-#endif /* LESSTIF_PRODUCTION */
