@@ -1,5 +1,5 @@
 /**
- * $Id: LTglob.c,v 1.10 2000/01/16 17:12:09 amai Exp $
+ * $Id: LTglob.c,v 1.11 2000/08/29 16:35:12 amai Exp $
  *
  * derived from GNU libc glob.c
  *
@@ -24,7 +24,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LTglob.c,v 1.10 2000/01/16 17:12:09 amai Exp $";
+static const char rcsid[] = "$Id: LTglob.c,v 1.11 2000/08/29 16:35:12 amai Exp $";
 
 #if defined (_AIX) && !defined (__GNUC__)
 #pragma alloca
@@ -116,6 +116,7 @@ extern void qsort();
 #define  INCL_DOSMISC
 #define  INCL_ERRORS
 #include <os2.h>
+static const char *GetDriveMap(void); /* local prototype */
 #endif
 
 #ifndef	HAVE_STRCOLL
@@ -711,42 +712,46 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
 }
 
 #ifdef __EMX__
-/* Under OS/2 we may need to deal with drive letters ...*/
+/*
+   Under OS/2 we may need to deal with drive letters.
+   Question is whether this "manual" implementation or
+   libExt will be faster in providing this feature ...
+*/
 
-static char *GetDriveMap(void)
+static const char 
+*GetDriveMap(void)
 {
   /* returns a string containing a list of all drives: e.g. "C: D: E:" */
 
-  static char drivelist[256];   /* so we'll never have a memory leak beyond 256 bytes */
-  static char tmpstr[4];
+#define MAXDRIVELETTERS 26
+  static char drivelist[3*MAXDRIVELETTERS +1] = "";
+  static char tmpstr[4] = " : ";
   ULONG  CurDrive;
   ULONG  DriveMap;
   int    dnum;
-  int    start = 3;
- 
-  drivelist[0] = '\0';
-  tmpstr[1] = ':';
-  tmpstr[2] = ' ';
-  tmpstr[3] = '\0';
-/*
-  DosError(0);
-*/
+  int    start = 3;  /* this should correspond to a hard coded limit
+                        to 'C', i.e. no check for floppy disk ?! */
+  static char offset = 'A' -1;
+
+/* DosError(0); */
+
   DosQueryCurrentDisk(&CurDrive, &DriveMap);
   DriveMap>>=start-1;
-  for (dnum = start; dnum <= 26; dnum++) {
+  for (dnum = start; dnum <= MAXDRIVELETTERS; dnum++) {
      if ((DriveMap & (ULONG)1)) {
-        tmpstr[0] = (char)dnum+'A'-1;
+        tmpstr[0] = (char)dnum + offset;
         strcat(drivelist, tmpstr);
-   }
+     }
       DriveMap>>=1; 
-  }
- 
+  } /* for dnum */
+
+  /* cosmetics: strip trailing blank: */ 
   if (drivelist[strlen(drivelist)-1]== ' ')
     drivelist[strlen(drivelist)-1] = '\0';
 
-/*
-  DosError(1);
-*/
-  return drivelist;
+/* DosError(1); */
+
+  return strdup(drivelist);
 }
+
 #endif
