@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/Label.c,v 1.111 2000/04/02 15:21:09 rwscott Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm/Label.c,v 1.115 2000/05/12 08:30:24 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/Label.c,v 1.111 2000/04/02 15:21:09 rwscott Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/Label.c,v 1.115 2000/05/12 08:30:24 amai Exp $";
 
 #include <LTconfig.h>
 #include <XmI/XmI.h>
@@ -43,6 +43,7 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/Label.c,v 1
 #include <XmI/DragDropI.h>
 
 #include <assert.h>
+#include <stdio.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -1212,7 +1213,7 @@ expose(Widget w, XEvent *event, Region region)
 	    {
 		unsigned int tmp, tmpw, tmph;
 		int tmpx, tmpy;
-		unsigned Depth;
+		int Depth;
 		Window tmpwin;
 
 		/* rws 4 Mar 2000
@@ -1224,12 +1225,45 @@ expose(Widget w, XEvent *event, Region region)
 		/* rws 10 Mar 2000
 		   Apparently a Motif 2 thing.
 		 */
-		XGetGeometry(XtDisplayOfObject(w),
-			     mypm,
-			     &tmpwin,
-			     &tmpx, &tmpy,
-			     &tmpw, &tmph,
-			     &tmp, &Depth);
+		/*
+		   eaf 3 Apr 2000 use the cache for this.  Tests indicate
+		   that Motif does this in set_values, but I like waiting
+		   until we actually need the information.
+		 */
+		{
+		  char *name ;
+		  Pixel fg, bg ;
+		  int hotx, hoty ;
+		  u_int wid, hgt ;
+
+		  if( !_XmGetPixmapData(XtScreen(w), mypm, &name,
+		  	&Depth, &fg, &bg, &hotx, &hoty, &wid, &hgt) )
+		  {
+		    /* This pixmap has never been seen before.  Generate
+		     * a unique name and add it to the cache.  The cache
+		     * mechanism will obtain the depth.  Then we can try
+		     * again.
+		     */
+		    char newname[40] ;
+		    sprintf(newname, "--anon pixmap %x-%x",
+		      (unsigned)XtScreen(w), (unsigned)mypm) ;
+		    (void) _XmInstallPixmap(mypm, XtScreen(w), newname,
+			  Prim_Foreground(w), XtBackground(w)) ;
+
+		    /* Ok, let's try again. */
+		    if( !_XmGetPixmapData(XtScreen(w), mypm, &name,
+			  &Depth, &fg, &bg, &hotx, &hoty, &wid, &hgt) )
+		    {
+		      /* Still not found?
+		       * Don't panic, ask the server directly.
+		       */
+		      unsigned uDepth;
+		      XGetGeometry(XtDisplayOfObject(w), mypm, &tmpwin,
+				&tmpx, &tmpy, &tmpw, &tmph, &tmp, &uDepth);
+		      Depth=uDepth;
+		    }
+		  }
+		}
 
 		if (Depth == 1)
 		{
