@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Manager.c,v 1.83 2000/03/05 12:38:29 rwscott Exp $
+ * $Id: Manager.c,v 1.86 2000/08/29 15:04:54 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,12 +22,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Manager.c,v 1.83 2000/03/05 12:38:29 rwscott Exp $";
+static const char rcsid[] = "$Id: Manager.c,v 1.86 2000/08/29 15:04:54 amai Exp $";
 
 #include <LTconfig.h>
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #ifdef HAVE_STRINGS_H
 #include <strings.h>
 #endif
@@ -649,7 +650,7 @@ static void
 CreateHighlightGC(Widget mw)
 {
     XGCValues values;
-    unsigned long mask;
+    unsigned long mask,dynamic,unused;
 
     mask = GCForeground | GCBackground;
     values.foreground = MGR_HighlightColor(mw);
@@ -671,7 +672,17 @@ CreateHighlightGC(Widget mw)
     values.join_style = JoinMiter;
     values.cap_style = CapButt;
 
-    MGR_HighlightGC(mw) = XtGetGC((Widget)mw, mask, &values);
+    /* these may be changed in _XmDrawHighlight() called from
+     * gadget_border_highlight() */
+    dynamic = GCLineWidth | GCLineStyle | GCJoinStyle | GCDashList;
+
+    /* have no idea ! */
+    unused = 0;
+
+    MGR_HighlightGC(mw) =
+      XtAllocateGC((Widget)mw,
+                  DefaultDepthOfScreen(XtScreen((Widget)mw)),
+                  mask,&values,dynamic,unused);
 }
 
 static void
@@ -852,6 +863,10 @@ destroy(Widget w)
     XtReleaseGC(w, MGR_BottomShadowGC(w));
     XtReleaseGC(w, MGR_HighlightGC(w));
     XtReleaseGC(w, MGR_BackgroundGC(w));
+    if (MGR_KeyboardList(w))
+    {
+        XtFree((char *)MGR_KeyboardList(w));
+    }
 
     if (MGR_EventHandlerAdded(w))
     {
