@@ -1,6 +1,6 @@
 /**
  *
- * $Id: MessageB.c,v 1.28 1998/09/30 03:41:28 rwscott Exp $
+ * $Id: MessageB.c,v 1.39 2000/08/29 15:04:55 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -22,11 +22,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: MessageB.c,v 1.28 1998/09/30 03:41:28 rwscott Exp $";
+static const char rcsid[] = "$Id: MessageB.c,v 1.39 2000/08/29 15:04:55 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <X11/Xfuncs.h>
 #include <Xm/XmP.h>
 #include <Xm/MessageBP.h>
@@ -45,7 +45,7 @@ static const char rcsid[] = "$Id: MessageB.c,v 1.28 1998/09/30 03:41:28 rwscott
 
 /* Forward Declarations */
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -303,7 +303,7 @@ XmMessageBoxClassRec xmMessageBoxClassRec = {
 WidgetClass xmMessageBoxWidgetClass = (WidgetClass)&xmMessageBoxClassRec;
 
 static void
-class_initialize()
+class_initialize(void)
 {
 #if 0
     _XmMessageBCoreClassExtRec.record_type = XmQmotif;
@@ -376,6 +376,10 @@ initialize(Widget request, Widget new_w,
 	MB_Symbol(new_w) = NULL;
     }
 
+    if (MB_MessageString(new_w)) {
+	MB_MessageString(new_w) = XmStringCopy(MB_MessageString(new_w));
+    }
+
     if (MB_DialogType(new_w) != XmDIALOG_TEMPLATE ||
 	MB_MessageString(new_w) != NULL)
     {
@@ -384,6 +388,7 @@ initialize(Widget request, Widget new_w,
 	    MB_MessageString(new_w) =
 		XmStringCreateLtoR("", XmFONTLIST_DEFAULT_TAG);
 	}
+
 	MB_Message(new_w) = _XmBB_CreateLabelG(new_w, MB_MessageString(new_w),
 					       "Message");
 
@@ -522,6 +527,22 @@ initialize(Widget request, Widget new_w,
 static void
 destroy(Widget w)
 {
+    if (MB_MessageString(w))
+    {
+	XmStringFree(MB_MessageString(w));
+    }
+    if (MB_HelpLabelString(w))
+    {
+        XmStringFree(MB_HelpLabelString(w));
+    }
+    if (MB_CancelLabelString(w))
+    {
+        XmStringFree(MB_CancelLabelString(w));
+    }
+    if (MB_OKLabelString(w))
+    {
+        XmStringFree(MB_OKLabelString(w));
+    }
 }
 
 static void
@@ -841,43 +862,55 @@ XmMbSetSubresources(Widget new_w, Widget old, ArgList args, Cardinal *nargs)
     }
 
     if (MB_HelpButton(new_w) &&
-	MB_HelpLabelString(new_w) != MB_HelpLabelString(old) &&	/* Fast */
-	!XmStringCompare(MB_HelpLabelString(new_w), MB_HelpLabelString(old)))
+	MB_HelpLabelString(new_w) != MB_HelpLabelString(old))
     {
-	Arg al[2];
+        if (!XmStringCompare(MB_HelpLabelString(new_w), MB_HelpLabelString(old)))
+        {
+            Arg al[2];
 
-	XtSetArg(al[0], XmNlabelString, MB_HelpLabelString(new_w));
-	XtSetArg(al[1], XmNlabelType, XmSTRING);
-	XtSetValues(MB_HelpButton(new_w), al, 2);
+            XtSetArg(al[0], XmNlabelString, MB_HelpLabelString(new_w));
+            XtSetArg(al[1], XmNlabelType, XmSTRING);
+            XtSetValues(MB_HelpButton(new_w), al, 2);
 
-	refresh_needed = True;
+            refresh_needed = True;
+        }
+        MB_HelpLabelString(new_w) = XmStringCopy(MB_HelpLabelString(new_w));
+        XmStringFree(MB_HelpLabelString(old));
     }
 
     if (BB_CancelButton(new_w) &&
-	MB_CancelLabelString(new_w) != MB_CancelLabelString(old) && /* Fast */
-	!XmStringCompare(MB_CancelLabelString(new_w),
-			 MB_CancelLabelString(old)))
+	MB_CancelLabelString(new_w) != MB_CancelLabelString(old))
     {
-	Arg al[2];
+	if (!XmStringCompare(MB_CancelLabelString(new_w),
+                             MB_CancelLabelString(old)))
+        {
+            Arg al[2];
 
-	XtSetArg(al[0], XmNlabelString, MB_CancelLabelString(new_w));
-	XtSetArg(al[1], XmNlabelType, XmSTRING);
-	XtSetValues(BB_CancelButton(new_w), al, 2);
+            XtSetArg(al[0], XmNlabelString, MB_CancelLabelString(new_w));
+            XtSetArg(al[1], XmNlabelType, XmSTRING);
+            XtSetValues(BB_CancelButton(new_w), al, 2);
 
-	refresh_needed = True;
+            refresh_needed = True;
+        }
+        MB_CancelLabelString(new_w) = XmStringCopy(MB_CancelLabelString(new_w));
+        XmStringFree(MB_CancelLabelString(old));
     }
 
     if (MB_OKButton(new_w) &&
-	MB_OKLabelString(new_w) != MB_OKLabelString(old) && /* Fast */
-	!XmStringCompare(MB_OKLabelString(new_w), MB_OKLabelString(old)))
+	MB_OKLabelString(new_w) != MB_OKLabelString(old))
     {
-	Arg al[2];
+        if (!XmStringCompare(MB_OKLabelString(new_w), MB_OKLabelString(old)))
+        {
+            Arg al[2];
 
-	XtSetArg(al[0], XmNlabelString, MB_OKLabelString(new_w));
-	XtSetArg(al[1], XmNlabelType, XmSTRING);
-	XtSetValues(MB_OKButton(new_w), al, 2);
+            XtSetArg(al[0], XmNlabelString, MB_OKLabelString(new_w));
+            XtSetArg(al[1], XmNlabelType, XmSTRING);
+            XtSetValues(MB_OKButton(new_w), al, 2);
 
-	refresh_needed = True;
+            refresh_needed = True;
+        }
+        MB_OKLabelString(new_w) = XmStringCopy(MB_OKLabelString(new_w));
+        XmStringFree(MB_OKLabelString(old));
     }
 
     return refresh_needed;
@@ -908,6 +941,12 @@ set_values(Widget old, Widget request, Widget new_w,
     /* Must do this call first */
     refresh_needed = XmMbSetSubresources(new_w, old, args, num_args);
 
+    /* Copy MB_MessageString */
+    if ((MB_MessageString(new_w) != MB_MessageString(old)) && MB_MessageString(new_w)) {
+	MB_MessageString(new_w) = XmStringCopy(MB_MessageString(new_w));
+	if (MB_MessageString(old))
+	    XmStringFree(MB_MessageString(old));
+    }
     if (refresh_needed || XtWidth(old) != XtWidth(new_w) ||
 	XtHeight(old) != XtHeight(new_w))
     {
@@ -987,6 +1026,15 @@ _XmMessageBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
 	}
     }
 
+#if 0
+/* rws 15 Nov 1998
+_XmMessageBoxGeoMatrixCreate() - When counting the rows that we need to 
+	allocate we were putting the work area on the same row as the
+	message and symbol, however we were doing the actual layout with
+	the work area on it's own row _iff_ there is a message.  So, if there
+	is a message and a work area we are laying out for 4 rows but only
+	allocating 3, which is not such a good idea.
+ */
     if ((MB_Message(_w) && XtIsManaged(MB_Message(_w))) ||
 	(MB_Symbol(_w) && XtIsManaged(MB_Symbol(_w))))
     {
@@ -1019,6 +1067,43 @@ _XmMessageBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
 	    }
 	}
     }
+#else
+    if ((MB_Message(_w) && XtIsManaged(MB_Message(_w))) ||
+	(MB_Symbol(_w) && XtIsManaged(MB_Symbol(_w))))
+    {
+	/* message and symbol are always on there own row */
+	nrows++;
+    }
+    if (nextras > 0)
+    {
+	/* look for work area */
+	for (i = 0; i < nextras; i++)
+	{
+	    if (extras[i] && XtIsManaged(extras[i]) &&
+		!XmIsMenuBar(extras[i]) && !XmIsPushButton(extras[i]) &&
+		!XmIsPushButtonGadget(extras[i]))
+	    {
+		if (MB_Message(_w) && XtIsManaged(MB_Message(_w)))
+		{
+		    /* work area is always below a message */
+		    nrows++;
+		    break;
+		}
+		else if ((MB_Symbol(_w) && XtIsManaged(MB_Symbol(_w))))
+		{
+		    /* work area is beside a symbol */
+		    break;
+		}
+		else
+		{
+		    /* work area is alone on the first row */
+		    nrows++;
+		    break;
+		}
+	    }
+	}
+    }
+#endif
 
     if (MB_Separator(_w) && XtIsManaged(MB_Separator(_w)))
     {
@@ -1160,6 +1245,13 @@ _XmMessageBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
     }
 
     newRow = False;
+    /* rws 28 Mar 1999
+       messagebox/test18 shows this wackyness. If we don't have an OK button
+       these are 6, if we do, they are 4. (go figure!!!)
+       messagebox/test10 shows that extra buttons are also 4.
+     */
+    layoutPtr->even_width = 6;
+    layoutPtr->even_height = 6;
     if (MB_OKButton(_w) && XtIsManaged(MB_OKButton(_w)) &&
 	_XmGeoSetupKid(boxPtr++, MB_OKButton(_w)))
     {
@@ -1191,8 +1283,10 @@ _XmMessageBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
     {
 	layoutPtr->fill_mode = XmGEO_CENTER;
 	layoutPtr->fit_mode = XmGEO_WRAP;
+	/*
 	layoutPtr->even_width = 4;
 	layoutPtr->even_height = 4;
+	*/
 	layoutPtr->space_above = BB_MarginHeight(_w);
 	newRow = True;
     }
@@ -1201,8 +1295,10 @@ _XmMessageBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
     {
 	layoutPtr->fill_mode = XmGEO_CENTER;
 	layoutPtr->fit_mode = XmGEO_WRAP;
+	/*
 	layoutPtr->even_width = 4;
 	layoutPtr->even_height = 4;
+	*/
 	layoutPtr->space_above = BB_MarginHeight(_w);
 	newRow = True;
     }
@@ -1391,19 +1487,20 @@ XmCreateMessageDialog(Widget parent,
     al = (Arg *)XtCalloc(argcount + 2, sizeof(Arg));
 
     nargs = 0;
-    XtSetArg(al[nargs], XmNallowShellResize, True);
-    nargs++;
+    XtSetArg(al[nargs], XmNallowShellResize, True); nargs++;
 
     for (i = 0; i < argcount; i++)
     {
-	XtSetArg(al[nargs], arglist[i].name, arglist[i].value);
-	nargs++;
+	XtSetArg(al[nargs], arglist[i].name, arglist[i].value); nargs++;
     }
 
     shell = XmCreateDialogShell(parent, shell_name, al, nargs);
     XtFree(shell_name);
 
     r = XmCreateMessageBox(shell, name, al, nargs);
+    XtAddCallback(r, XmNdestroyCallback,
+		  _XmDestroyParentCallback,
+		  (XtPointer)r);
     XtFree((XtPointer)al);
 
     return r;
@@ -1560,31 +1657,24 @@ XmMessageBoxGetChild(Widget parent,
     {
     case XmDIALOG_CANCEL_BUTTON:
 	return BB_CancelButton(mb);
-	break;
 
     case XmDIALOG_DEFAULT_BUTTON:
 	return BB_DefaultButton(mb);
-	break;
 
     case XmDIALOG_HELP_BUTTON:
 	return MB_HelpButton(mb);
-	break;
 
     case XmDIALOG_MESSAGE_LABEL:
 	return MB_Message(mb);
-	break;
 
     case XmDIALOG_OK_BUTTON:
 	return MB_OKButton(mb);
-	break;
 
     case XmDIALOG_SEPARATOR:
 	return MB_Separator(mb);
-	break;
 
     case XmDIALOG_SYMBOL_LABEL:
 	return MB_Symbol(mb);
-	break;
 
     default:
 	/* invalid child */
