@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Protocols.c,v 1.4 1998/09/12 15:05:36 rwscott Exp $
+ * $Id: Protocols.c,v 1.9 2000/07/09 11:33:02 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,10 +22,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Protocols.c,v 1.4 1998/09/12 15:05:36 rwscott Exp $";
+static const char rcsid[] = "$Id: Protocols.c,v 1.9 2000/07/09 11:33:02 rwscott Exp $";
 
 #include <LTconfig.h>
 #include <XmI/XmI.h>
+#include <XmI/MacrosI.h>
 
 #include <Xm/XmP.h>
 #include <Xm/ProtocolsP.h>
@@ -33,7 +34,7 @@ static const char rcsid[] = "$Id: Protocols.c,v 1.4 1998/09/12 15:05:36 rwscott
 
 #include <XmI/DebugUtil.h>
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -47,7 +48,47 @@ static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
 #endif
 
+#if 0
 static void _XmProtocolHandler(Widget w, XEvent *evp, String *params, Cardinal *nparams);
+#else
+static void _XmProtocolHandler(Widget w, XtPointer client_data, XEvent *ev, Boolean *ctd);
+#endif
+
+/* For the prototype police */
+#ifdef	XmActivateWMProtocol
+#undef	XmActivateWMProtocol
+#endif
+#ifdef	XmAddWMProtocols
+#undef	XmAddWMProtocols
+#endif
+#ifdef	XmAddWMProtocolCallback
+#undef	XmAddWMProtocolCallback
+#endif
+#ifdef	XmRemoveWMProtocolCallback
+#undef	XmRemoveWMProtocolCallback
+#endif
+#ifdef	XmRemoveWMProtocols
+#undef	XmRemoveWMProtocols
+#endif
+#ifdef	XmSetWMProtocolHooks
+#undef	XmSetWMProtocolHooks
+#endif
+extern void XmActivateWMProtocol(Widget shell, Atom protocol);
+extern void XmAddWMProtocols(Widget shell, Atom *protocols,
+			     Cardinal num_protocols);
+extern void XmAddWMProtocolCallback(Widget shell, Atom protocol,
+				   XtCallbackProc callback, XtPointer closure);
+extern void XmRemoveWMProtocolCallback(Widget shell, Atom protocol,
+				   XtCallbackProc callback, XtPointer closure);
+extern void XmRemoveWMProtocols(Widget shell, Atom *protocols,
+				Cardinal num_protocols);
+extern void XmSetWMProtocolHooks(Widget shell, Atom protocol,
+				 XtCallbackProc prehook, XtPointer pre_closure,
+				 XtCallbackProc posthook,
+				 XtPointer post_closure);
+
+extern void _XtAddCallback(XtCallbackList *, XtCallbackProc, XtPointer);
+extern void _XtRemoveCallback(XtCallbackList *, XtCallbackProc, XtPointer);
 
 /*
  * resources 
@@ -120,7 +161,7 @@ XmProtocolClassRec xmProtocolClassRec = {
 WidgetClass xmProtocolClass = (WidgetClass)&xmProtocolClassRec;
 
 static void
-class_initialize()
+class_initialize(void)
 {
     DEBUGOUT(XdbDebug(__FILE__, NULL, "Protocol ClassInitialize\n"));
 }
@@ -136,9 +177,6 @@ initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
     DEBUGOUT(XdbDebug(__FILE__, new_w, "Protocol Initialize\n"));
-
-    Protocol_PreHook(new_w).callback = NULL;
-    Protocol_PostHook(new_w).callback = NULL;
 }
 
 static void
@@ -258,8 +296,14 @@ __XmAddProtocol(XmAllProtocolsMgr mgrs, Atom property, Atom protocol)
 	_XmError(NULL, "Shell has no extension!\n");
     }
 
-    w = (XmProtocol)XtCreateWidget("protocol_ext", xmProtocolClass,
-				   ve, NULL, 0);
+    w = (XmProtocol)_XmExtObjAlloc(xmProtocolClass->
+					core_class.widget_size);
+    ExtObj_LogicalParent(w) = mgrs->shell;
+    ExtObj_ExtensionType(w) = XmPROTOCOL_EXTENSION;
+
+    bzero(&Protocol_PreHook(w), sizeof(XtCallbackRec));
+    bzero(&Protocol_PostHook(w), sizeof(XtCallbackRec));
+    Protocol_Callbacks(w) = NULL;
 
     Protocol_Atom(w) = protocol;
     mgr->protocols[mgr->num_protocols] = w;
@@ -291,10 +335,12 @@ __XmFindProtocol(XmAllProtocolsMgr mgrs, Atom property, Atom protocol)
     return NULL;
 }
 
+#if 0
 static XtActionsRec actions[] =
 {
     {"XmProtocolHandler", _XmProtocolHandler},
 };
+#endif
 
 void
 _XmInitProtocols(Widget w)
@@ -308,8 +354,60 @@ _XmInitProtocols(Widget w)
 
     DEBUGOUT(XdbDebug(__FILE__, w, "Init Protocols: %08x %08x\n", w, newman));
 
+#if 0
     XtAppAddActions(XtWidgetToApplicationContext(w),
 		    actions, XtNumber(actions));
+	/* We shouldn't add the same action again and again - it's not possible
+	 * to remove it and the appContext's action table will grow.
+	 *
+	 * However, we can not do this just once either (e.g. in class_initialize)
+	 * because we have no idea about how many app_contexts there are.
+	 *
+	 * We simply change the action for an event handler (they dont have
+	 * no XmProtocolHandler action either)
+	 */
+#else
+	XtAddEventHandler(w, 0, True, _XmProtocolHandler, NULL);
+#endif
+}
+
+void
+_XmDestroyProtocols(Widget w)
+{
+	XmAllProtocolsMgr allmgrs = NULL;
+	int nmgr, nproto;
+
+	_XmPopWidgetExtData(w, (XmWidgetExtData*) &allmgrs, XmPROTOCOL_EXTENSION);
+
+	if ( ! allmgrs )
+	{
+	    return;
+	}
+
+	/* we could repeatedly call _XmRemoveProtocols here, but it is easier
+	 * to just destroy everything thus avoiding any searching.
+	 */
+
+	/* remove all manager structures */
+	for (nmgr = 0; nmgr < allmgrs->num_protocol_mgrs; nmgr++)
+	{
+		XmProtocolMgr mgr = allmgrs->protocol_mgrs[nmgr];
+		/* destroy all protocol objects */
+		for (nproto = 0; nproto < mgr->num_protocols; nproto++)
+		{
+		    _XmExtObjFree((Widget) mgr->protocols[nproto]);
+		}
+		XtFree((char*) mgr->protocols);
+		XtFree((char*) mgr);
+	}
+	
+	if (allmgrs->protocol_mgrs)
+	{
+	    XtFree((char*) allmgrs->protocol_mgrs);
+	}
+	
+	XtFree((char*)allmgrs);
+	XtRemoveEventHandler(w, XtAllEvents, True, _XmProtocolHandler, NULL);
 }
 
 /*
@@ -351,7 +449,11 @@ _XmInstallProtocols(Widget w)
 }
 
 static void
+#if 0
 _XmProtocolHandler(Widget w, XEvent *evp, String *params, Cardinal *nparams)
+#else
+_XmProtocolHandler(Widget w, XtPointer client_data, XEvent *evp, Boolean *ctd)
+#endif
 {
     Atom property, protocol;
     XmAllProtocolsMgr mgrs;
@@ -405,7 +507,7 @@ _XmProtocolHandler(Widget w, XEvent *evp, String *params, Cardinal *nparams)
 			   Protocol_Callbacks(p),
 			   (XtPointer)&cd);
 
-	if (Protocol_PostHook(p).callback)
+	if ((!Protocol_Callbacks(p)) && Protocol_PostHook(p).callback)
 	{
 	    (Protocol_PostHook(p).callback) (mgrs->shell,
 					     Protocol_PostHook(p).closure,
@@ -465,9 +567,6 @@ XmDeactivateProtocol(Widget shell,
     Protocol_Active(p) = False;
 }
 
-#ifdef	XmActivateWMProtocol
-#undef	XmActivateWMProtocol
-#endif
 void
 XmActivateWMProtocol(Widget shell,
 		     Atom protocol)
@@ -483,8 +582,10 @@ XmAddProtocols(Widget shell,
 	       Atom *protocol,
 	       Cardinal num_protocols)
 {
+#if 0
     char *tbl, *a;
     XtTranslations ctbl;
+#endif
     int i;
     XmAllProtocolsMgr mgrs;
     XmProtocol p;
@@ -499,17 +600,43 @@ XmAddProtocols(Widget shell,
 	return;
     }
 
+	/* T. Straumann: I changed the action/translation implementation for an event
+	 * 				 handler. This is easier and avoids some memory leaks.
+	 */
+#if 0
     a = XGetAtomName(XtDisplay(shell), property);
     tbl = (char *)XtMalloc(32 + strlen(a));
     strcpy(tbl, "<Message>");	/* len 9 */
     strcat(tbl, a);
     strcat(tbl, ": XmProtocolHandler()\n");	/* len 21 */
 
+#ifdef NEVER_DO_THIS
+	/* T. Straumann: never use XtParseTranslationTable() in a routine
+	 *				 that might get called many times. The constructed
+	 *               translation table is dynamically allocated and there's
+	 *				 no way to free it.
+	 *				 If you absolutely need this, it's better to use
+	 *				 XtConvertAndStore() because, at least, identical tables 
+	 *				 will be cached.
+	 */
     ctbl = XtParseTranslationTable(tbl);
+#else
+	{   
+	XrmValue from,to;
+    Boolean result;
+	from.size = sizeof(String);
+	from.addr = tbl;
+	to.size = sizeof(XtTranslations);
+	to.addr = &ctbl;
+	XtConvertAndStore(shell,XtRString,&from,XtRTranslationTable,&to);
+	}
+#endif
+
     XtAugmentTranslations(shell, ctbl);
 
     XtFree(tbl);
     XFree(a);
+#endif
 
     for (i = 0; i < num_protocols; i++)
     {
@@ -533,10 +660,6 @@ XmAddProtocols(Widget shell,
     }
 }
 
-#ifdef	XmAddWMProtocols
-#undef	XmAddWMProtocols
-#endif
-
 void
 XmAddWMProtocols(Widget shell,
 		 Atom *protocols,
@@ -548,10 +671,6 @@ XmAddWMProtocols(Widget shell,
 		   num_protocols);
 }
 
-#ifdef	XmAddWMProtocolCallback
-#undef	XmAddWMProtocolCallback
-#endif
-
 void
 XmAddProtocolCallback(Widget shell,
 		      Atom property,
@@ -583,7 +702,7 @@ XmAddProtocolCallback(Widget shell,
     /*
      * Add Callback
      */
-    XtAddCallback((Widget)p, XmNprotocolCallback, callback, closure);
+    _XtAddCallback(&Protocol_Callbacks(p), callback, closure);
 }
 
 void
@@ -630,13 +749,9 @@ XmRemoveProtocolCallback(Widget shell,
     /*
      * Remove Callback
      */
-    XtRemoveCallback((Widget)p, XmNprotocolCallback, callback, closure);
+    _XtRemoveCallback(&Protocol_Callbacks(p), callback, closure);
 }
 
-#ifdef	XmRemoveWMProtocolCallback
-#undef	XmRemoveWMProtocolCallback
-#endif
-
 void
 XmRemoveWMProtocolCallback(Widget shell,
 			   Atom protocol,
@@ -657,8 +772,8 @@ XmRemoveProtocols(Widget shell,
 		  Cardinal num_protocols)
 {
     XmAllProtocolsMgr mgrs;
-    XmProtocol p;
-    int i;
+	XmProtocolMgr	  mgr;
+    int i, mgr_slot, proto_slot;
 
     DEBUGOUT(XdbDebug(__FILE__, shell, "XmRemoveProtocols\n"));
 
@@ -667,21 +782,75 @@ XmRemoveProtocols(Widget shell,
 	return;
     }
 
+    for (mgr_slot = 0; mgr_slot < mgrs->num_protocol_mgrs; mgr_slot++)
+    {
+	if (mgrs->protocol_mgrs[mgr_slot]->property == property)
+	    break;
+    }
+
+    if ( mgr_slot == mgrs->num_protocol_mgrs )
+    {
+	/* property not found */
+	return;
+    }
+
+    mgr = mgrs->protocol_mgrs[mgr_slot];
+
     for (i = 0; i < num_protocols; i++)
     {
-	if ((p = __XmFindProtocol(mgrs, property, protocols[i])) == NULL)
-	{
-	    return;
-	}
+	proto_slot = 0;
+	while (proto_slot < mgr->num_protocols)
+        {
+	    if (Protocol_Atom(mgr->protocols[proto_slot]) == protocols[i])
+	    {
+		int j;
 
-	Protocol_Active(p) = False;
+		/* destroy protocol object */
+	        _XmExtObjFree((Widget)mgr->protocols[proto_slot]);
+
+		/* compact the remaining list */
+		for (j = proto_slot; j < mgr->num_protocols - 1; j++)
+		{
+			mgr->protocols[j] = mgr->protocols[j+1];
+		}
+
+		/* free the list of protocols and remove the
+		 * property from the list of managers
+		 * if count drops to 0
+		 */
+		if ( --(mgr->num_protocols) == 0 )
+		{
+		    int j;
+	
+		    XtFree((char*)mgr->protocols);
+
+		    XtFree((char*)mgrs->protocol_mgrs[mgr_slot]);
+
+		    /* compact list of managers */
+		    for ( j = mgr_slot; j < mgrs->num_protocol_mgrs - 1; j++)
+		    {
+			mgrs->protocol_mgrs[j] = mgrs->protocol_mgrs[j+1];
+		    }
+		    if ( --(mgrs->num_protocol_mgrs) == 0 )
+		    {
+			XtFree((char*) mgrs->protocol_mgrs);
+			mgrs->protocol_mgrs = NULL;
+			mgrs->max_protocol_mgrs = 0;
+		    }
+		    /* IMPORTANT NOTE: If we should get here, mgr is does
+		     * not exist anymore and hence we must leave the loop
+		     * immediately.
+		     */
+		    return;
+		}
+		break; /* and continue looking for the next protocol to
+			* remove */
+	    }
+	    proto_slot++;
+        }
     }
 }
 
-#ifdef	XmRemoveWMProtocols
-#undef	XmRemoveWMProtocols
-#endif
-
 void
 XmRemoveWMProtocols(Widget shell,
 		    Atom *protocols,
@@ -729,9 +898,6 @@ XmSetProtocolHooks(Widget shell,
     Protocol_PostHook(p).closure = post_closure;
 }
 
-#ifdef	XmSetWMProtocolHooks
-#undef	XmSetWMProtocolHooks
-#endif
 void
 XmSetWMProtocolHooks(Widget shell,
 		     Atom protocol,
