@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Region.c,v 1.4 1998/09/12 15:05:37 rwscott Exp $
+ * $Id: Region.c,v 1.6 2000/04/30 22:38:23 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -21,12 +21,13 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  **/
-static const char rcsid[] = "$Id: Region.c,v 1.4 1998/09/12 15:05:37 rwscott Exp $";
+static const char rcsid[] = "$Id: Region.c,v 1.6 2000/04/30 22:38:23 amai Exp $";
+
+#include <LTconfig.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 
-#include <LTconfig.h>
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
 
@@ -47,6 +48,7 @@ static const char rcsid[] = "$Id: Region.c,v 1.4 1998/09/12 15:05:37 rwscott Exp
 #define ASSIGN_IF_LT(a,b) { if ((a) < (b)) a = b; }
 
 
+#if 0
 static int
 qsort_compare_function(const void *a,
 		       const void *b)
@@ -75,6 +77,7 @@ __XmCompactRectangles(XmRegionBox **rects,
     qsort(*rects, *numRects, sizeof(XmRegionBox),
 	  qsort_compare_function);
 }
+#endif
 
 /**
  * __XmAddRectangle
