@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Scale.c,v 1.39 2000/05/30 19:53:12 hennessy Exp $
+ * $Id: Scale.c,v 1.40 2000/07/17 13:59:00 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Scale.c,v 1.39 2000/05/30 19:53:12 hennessy Exp $";
+static const char rcsid[] = "$Id: Scale.c,v 1.40 2000/07/17 13:59:00 amai Exp $";
 
 #include <LTconfig.h>
 #include <stdlib.h>
@@ -598,6 +598,11 @@ initialize(Widget request, Widget new_w,
 static void
 destroy(Widget w)
 {
+
+    if (Scale_Title(w))
+     {
+         XmStringFree(Scale_Title(w));
+     }
     XmFontListFree(Scale_FontList(w));
     XtDestroyGC(Scale_ForegroundGC(w));
 }
