@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/SelectionBox.c,v 1.37 1998/10/23 05:15:52 rwscott Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm/SelectionBox.c,v 1.46 2000/03/05 13:12:26 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/SelectionBox.c,v 1.37 1998/10/23 05:15:52 rwscott Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/SelectionBox.c,v 1.46 2000/03/05 13:12:26 rwscott Exp $";
 
 #include <LTconfig.h>
 #include <XmI/XmI.h>
@@ -50,7 +50,7 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/SelectionBo
 
 /* Forward Declarations */
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -374,7 +374,8 @@ XmSelectionBoxClassRec xmSelectionBoxClassRec = {
     },
     /* XmSelectionBox part */
     {
-	/* extension */ NULL,
+	/* list_callback                */ NULL,
+	/* extension                    */ NULL,
     }
 };
 /* *INDENT-ON* */
@@ -384,7 +385,7 @@ XmSelectionBoxClassRec xmSelectionBoxClassRec = {
 WidgetClass xmSelectionBoxWidgetClass = (WidgetClass)&xmSelectionBoxClassRec;
 
 static void
-class_initialize()
+class_initialize(void)
 {
     if (text_accelerators_parsed == NULL)
     {
@@ -399,6 +400,13 @@ class_initialize()
 static void
 class_part_initialize(WidgetClass widget_class)
 {
+    XmSelectionBoxWidgetClass sbwc = (XmSelectionBoxWidgetClass)widget_class;
+    XmSelectionBoxWidgetClass swc = (XmSelectionBoxWidgetClass)widget_class->core_class.superclass;
+
+    if (sbwc->selection_box_class.list_callback == XmInheritCallbackProc)
+    {
+    	sbwc->selection_box_class.list_callback = swc->selection_box_class.list_callback;
+    }
     _XmFastSubclassInit(widget_class, XmSELECTION_BOX_BIT);
 }
 
@@ -579,7 +587,7 @@ _XmSbButton(Widget w, XtPointer client, XtPointer call)
 
 	XtCallCallbackList((Widget)sb, sb->manager.help_callback, &cbs);
     }
-
+#if 0
     if (BB_AutoUnmanage(sb) && au)
     {
 	Widget s = XtParent((Widget)sb);
@@ -594,7 +602,7 @@ _XmSbButton(Widget w, XtPointer client, XtPointer call)
 	    XtCallCallbackList(s, Shell_PopdownCallback(s), NULL);
 	}
     }
-
+#endif
 }
 
 /*
@@ -712,17 +720,26 @@ initialize(Widget request,
     		XmNitems, SB_ListItems(sb),
     		XmNitemCount, SB_ListItemCount(sb),
     		NULL);
+		/* T. Straumann: List made a copy of the item list;
+		 *				 we have to adjust SB_ListItems
+		 */
+		XtVaGetValues(SB_List(sb), XmNitems, &SB_ListItems(sb), 0);
     }
 }
 
 static void
 destroy(Widget w)
 {
+    DEBUGOUT(XdbDebug("RWS", w,"%s:destroy(%d)\n",
+    	__FILE__, __LINE__
+    	));
     /* rws 14 Apr 1998
        Motif does not have this method.  Then again we all know Motif has
        memory leaks.
      */
     XmStringFree(SB_TextString(w));
+	/* T. Straumann: fixed memory leak */
+	XmStringFree(SB_ApplyLabelString(w));
 }
 
 /*
@@ -770,6 +787,11 @@ set_values(Widget old,
     if (ac && SB_List(sb))
     {
 	XtSetValues(SB_List(sb), al, ac);
+	/* T. Straumann: List made a copy of the item list;
+	 *				 we have to adjust SB_ListItems
+	 */
+	al[0].value = (XtArgVal)&SB_ListItems(sb);
+	XtGetValues(SB_List(sb), al, 1);
     }
 
     /* Text : Text string */
@@ -1526,7 +1548,7 @@ _XmSelectionBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
 	layoutPtr->stretch_height = 1;
 	layoutPtr->fill_mode = XmGEO_EXPAND;
 	layoutPtr->even_width = 1;
-	layoutPtr->even_height = 1;
+	layoutPtr->even_height = 4;
 	layoutPtr->space_above = BB_MarginHeight(_w);
 	layoutPtr++;
 	boxPtr += 2;
@@ -1584,8 +1606,8 @@ _XmSelectionBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
     {
 	layoutPtr->fill_mode = XmGEO_CENTER;
 	layoutPtr->fit_mode = XmGEO_WRAP;
-	layoutPtr->even_width = 1;
-	layoutPtr->even_height = 1;
+	layoutPtr->even_width = 6;
+	layoutPtr->even_height = 6;
 	layoutPtr->space_above = BB_MarginHeight(_w);
 	newRow = True;
     }
@@ -1598,8 +1620,8 @@ _XmSelectionBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
 	    _XmBulletinBoardSetDefaultShadow(extras[i]);
 	    layoutPtr->fill_mode = XmGEO_CENTER;
 	    layoutPtr->fit_mode = XmGEO_WRAP;
-	    layoutPtr->even_width = 1;
-	    layoutPtr->even_height = 1;
+	    layoutPtr->even_width = 6;
+	    layoutPtr->even_height = 6;
 	    layoutPtr->space_above = BB_MarginHeight(_w);
 	    newRow = True;
 	}
@@ -1610,8 +1632,8 @@ _XmSelectionBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
     {
 	layoutPtr->fill_mode = XmGEO_CENTER;
 	layoutPtr->fit_mode = XmGEO_WRAP;
-	layoutPtr->even_width = 1;
-	layoutPtr->even_height = 1;
+	layoutPtr->even_width = 6;
+	layoutPtr->even_height = 6;
 	layoutPtr->space_above = BB_MarginHeight(_w);
 	newRow = True;
     }
@@ -1620,8 +1642,8 @@ _XmSelectionBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
     {
 	layoutPtr->fill_mode = XmGEO_CENTER;
 	layoutPtr->fit_mode = XmGEO_WRAP;
-	layoutPtr->even_width = 1;
-	layoutPtr->even_height = 1;
+	layoutPtr->even_width = 6;
+	layoutPtr->even_height = 6;
 	layoutPtr->space_above = BB_MarginHeight(_w);
 	newRow = True;
     }
@@ -1630,8 +1652,8 @@ _XmSelectionBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
     {
 	layoutPtr->fill_mode = XmGEO_CENTER;
 	layoutPtr->fit_mode = XmGEO_WRAP;
-	layoutPtr->even_width = 1;
-	layoutPtr->even_height = 1;
+	layoutPtr->even_width = 6;
+	layoutPtr->even_height = 6;
 	layoutPtr->space_above = BB_MarginHeight(_w);
 	newRow = True;
     }
