@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/Text.c,v 1.123 2000/05/20 15:46:14 hennessy Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm/Text.c,v 1.124 2000/07/18 23:16:38 hennessy Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Text.c,v 1.123 2000/05/20 15:46:14 hennessy Exp $";
+static const char rcsid[] = "$Id: Text.c,v 1.124 2000/07/18 23:16:38 hennessy Exp $";
 
 #undef VERBOSE
 
@@ -2565,7 +2565,7 @@ XmTextSetEditable(Widget w, Boolean editable)
 void
 XmTextSetHighlight(Widget w, XmTextPosition left, XmTextPosition right, XmHighlightMode mode)
 {
-    if (left >= right)
+    if (left >= right || left < 0 )
     {
 	/* FIX ME */
 	DEBUGOUT(XdbDebug(__FILE__, w,
@@ -2663,7 +2663,7 @@ XmTextSetHighlight(Widget w, XmTextPosition left, XmTextPosition right, XmHighli
 	/* FIX ME this can be more efficient */
 	for (i=0; i<Text_Highlight(w).number && Text_Highlight(w).list[i].position < left; i++) ;
 		/* i points to the entry just beyond "left" */
-	for (j=i; j<Text_Highlight(w).number && Text_Highlight(w).list[j].position <= right; j++) ;
+	for (j=i; j<Text_Highlight(w).number && Text_Highlight(w).list[j].position < right; j++) ;
 	if (i < j-1) 
 	{
 	    for (k=i+1, l=j; l<Text_Highlight(w).number; k++,l++) 
