@@ -1,7 +1,6 @@
-/*                   -*-Mode: c; c-file-style: "GNU"-*-              */
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/TextOut.c,v 1.83 2000/05/24 23:08:54 hennessy Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm/TextOut.c,v 1.85 2000/08/03 21:29:46 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -23,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/TextOut.c,v 1.83 2000/05/24 23:08:54 hennessy Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/TextOut.c,v 1.85 2000/08/03 21:29:46 rwscott Exp $";
 
 #include <LTconfig.h>
 #include <Xm/XmP.h>
@@ -2300,9 +2299,18 @@ destroy(Widget aw)
 	Out_TimerId(o) = 0;
     }
 
-    XtReleaseGC((Widget)w, Out_DrawGC(o));
-    XtReleaseGC((Widget)w, Out_CursorGC(o));
-    XtReleaseGC((Widget)w, Out_CopyGC(o));
+    if (o && Out_DrawGC(o))
+    {
+	XFreeGC(XtDisplay(w), Out_DrawGC(o));
+    }
+    if (o && Out_CursorGC(o))
+    {
+	XFreeGC(XtDisplay(w), Out_CursorGC(o));
+    }
+    if (o && Out_CopyGC(o))
+    {
+	XtReleaseGC((Widget)w, Out_CopyGC(o));
+    }
 
     if (Out_CursorIBeam(o))
     {
@@ -2317,10 +2325,10 @@ destroy(Widget aw)
 	XFreePixmap(XtDisplay((Widget)w), Out_CursorSave(o));
     }
 
-	if (Out_FontListCreated(o) && Out_FontList(o))
-	{
+    if (Out_FontListCreated(o) && Out_FontList(o))
+    {
 	XmFontListFree(Out_FontList(o));
-	}
+    }
 
     XtFree((char *)Text_Output(w));
 }
