@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Vendor.c,v 1.58 1994/06/05 13:13:36 amai Exp $
+ * $Id: Vendor.c,v 1.60 2000/08/04 16:08:14 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Vendor.c,v 1.58 1994/06/05 13:13:36 amai Exp $";
+static const char rcsid[] = "$Id: Vendor.c,v 1.60 2000/08/04 16:08:14 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -41,6 +41,7 @@ static const char rcsid[] = "$Id: Vendor.c,v 1.58 1994/06/05 13:13:36 amai Exp $
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/BulletinBP.h>
+#include <Xm/ShellEP.h>
 #include <Xm/MenuShellP.h>
 #include <Xm/VendorSEP.h>
 #include <Xm/VendorSP.h>
@@ -630,14 +631,62 @@ static Display *default_display = NULL;
 static void
 class_initialize(void)
 {
+    int ncom;
+    XtResourceList combined, shells;
+    Cardinal nshells;
+
     /* we only do this here so that people can override the default reptypes,
        based on information from Harald Albrecht */
     XmSetColorCalculation(NULL);
     _XmRegisterConverters();
     _XmRegisterPixmapConverters();
+
+    ncom = XtNumber(ext_resources) +
+		xmShellExtClassRec.object_class.num_resources;
+
+    _XmTransformSubResources(xmShellExtClassRec.object_class.resources,
+                             xmShellExtClassRec.object_class.num_resources,
+			     &shells, &nshells);
+
+    combined = (XtResourceList)XtMalloc(sizeof(XtResource) * ncom);
+
+    bcopy(shells, combined, nshells * sizeof(XtResource));
+    bcopy(ext_resources, &combined[nshells],
+	  XtNumber(ext_resources) * sizeof(XtResource));
+
+    xmVendorShellExtClassRec.object_class.resources = combined;
+    xmVendorShellExtClassRec.object_class.num_resources = ncom;
+
     _XmInitializeExtensions();
     _XmVendorSCoreClassExtRec.record_type = XmQmotif;
 
+    _XmBuildExtResources((WidgetClass)&xmVendorShellExtClassRec);
+
+    if (((XmShellExtObjectClass)&xmVendorShellExtClassRec)->
+	desktop_class.insert_child == XtInheritInsertChild)
+    {
+	((XmShellExtObjectClass)&xmVendorShellExtClassRec)->
+		desktop_class.insert_child =
+	    ((XmShellExtObjectClass)xmDesktopClass)->
+		    desktop_class.insert_child;
+    }
+    if (((XmShellExtObjectClass)&xmVendorShellExtClassRec)->
+	desktop_class.delete_child == XtInheritDeleteChild)
+    {
+	((XmShellExtObjectClass)&xmVendorShellExtClassRec)->
+		desktop_class.delete_child =
+	    ((XmShellExtObjectClass)xmDesktopClass)->
+		    desktop_class.delete_child;
+    }
+
+    if (((XmShellExtObjectClass)&xmVendorShellExtClassRec)->
+	shell_class.structureNotifyHandler == XmInheritEventHandler)
+    {
+	((XmShellExtObjectClass)&xmVendorShellExtClassRec)->
+		shell_class.structureNotifyHandler =
+	    ((XmShellExtObjectClass)xmShellExtClass)->
+		    shell_class.structureNotifyHandler;
+    }
 #if XmVERSION > 1
     /* Initialize traits */
     _XmInitTraits();
@@ -840,11 +889,12 @@ secondary_object_create(Widget req, Widget new_w,
 			ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
-    XmWidgetExtData data;
-    ArgList AllArgs;
-    Arg NeededArgs[3];
     Widget desktopParent;
     XmDisplay d = (XmDisplay)XmGetXmDisplay(XtDisplay(new_w));
+    XmWidgetExtData ed;
+    int size;
+    XtPointer nsec, rsec;
+    extern void _XtAddCallback(XtCallbackList *, XtCallbackProc, XtPointer);
 
     Display_ShellCount(d)++;
 
@@ -858,54 +908,54 @@ secondary_object_create(Widget req, Widget new_w,
      * --aldi 97/01/03: someone "optimized" here so that setting the
      * logicalParent and the extensionType is done after the XtCreateWidget().
      * But the initialize() method of the Desktop object relies on the
-     * desktopParent resource being set already when it is called. So either
-     * switch over to way we create secondary objects for gadgets (urgh) or
-     * we must set XmNdesktopParent before XtCreateWidget().
+     * desktopParent resource being set already when it is called.
      */
-    data = (XmWidgetExtData)XtCalloc(1, sizeof(XmWidgetExtDataRec));
     desktopParent = LTGetDesktopLogicalParentForShell(new_w);
-    if (*num_args)
-    {
-	AllArgs = (ArgList)XtCalloc(3 + *num_args, sizeof(Arg));
 
-	bcopy(args, &(AllArgs[3]), *num_args * sizeof(Arg));
+    size = (*bce)->secondaryObjectClass->core_class.widget_size;
 
-	XtSetArg(AllArgs[0], XmNlogicalParent, new_w);
-	XtSetArg(AllArgs[1], XmNextensionType, XmSHELL_EXTENSION);
-	XtSetArg(AllArgs[2], XmNdesktopParent, desktopParent);
+    nsec = XtCalloc(1, size);
+    rsec = _XmExtObjAlloc(size);
 
-	data->widget = XtCreateWidget("VendorShellExt",
-				      (*bce)->secondaryObjectClass,
-				      new_w,
-				      AllArgs, 3 + *num_args);
+    ((XmExtRec *)nsec)->object.self = (Widget)nsec;
+    ((XmExtRec *)nsec)->object.widget_class = (*bce)->secondaryObjectClass;
+    ((XmExtRec *)nsec)->object.parent = new_w;
+    ((XmExtRec *)nsec)->object.xrm_name = new_w->core.xrm_name;
+    ((XmExtRec *)nsec)->object.being_destroyed = False;
+    ((XmExtRec *)nsec)->object.destroy_callbacks = NULL;
+    ((XmExtRec *)nsec)->object.constraints = NULL;
 
-	XtFree((char *)AllArgs);
-    }
-    else
-    {
-	XtSetArg(NeededArgs[0], XmNlogicalParent, new_w);
-	XtSetArg(NeededArgs[1], XmNextensionType, XmSHELL_EXTENSION);
-	XtSetArg(NeededArgs[2], XmNdesktopParent, desktopParent);
-	data->widget = XtCreateWidget("VendorShellExt",
-				      (*bce)->secondaryObjectClass,
-				      new_w,
-				      NeededArgs, 3);
-    }
+    ExtObj_LogicalParent(nsec) = new_w;
+    ExtObj_ExtensionType(nsec) = XmSHELL_EXTENSION;
 
-    data->reqWidget = NULL;
+    Desktop_Parent(nsec) = desktopParent;
 
-    _XmPushWidgetExtData(new_w, data, XmSHELL_EXTENSION);
+    XtGetSubresources(new_w, nsec, NULL, NULL,
+                      (*bce)->secondaryObjectClass->core_class.resources,
+                      (*bce)->secondaryObjectClass->core_class.num_resources,
+                      args, *num_args);
 
-    XtAddCallback(data->widget, XmNrealizeCallback,
-		  _XmVendorExtRealize, NULL);
+    ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
+    ed->widget = (Widget)nsec;
+    ed->reqWidget = (Widget)rsec;
+
+    bcopy(nsec, rsec, size);
+    ((XmExtRec *)rsec)->object.self = (Widget)rsec;
+
+    _XmPushWidgetExtData(new_w, ed, XmSHELL_EXTENSION);
+
+    _XmExtImportArgs(nsec, args, num_args);
+
+    _XtAddCallback(&VSEP_RealizeCallback(ed->widget),
+		   _XmVendorExtRealize, NULL);
 
     /*
      * Now install some callbacks for use with the grab mechanism...
      */
     XtAddCallback(new_w, XmNpopupCallback,
-		  LTShellPopupCallback, data->widget);
+		  LTShellPopupCallback, ed->widget);
     XtAddCallback(new_w, XmNpopdownCallback,
-		  LTShellPopdownCallback, data->widget);
+		  LTShellPopdownCallback, ed->widget);
 }
 
 static void
@@ -936,6 +986,13 @@ static void
 initialize_posthook(Widget req, Widget new_w,
 		    ArgList args, Cardinal *num_args)
 {
+    XmWidgetExtData ext;
+
+    if ((ext = _XmGetWidgetExtData(new_w, XmSHELL_EXTENSION)) != NULL)
+    {
+	_XmExtObjFree(ext->reqWidget);
+        ext->reqWidget = NULL;
+    }
 }
 
 #define VSEPC_DeleteWindowHandler(w) \
@@ -1017,7 +1074,10 @@ destroy(Widget w)
 	DEBUGOUT(XdbDebug2(__FILE__, w, data->widget,
 		"VendorShell Destroy: destroy child\n"));
 
+	/* mitch
 	XtDestroyWidget(data->widget);
+	*/
+	_XmVendorExtDestroy(data->widget);
 	XtFree((char *)data);
     }
 }
@@ -1198,9 +1258,12 @@ set_values_prehook(Widget old, Widget req, Widget new_w,
 
     _XmPushWidgetExtData(new_w, data, XmSHELL_EXTENSION);
 
-    _XmExtImportArgs(data->widget, args, num_args);
+    XtSetSubvalues(data->widget,
+                   (*bce)->secondaryObjectClass->core_class.resources,
+                   (*bce)->secondaryObjectClass->core_class.num_resources,
+                   args, *num_args);
 
-    XtSetValues(data->widget, args, *num_args);
+    _XmExtImportArgs(data->widget, args, num_args);
 
     return False;
 }
@@ -1278,7 +1341,10 @@ get_values_prehook(Widget widget,
 
     _XmPushWidgetExtData(widget, data, XmSHELL_EXTENSION);
 
-    XtGetValues(data->widget, args, *num_args);
+    XtGetSubvalues(data->widget,
+                   (*bce)->secondaryObjectClass->core_class.resources,
+                   (*bce)->secondaryObjectClass->core_class.num_resources,
+		   args, *num_args);
 
     _XmExtGetValuesHook(data->widget, args, num_args);
 }
