@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Visual.c,v 1.24 1998/10/10 07:46:03 gritton Exp $
+ * $Id: Visual.c,v 1.29 1999/09/03 00:17:41 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Visual.c,v 1.24 1998/10/10 07:46:03 gritton Exp $";
+static const char rcsid[] = "$Id: Visual.c,v 1.29 1999/09/03 00:17:41 rwscott Exp $";
 
 #include <LTconfig.h>
 #include <XmI/XmI.h>
@@ -63,9 +63,12 @@ static const char rcsid[] = "$Id: Visual.c,v 1.24 1998/10/10 07:46:03 gritton Ex
 
 static Pixel black_or_white(XmColorData *cd, unsigned char which);
 static void call_color_proc(XmColorData *cd);
+static void _XmColorProcDefaultProc(XColor *bg_color, XColor *fg_color,
+				    XColor *sel_color, XColor *ts_color,
+				    XColor *bs_color);
 
 static XContext background_color_context, background_spec_context;
-static XmColorProc _color_proc = NULL;
+static XmColorProc _color_proc = _XmColorProcDefaultProc;
 static XmColorData color_cache[COLOR_CACHE_SIZE];
 
 /*
@@ -97,10 +100,6 @@ static void color_fail_warn(void)
   }
 }
 
-static void _XmColorProcDefaultProc(XColor *bg_color, XColor *fg_color,
-				    XColor *sel_color, XColor *ts_color,
-				    XColor *bs_color);
-
 XmColorProc
 XmSetColorCalculation(XmColorProc proc)
 {
@@ -123,7 +122,7 @@ XmSetColorCalculation(XmColorProc proc)
 }
 
 XmColorProc
-XmGetColorCalculation()
+XmGetColorCalculation(void)
 {
     return _color_proc;
 }
@@ -454,7 +453,7 @@ _XmAccessColorData(XmColorData *cd, unsigned char which)
 static Pixel
 black_or_white(XmColorData *cd, unsigned char which)
 {
-    int threshold;
+    int threshold = 0;
     long brightness;
     Widget sw;
 
@@ -813,7 +812,11 @@ _XmBackgroundColorDefault(Widget w,
 	_XmAddBackgroundToColorCache(cd.screen,
 				   cd.color_map,
 				   _XmGetDefaultBackgroundColorSpec(cd.screen),
+#if XmVERSION == 1
 				   0x729fff,
+#else
+				   0xc4c4c4,
+#endif
 				   val);
 
 	/* Save the XColor (which is now in the front of the color cache). */
@@ -910,7 +913,12 @@ _XmGetDefaultBackgroundColorSpec(Screen *screen)
 
     background_spec = XrmGetResource(XtScreenDatabase(screen), XmNbackground,
 	XmNbackground, &str_type, &val) && !strcmp( str_type, XmRString)
-	? val.addr : "rgb:72/9f/ff";
+	? val.addr
+#if XmVERSION == 1
+	: "rgb:72/9f/ff";
+#else
+	: "rgb:c4/c4/c4";
+#endif
 
     XSaveContext(DisplayOfScreen(screen),
 		 RootWindowOfScreen(screen),
@@ -1132,13 +1140,13 @@ static XtConvertArgRec gadgetPixmapArgs[] =
 static char *background_pixmap_name = NULL;
 
 char *
-_XmGetBGPixmapName()
+_XmGetBGPixmapName(void)
 {
     return background_pixmap_name;
 }
 
 void
-_XmClearBGPixmap( void )
+_XmClearBGPixmap(void)
 {
     background_pixmap_name = NULL;
 }
@@ -1327,8 +1335,8 @@ _XmCvtStringToGadgetPixmap(XrmValuePtr args, Cardinal *num_args,
     parent = *((Widget *)args[0].addr);
 
     pargs[0].addr = (XPointer)&CoreScreen(parent);
-    pargs[1].addr = (XPointer)&CoreBackground(parent);
-    pargs[2].addr = (XPointer)&MGR_Foreground(parent);
+    pargs[1].addr = (XPointer)&MGR_Foreground(parent);
+    pargs[2].addr = (XPointer)&CoreBackground(parent);
     pargs[3].addr = (XPointer)&CoreDepth(parent);
 
     BuildPixmap(pnargs, "_XmCvtStringToGadgetPixmap",
