@@ -1,6 +1,6 @@
 /*
 
- * $Header: /cvsroot/hungry/lesstif/lib/Xm/XmString.c,v 1.47 2000/06/14 20:00:12 danny Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm/XmString.c,v 1.50 2000/08/16 10:12:58 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/XmString.c,v 1.47 2000/06/14 20:00:12 danny Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/XmString.c,v 1.50 2000/08/16 10:12:58 amai Exp $";
 
 /*
  * ** Danny had added a flag here, but I think the behavior he added is always
@@ -1213,7 +1213,10 @@ _XmStringFree(_XmString string)
 
     for (i = 0; i < string->number_of_components; i++)
     {
-	if (string->components[i]->data /*&& string->components[i]->length*/)
+       /* Peter Stein, 07/2000 */                                                       
+       /* in some wired circumstances this may not be the case */                       
+       /* leading to a crash */                                                         
+	if (string->components[i] && string->components[i]->data /*&& string->components[i]->length*/)
 	{
 	    /* rws 30 Aug 1998
 	       If we only free this if the length is greater than 0 we end
@@ -1225,8 +1228,15 @@ _XmStringFree(_XmString string)
 
 	XtFree((char *)string->components[i]);
     }
-
-    XtFree((char *)string->components);
+                                                                                                  
+    if( string->number_of_components > 0 )                                                  
+      {                                                                                       
+       /* Peter Stein, 07/2000: */                                                      
+       /* initialisation in __XmAllocNewXmString() */                                   
+       /*      only done in this case */                                                
+       /* so free should also only happen than*/                                        
+         XtFree((char *)string->components);                                              
+      }
     XtFree((char *)string);
 }
 
@@ -1950,7 +1960,8 @@ int
 _XmStringLineCount(_XmString string)
 {
     _XmStringContext context = NULL;
-    char *text, *tag;
+    char *text;
+    char *tag=NULL;
     short len;
     XmStringDirection dir;
     Boolean sep;
@@ -4352,4 +4363,17 @@ XmParseTableFree(XmParseTable parse_table, Cardinal parse_count)
 	_XmWarning(NULL, "XmParseTableFree() is not implemented yet!\n");
 }
 
+/*  see
+   http://www.cs.stedwards.edu/a_doc_lib/libs/motiftr/XmStringGetNextTriple.htm
+*/
+
+XmStringComponentType XmStringGetNextTriple(XmStringContext context,
+           unsigned int *length,
+	   XtPointer *value)
+{
+	_XmWarning(NULL, "XmStringGetNextTriple() is not implemented yet!\n");
+	return (XmStringComponentType)NULL;
+}
+
+
 #endif
