@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Xmos.c,v 1.28 2000/02/03 17:55:38 amai Exp $
+ * $Id: Xmos.c,v 1.29 2000/08/04 12:02:47 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Xmos.c,v 1.28 2000/02/03 17:55:38 amai Exp $";
+static const char rcsid[] = "$Id: Xmos.c,v 1.29 2000/08/04 12:02:47 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -859,20 +859,20 @@ char _XmSDEFAULT_BACKGROUND[] = "Blue";
 
 
 /*
- * Not sure what this thing does but it's rumoured to exist
+ * ?: Not sure what this thing does but it's rumoured to exist
    amai: based on a look at some Motif libs I guess it's
          a 'ghost' induced by typo only ... See below!
- */
+
 void
 XmOSInitPath()
 {
- _XmWarning(NULL, "XmOSInitPath() is not yet implemented!");
+ _XmWarning(NULL, "XmOSInitPath() is not implemented! Please report!");
 }
-
+*/
 
 /*
- * This one seems to exist in Motif 1.2 and above ...
-   Probably contrary to XmOSInitPath()
+ * This one exists in Motif 1.2 (and above?)
+   Probably contrary to XmOSInitPath() ...
  */
 String
 _XmOSInitPath(String file_name, String env_pathname, Boolean *user_path)
