@@ -5,6 +5,66 @@
 #include <Xm/XmAll.h>
 #include <Xm/Notebook.h>
 
+void
+check_geometry(Widget w)
+{
+   static int result_index = 0;
+
+static XtWidgetGeometry Expected[] = {
+/* result test 0 */
+{  CWWidth | CWHeight            ,    4,   23,  639,  565, 0,0,0 }, /* test1.motif */
+{  CWWidth | CWHeight            ,    4,   23,  639,  565, 0,0,0 }, /* notebook */
+{  CWWidth | CWHeight | CWX | CWY,  446,  507,   94,   29, 0,0,0 }, /* PageScroller */
+{  CWWidth | CWHeight | CWX | CWY,   20,    2,   54,   25, 0,0,0 }, /* NBTextField */
+{  CWWidth | CWHeight | CWX | CWY,  -20,  -20,   20,   20, 0,0,0 }, /* MajorTabScrollerNext */
+{  CWWidth | CWHeight | CWX | CWY,  -20,  -20,   20,   20, 0,0,0 }, /* MajorTabScrollerPrevious */
+{  CWWidth | CWHeight | CWX | CWY,  -20,  -20,   20,   20, 0,0,0 }, /* MinorTabScrollerNext */
+{  CWWidth | CWHeight | CWX | CWY,  -20,  -20,   20,   20, 0,0,0 }, /* MinorTabScrollerPrevious */
+{  CWWidth | CWHeight | CWX | CWY, -500, -504,  500,  504, 0,0,0 }, /* configureWindow */
+{  CWWidth | CWHeight | CWX | CWY,  383,  160,   99,   30, 0,0,0 }, /* moveDownButton */
+{  CWWidth | CWHeight | CWX | CWY,  259,  160,   99,   30, 0,0,0 }, /* moveUpButton */
+{  CWWidth | CWHeight | CWX | CWY,   10,  160,   99,   30, 0,0,0 }, /* addDBButton */
+{  CWWidth | CWHeight | CWX | CWY,   10,  200,  482,   20, 0,0,0 }, /* separator2 */
+{  CWWidth | CWHeight | CWX | CWY,  134,  160,  100,   30, 0,0,0 }, /* deleteButton */
+{  CWWidth | CWHeight | CWX | CWY,   10,  426,  480,   20, 0,0,0 }, /* separator1 */
+{  CWWidth | CWHeight | CWX | CWY,  222,  380,  268,   36, 0,0,0 }, /* dbDescFileTf */
+{  CWWidth | CWHeight | CWX | CWY,  222,  332,  268,   36, 0,0,0 }, /* dbFileTf */
+{  CWWidth | CWHeight | CWX | CWY,   10,  383,  200,   43, 0,0,0 }, /* label5 */
+{  CWWidth | CWHeight | CWX | CWY,   10,  331,  202,   42, 0,0,0 }, /* label4 */
+{  CWWidth | CWHeight | CWX | CWY,   10,  280,  202,   41, 0,0,0 }, /* label3 */
+{  CWWidth | CWHeight | CWX | CWY,  222,  280,  268,   35, 0,0,0 }, /* optionMenu1 */
+{  CWWidth | CWHeight | CWX | CWY,    3,    3,   10,   29, 0,0,0 }, /* OptionLabel */
+{  CWWidth | CWHeight | CWX | CWY,   16,    3,  103,   29, 0,0,0 }, /* OptionButton */
+{  CWWidth | CWHeight | CWX | CWY,  222,  230,  268,   36, 0,0,0 }, /* dbNameTf */
+{  CWWidth | CWHeight | CWX | CWY,   10,  230,  202,   40, 0,0,0 }, /* label2 */
+{  CWWidth | CWHeight | CWX | CWY,   10,   50,  481,  100, 0,0,0 }, /* scrolledWindow1 */
+{  CWWidth | CWHeight | CWX | CWY,    0,    0,   15,  104, 0,0,0 }, /* VertScrollBar */
+{  CWWidth | CWHeight | CWX | CWY,    0,    0,  481,  100, 0,0,0 }, /* dbList */
+{  CWWidth | CWHeight | CWX | CWY,   10,   10,  101,   30, 0,0,0 }, /* label1 */
+{  CWWidth | CWHeight | CWX | CWY,  230,  456,  115,   31, 0,0,0 }, /* cancelButton */
+{  CWWidth | CWHeight | CWX | CWY,   20,  456,  115,   31, 0,0,0 }, /* applyButton */
+{  CWWidth | CWHeight | CWX | CWY,    0,    0,    1,    1, 0,0,0 }, /* menuShell */
+{  CWWidth | CWHeight | CWX | CWY,    0,    0,   78,   25, 0,0,0 }, /* pulldownMenu5 */
+{  CWWidth | CWHeight | CWX | CWY,    2,    2,   74,   21, 0,0,0 }, /* pushButton5 */
+{  CWWidth | CWHeight | CWX | CWY,  -90,  -25,   90,   25, 0,0,0 }, /* ConfigurePage */
+{  CWWidth | CWHeight | CWX | CWY,   40,    3,  500,  504, 0,0,0 }, /* tf */
+{  CWWidth | CWHeight | CWX | CWY,  540,   10,   90,   25, 0,0,0 }, /* Editor */
+{  CWWidth | CWHeight | CWX | CWY,  -36,  -25,   36,   25, 0,0,0 }, /* quit */
+{  CWWidth | CWHeight | CWX | CWY,  545,   38,   90,   25, 0,0,0 }, /* Quit */
+};
+
+#if 0
+   PrintDetails2(w, NULL);
+#else
+  if (result_index <= 0)
+  {
+     PrintDetails2(w, Expected);
+     fflush(stdout);
+     result_index ++;
+  }
+#endif
+}
+
 void Quit(Widget w, XtPointer client, XtPointer call)
 {
 	exit(0);
@@ -28,6 +88,7 @@ main(int argc, char **argv)
 		&argc, argv, NULL, NULL);
 
 	ac = 0;
+	XtSetArg(al[ac], XmNbindingType, XmSPIRAL); ac++;
 	nb = XmCreateNotebook(toplevel, "notebook", al, ac);
 
 	ac = 0;
@@ -68,7 +129,9 @@ main(int argc, char **argv)
 
 	XtRealizeWidget(toplevel);
 
-	XtAppMainLoop(app);
+	check_geometry(toplevel);
+
+	LessTifTestMainLoop(toplevel);
 
 	exit(0);
 }
