@@ -9,6 +9,9 @@
 #include <Xm/MessageB.h>
 #include <Xm/CascadeB.h>
 #include <Xm/Command.h>
+#include <Xm/Text.h>
+#include <Xm/TextF.h>
+#include <Xm/PanedW.h>
 #include <Xm/Frame.h>
 #include <Xm/Label.h>
 
@@ -67,6 +70,7 @@ static String fallback_resources[] =
    CWWidth | CWHeight | CWX | CWY,  380,  164,   10,   10, 0,0,0, /* sash */
    CWWidth | CWHeight | CWX | CWY,    0,  168,  400,    2, 0,0,0, /* separator */ 
     };
+
 void ShowHelp(w, client_data, call_data)
 Widget w;
 XtPointer client_data;
@@ -213,7 +217,7 @@ char **argv;
             0);         /* no arguments needed */
     XtManageChild(menuBar);
 
-    paned = XmCreatePanedWindow(mainWindow, "GXPanedW", NULL, NULL);
+    paned = XmCreatePanedWindow(mainWindow, "GXPanedW", NULL, 0);
     XtVaSetValues(paned, XmNspacing, 10, NULL);	    
     XtManageChild(paned);
 
