@@ -1,3 +1,4 @@
+/* $Id: test13.c,v 1.6 2000/08/25 13:38:40 amai Exp $ */
 /*
 From:        "Dr. Peer Griebel" <griebel@rocketmail.com>
 - shows a sizing problem when the top window is resized
@@ -24,6 +25,7 @@ From:        "Dr. Peer Griebel" <griebel@rocketmail.com>
 #include <Xm/MainW.h>
 #include <Xm/RowColumn.h>
 
+#include <stdlib.h>
 #include <stdio.h>
 
 static Widget appshell = NULL;
@@ -39,7 +41,8 @@ static Display		*display;
 static XtAppContext	application_context;
 static int		quad_width;
 
-void Resize()
+void Resize(void)
+
 {
     Arg            args[10];
     Cardinal      argcount;
@@ -99,8 +102,8 @@ void BuildMainApplication( display )
     XtSetArg( args[argcount], XmNspacing, (short) 1 ); argcount++;
     pgHelpMainWindow = XmCreateMainWindow( appshell, "pgHelpMainWindow", args,
 					   argcount );
-    XtAddEventHandler( pgHelpMainWindow, StructureNotifyMask, False, Resize,
-		       (XtPointer) NULL ); /* help.c */
+    XtAddEventHandler( pgHelpMainWindow, StructureNotifyMask, False,
+                       (XtEventHandler)Resize, (XtPointer) NULL ); /* help.c */
     XtManageChild( pgHelpMainWindow );
    
     /*
