@@ -1,4 +1,9 @@
+/* $Id: test8.c,v 1.6 2000/08/25 13:38:42 amai Exp $ */
+
+#include <stdlib.h>
+#include <stdio.h>
 #include <Xm/XmAll.h>
+
 #define LOCAL_CLIP_FRONT 0
 #define LOCAL_CLIP_REAR 1
 #define GLOBAL_CLIP_FRONT 2
@@ -7,6 +12,7 @@
 void GXMakeClipBox(void);
 
 Widget GXTopWidget, GXClipBox;
+
 int main(int argc, char **argv)
 {
   XtAppContext theApp;
@@ -32,13 +38,15 @@ static XtWidgetGeometry Expected[] = {
    CWWidth | CWHeight | CWX | CWY,  275,    0,   31,  104, 0,0,0, /* RearGlobalClipScale */
    CWWidth | CWHeight | CWX | CWY,   12,    0,   19,  104, 0,0,0, /* Scrollbar */
 };
+
 /* toplevel should be replaced with to correct applicationShell */
 PrintDetails(GXClipBox, Expected);
 }
-  LessTifTestMainLoop(GXTopWidget);
+  LessTifTestMainLoop(GXClipBox);
 
   exit(0);
 }
+
 static void scaleCB(Widget w, int client, XtPointer call_data)
 /*-
  *  callback for clipping scales
@@ -74,6 +82,7 @@ GXGetColor(char *colorstr)
 	return ((XtArgVal) NULL);
 
 }
+
 void GXSetTroughColor(Widget w, Pixel selectColor)
 /*-
   provide an API for setting the trough color of an XmScale Widget
@@ -147,9 +156,9 @@ void GXMakeClipBox(void)
     GXSetTroughColor(scale, GXGetColor("white"));
 
     XtManageChild(scale);
-    XtAddCallback(scale, XmNvalueChangedCallback, (XtPointer) scaleCB,
+    XtAddCallback(scale, XmNvalueChangedCallback, (XtCallbackProc) scaleCB,
 		  (XtPointer) GLOBAL_CLIP_FRONT);
-    XtAddCallback(scale, XmNdragCallback, (XtPointer) scaleCB,
+    XtAddCallback(scale, XmNdragCallback, (XtCallbackProc) scaleCB,
 		  (XtPointer) GLOBAL_CLIP_FRONT);
 
     /* front local scale */
@@ -171,9 +180,9 @@ void GXMakeClipBox(void)
     GXSetTroughColor(scale, GXGetColor("red"));
 
     XtManageChild(scale);
-    XtAddCallback(scale, XmNvalueChangedCallback, (XtPointer) scaleCB,
+    XtAddCallback(scale, XmNvalueChangedCallback, (XtCallbackProc) scaleCB,
 		  (XtPointer) LOCAL_CLIP_FRONT);
-    XtAddCallback(scale, XmNdragCallback, (XtPointer) scaleCB,
+    XtAddCallback(scale, XmNdragCallback, (XtCallbackProc) scaleCB,
 		  (XtPointer) LOCAL_CLIP_FRONT);
 
 #ifdef USEGL
@@ -221,9 +230,9 @@ void GXMakeClipBox(void)
     GXSetTroughColor(scale, GXGetColor("green"));
 
     XtManageChild(scale);
-    XtAddCallback(scale, XmNvalueChangedCallback, (XtPointer) scaleCB,
+    XtAddCallback(scale, XmNvalueChangedCallback, (XtCallbackProc) scaleCB,
 		  (XtPointer) LOCAL_CLIP_REAR);
-    XtAddCallback(scale, XmNdragCallback, (XtPointer) scaleCB,
+    XtAddCallback(scale, XmNdragCallback, (XtCallbackProc) scaleCB,
 		  (XtPointer) LOCAL_CLIP_REAR);
 
     /* rear scale */
@@ -244,9 +253,9 @@ void GXMakeClipBox(void)
 		  NULL);
     GXSetTroughColor(scale, GXGetColor("blue"));
     XtManageChild(scale);
-    XtAddCallback(scale, XmNvalueChangedCallback, (XtPointer) scaleCB,
+    XtAddCallback(scale, XmNvalueChangedCallback, (XtCallbackProc) scaleCB,
 		  (XtPointer) GLOBAL_CLIP_REAR);
-    XtAddCallback(scale, XmNdragCallback, (XtPointer) scaleCB,
+    XtAddCallback(scale, XmNdragCallback, (XtCallbackProc) scaleCB,
 		  (XtPointer) GLOBAL_CLIP_REAR);
 
     /* install_icon(GXClipBox); */
