@@ -1,3 +1,7 @@
+/* $Id: test51.c,v 1.29 2000/08/25 13:38:50 amai Exp $ */
+
+#include <stdlib.h>
+#include <stdio.h>
 #include <Xm/Xm.h>
 #include <Xm/XmP.h>
 #include <Xm/CascadeB.h>
@@ -16,7 +20,6 @@
 #include <Xm/DrawingA.h>
 #include <Xm/Label.h>
 #include <X11/keysym.h>
-#include <stdio.h>
 #include "../../common/Test.h"
 
 /*
@@ -510,12 +513,12 @@ main(int argc, char **argv)
 
 /* First Menu */
     pane1 = XmCreatePulldownMenu(menubar, "pane1", NULL, 0);
-    XtAddCallback(pane1, XmNmapCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(pane1, XmNtearOffMenuActivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(pane1, XmNtearOffMenuDeactivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(pane1, XmNunmapCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    /*XtAddCallback(XtParent(pane1), XmNpopupCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(XtParent(pane1), XmNpopdownCallback, (void *)GenericCallback, (XtPointer)__LINE__);*/
+    XtAddCallback(pane1, XmNmapCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(pane1, XmNtearOffMenuActivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(pane1, XmNtearOffMenuDeactivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(pane1, XmNunmapCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    /*XtAddCallback(XtParent(pane1), XmNpopupCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(XtParent(pane1), XmNpopdownCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);*/
     pane1_tear_off = XmGetTearOffControl(pane1);
 
     cascade1 = XtVaCreateWidget("cascade1",
@@ -525,39 +528,39 @@ main(int argc, char **argv)
     XtVaGetValues(cascade1,
     	XmNmappingDelay, &mappingDelay,
     	NULL);
-    XtAddCallback(cascade1, XmNactivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(cascade1, XmNcascadingCallback, (void *)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(cascade1, XmNactivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(cascade1, XmNcascadingCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
 
     button1 = XtVaCreateManagedWidget("button1", 
     				xmPushButtonWidgetClass, pane1,
 				NULL);
-    XtAddCallback(button1, XmNactivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(button1, XmNarmCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(button1, XmNdisarmCallback, (void *)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(button1, XmNactivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(button1, XmNarmCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(button1, XmNdisarmCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
 
 /* Second Menu */
     pane2 = XmCreatePulldownMenu(pane1, "pane2", NULL, 0);
-    XtAddCallback(pane2, XmNmapCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(pane2, XmNtearOffMenuActivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(pane2, XmNtearOffMenuDeactivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(pane2, XmNunmapCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    /*XtAddCallback(XtParent(pane2), XmNpopupCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(XtParent(pane2), XmNpopdownCallback, (void *)GenericCallback, (XtPointer)__LINE__);*/
+    XtAddCallback(pane2, XmNmapCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(pane2, XmNtearOffMenuActivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(pane2, XmNtearOffMenuDeactivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(pane2, XmNunmapCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    /*XtAddCallback(XtParent(pane2), XmNpopupCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(XtParent(pane2), XmNpopdownCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);*/
     pane2_tear_off = XmGetTearOffControl(pane2);
 
     cascade2 = XtVaCreateManagedWidget("cascade2",
 				       xmCascadeButtonWidgetClass, pane1, 
 				       XmNsubMenuId,	pane2,
 				       NULL);
-    XtAddCallback(cascade2, XmNactivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(cascade2, XmNcascadingCallback, (void *)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(cascade2, XmNactivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(cascade2, XmNcascadingCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
 
     button2 = XtVaCreateManagedWidget("button2", 
     				xmPushButtonWidgetClass, pane2,
 				NULL);
-    XtAddCallback(button2, XmNactivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(button2, XmNarmCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(button2, XmNdisarmCallback, (void *)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(button2, XmNactivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(button2, XmNarmCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(button2, XmNdisarmCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
 
     XtManageChild(menubar);
     XtRealizeWidget(toplevel);
@@ -650,9 +653,9 @@ main(int argc, char **argv)
     printf("\n");
 
     toggle1 = XmCreateToggleButton(pane1, "toggle1", NULL, 0);
-    XtAddCallback(toggle1, XmNvalueChangedCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(toggle1, XmNarmCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(toggle1, XmNdisarmCallback, (void *)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(toggle1, XmNvalueChangedCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(toggle1, XmNarmCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(toggle1, XmNdisarmCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
     XtManageChild(toggle1);
 
     LessTifTestBtn1Down(cascade1);
@@ -676,9 +679,9 @@ main(int argc, char **argv)
     button3 = XtVaCreateManagedWidget("button3", 
     				xmPushButtonWidgetClass, pane1,
 				NULL);
-    XtAddCallback(button3, XmNactivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(button3, XmNarmCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(button3, XmNdisarmCallback, (void *)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(button3, XmNactivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(button3, XmNarmCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(button3, XmNdisarmCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
 
     LessTifTestBtn1Down(cascade1);
     LessTifTestBtn1Up(cascade1);
@@ -733,8 +736,8 @@ main(int argc, char **argv)
     cascade3 = XtVaCreateWidget("cascade3",
 				       xmCascadeButtonWidgetClass, menubar, 
 				       NULL);
-    XtAddCallback(cascade3, XmNactivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(cascade3, XmNcascadingCallback, (void *)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(cascade3, XmNactivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(cascade3, XmNcascadingCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
     XtManageChild(cascade3);
 
     LessTifTestBtn1Down(cascade1);
@@ -748,17 +751,17 @@ main(int argc, char **argv)
     printf("\n");
 
     pane3 = XmCreatePulldownMenu(menubar, "pane3", NULL, 0);
-    XtAddCallback(pane3, XmNmapCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(pane3, XmNtearOffMenuActivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(pane3, XmNtearOffMenuDeactivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(pane3, XmNunmapCallback, (void *)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(pane3, XmNmapCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(pane3, XmNtearOffMenuActivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(pane3, XmNtearOffMenuDeactivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(pane3, XmNunmapCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
     pane3_tear_off = XmGetTearOffControl(pane3);
     button4 = XtVaCreateManagedWidget("button4", 
     				xmPushButtonWidgetClass, pane3,
 				NULL);
-    XtAddCallback(button4, XmNactivateCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(button4, XmNarmCallback, (void *)GenericCallback, (XtPointer)__LINE__);
-    XtAddCallback(button4, XmNdisarmCallback, (void *)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(button4, XmNactivateCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(button4, XmNarmCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
+    XtAddCallback(button4, XmNdisarmCallback, (XtCallbackProc)GenericCallback, (XtPointer)__LINE__);
     XtVaSetValues(cascade3,
     	XmNsubMenuId, pane3,
     	NULL);
