@@ -1,3 +1,4 @@
+/* $Id: test15.c,v 1.5 2000/08/25 13:38:55 amai Exp $ */
 /**---------------------------------------------------------------
 ***-------------------------------------------------------------------*/
 
@@ -101,11 +102,11 @@ XtExposeProc DefaultOutputExpose ;
 XtInitProc DefaultInitialize ;
 
 XmTextStatus MyReplaceProc( XmTextWidget, XEvent *, XmTextPosition *,
-    		XmTextPosition *, XmTextBlock , int  );
+    		XmTextPosition *, XmTextBlock , Boolean);
 XmTextPosition MyReadProc( XmTextSource, XmTextPosition, XmTextPosition, XmTextBlock );
 XmTextPosition MyXYToPos( XmTextWidget, Position, Position );
 XmTextPosition MyScanProc( XmTextSource, XmTextPosition, XmTextScanType,
-    		XmTextScanDirection, int, int);
+    		XmTextScanDirection, int, Boolean);
 Boolean MyGetSelectionProc  ( XmTextSource , XmTextPosition* , XmTextPosition* );
 Boolean MyMeasureLineProc ( XmTextWidget, LineNum, XmTextPosition, XmTextPosition *,
 			LineTableExtraRec **);
@@ -1048,7 +1049,7 @@ XmTextStatus MyReplaceProc(
     		XmTextPosition *start,
     		XmTextPosition *end,
     		XmTextBlock block,
-			int callcallback )
+		Boolean callcallback )
 {
 	LineNum lineNum;
 	XmTextStatus status;
@@ -1369,7 +1370,7 @@ XmTextPosition MyScanProc(
     		XmTextScanType type,
     		XmTextScanDirection dir,	/* Either XmsdLeft or XmsdRight. */
     		int count,
-    		int include )
+    		Boolean include )
 {
 	XmTextPosition result;
 	indent ++;
